@@ -93,9 +93,9 @@ func GenMarkdownCustom(cmd *cobra.Command, w io.Writer, linkHandler func(string)
 
 		// If it's runnable, show the useline otherwise show a version with [command]
 		if cmd.Runnable() {
-			buf.WriteString(fmt.Sprintf("```\n%s\n```\n\n", cmd.UseLine()))
+			fmt.Fprintf(buf, "```\n%s\n```\n\n", cmd.UseLine())
 		} else {
-			buf.WriteString(fmt.Sprintf("```\n%s [command] [flags]\n```", cmd.CommandPath()) + "\n\n")
+			fmt.Fprintf(buf, "```\n%s [command] [flags]\n```\n\n", cmd.CommandPath())
 		}
 	}
 
@@ -110,15 +110,15 @@ func GenMarkdownCustom(cmd *cobra.Command, w io.Writer, linkHandler func(string)
 			}
 			cname := name + " " + child.Name()
 			link := cname + ".md"
-			link = strings.Replace(link, " ", "_", -1)
-			buf.WriteString(fmt.Sprintf("* [%s](%s)\t - %s\n", child.Name(), linkHandler(link), child.Short))
+			link = strings.ReplaceAll(link, " ", "_")
+			fmt.Fprintf(buf, "* [%s](%s)\t - %s\n", child.Name(), linkHandler(link), child.Short)
 		}
 		buf.WriteString("\n")
 	}
 
 	if len(cmd.Example) > 0 {
 		buf.WriteString(titlePrefix + "Examples\n\n")
-		buf.WriteString(fmt.Sprintf("```\n%s\n```\n\n", cmd.Example))
+		fmt.Fprintf(buf, "```\n%s\n```\n\n", cmd.Example)
 	}
 
 	if err := printOptions(buf, cmd, name); err != nil {
@@ -130,8 +130,8 @@ func GenMarkdownCustom(cmd *cobra.Command, w io.Writer, linkHandler func(string)
 			parent := cmd.Parent()
 			pname := parent.CommandPath()
 			link := pname + ".md"
-			link = strings.Replace(link, " ", "_", -1)
-			buf.WriteString(fmt.Sprintf("* [%s](%s)\t - %s\n", pname, linkHandler(link), parent.Short))
+			link = strings.ReplaceAll(link, " ", "_")
+			fmt.Fprintf(buf, "* [%s](%s)\t - %s\n", pname, linkHandler(link), parent.Short)
 			cmd.VisitParents(func(c *cobra.Command) {
 				if c.DisableAutoGenTag {
 					cmd.DisableAutoGenTag = c.DisableAutoGenTag
@@ -172,7 +172,7 @@ func GenMarkdownTreeCustom(cmd *cobra.Command, dir string, filePrepender, linkHa
 		}
 	}
 
-	basename := strings.Replace(cmd.CommandPath(), " ", "_", -1) + ".md"
+	basename := strings.ReplaceAll(cmd.CommandPath(), " ", "_") + ".md"
 	filename := filepath.Join(dir, basename)
 	f, err := os.Create(filename)
 	if err != nil {
