@@ -33,11 +33,11 @@ func getAppV2ConfigFromMachines(ctx context.Context, appName string) (*Config, e
 	flapsClient := flapsutil.ClientFromContext(ctx)
 	io := iostreams.FromContext(ctx)
 
-	activeMachines, err := machine.ListActive(ctx)
+	activeMachines, err := machine.ListActive(ctx, appName)
 	if err != nil {
 		return nil, fmt.Errorf("error listing active machines for %s app: %w", appName, err)
 	}
-	machineSet := machine.NewMachineSet(flapsClient, io, activeMachines, true)
+	machineSet := machine.NewMachineSet(flapsClient, io, appName, activeMachines, true)
 	appConfig, warnings, err := FromAppAndMachineSet(ctx, appName, machineSet)
 	if err != nil {
 		return nil, fmt.Errorf("failed to grab app config from existing machines, error: %w", err)
