@@ -9,13 +9,17 @@ import (
 
 	"github.com/spf13/pflag"
 	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag/flagctx"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/instrument"
 	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/state"
+	"github.com/superfly/flyctl/internal/uiex"
+	"github.com/superfly/flyctl/internal/uiexutil"
 	"go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp"
 )
 
@@ -56,6 +60,25 @@ func InitClient(ctx context.Context) (context.Context, error) {
 		ctx = flyutil.NewContextWithClient(ctx, client)
 	}
 
+	if uiexutil.ClientFromContext(ctx) == nil {
+		client, err := uiexutil.NewClientWithOptions(ctx, uiex.NewClientOpts{
+			Logger: logger,
+			Tokens: cfg.Tokens,
+		})
+		if err != nil {
+			return nil, err
+		}
+		ctx = uiexutil.NewContextWithClient(ctx, client)
+	}
+
+	if flapsutil.ClientFromContext(ctx) == nil {
+		flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{})
+		if err != nil {
+			return nil, err
+		}
+		ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
+	}
+
 	return ctx, nil
 }
 
@@ -132,7 +155,7 @@ func ApplyAliases(ctx context.Context) (context.Context, error) {
 			errorMessages = append(errorMessages, fmt.Sprintf("flags '%v' have different types", invalidTypes))
 		}
 		if len(errorMessages) > 1 {
-			err = fmt.Errorf("multiple errors occured:\n > %s\n", strings.Join(errorMessages, "\n > "))
+			err = fmt.Errorf("multiple errors occurred:\n > %s\n", strings.Join(errorMessages, "\n > "))
 		} else if len(errorMessages) == 1 {
 			err = fmt.Errorf("%s", errorMessages[0])
 		}
