@@ -12,6 +12,7 @@ import (
 
 	"github.com/superfly/flyctl/iostreams"
 
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/prompt"
@@ -84,7 +85,7 @@ func RunDestroy(ctx context.Context) error {
 		}
 
 		if bucket != nil {
-			_, err = gql.DeleteAddOn(ctx, client.GenqClient(), bucket.Name)
+			_, err = gql.DeleteAddOn(ctx, client.GenqClient(), bucket.Name, string(gql.AddOnTypeTigris))
 			if err != nil {
 				return err
 			}
@@ -95,6 +96,8 @@ func RunDestroy(ctx context.Context) error {
 			return err
 		}
 
+		_ = appsecrets.DeleteMinvers(ctx, appName)
+
 		fmt.Fprintf(io.Out, "Destroyed app %s\n", appName)
 	}
 
