@@ -5,6 +5,7 @@ import (
 	"fmt"
 
 	"github.com/spf13/cobra"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command/deploy/statics"
 	"github.com/superfly/flyctl/internal/flag/completion"
 	"github.com/superfly/flyctl/internal/flyutil"
@@ -107,7 +108,7 @@ func runMoveAppOnMachines(ctx context.Context, app *fly.App, targetOrg *fly.Orga
 		return err
 	}
 
-	machines, releaseLeaseFunc, err := mach.AcquireAllLeases(ctx)
+	machines, releaseLeaseFunc, err := mach.AcquireAllLeases(ctx, app.Name)
 	defer releaseLeaseFunc()
 	if err != nil {
 		return err
@@ -134,14 +135,20 @@ func runMoveAppOnMachines(ctx context.Context, app *fly.App, targetOrg *fly.Orga
 		}
 	}
 
+	minvers, err := appsecrets.GetMinvers(app.Name)
+	if err != nil {
+		return err
+	}
+
 	for _, machine := range machines {
 		input := &fly.LaunchMachineInput{
-			Name:             machine.Name,
-			Region:           machine.Region,
-			Config:           machine.Config,
-			SkipHealthChecks: skipHealthChecks,
+			Name:              machine.Name,
+			Region:            machine.Region,
+			Config:            machine.Config,
+			SkipHealthChecks:  skipHealthChecks,
+			MinSecretsVersion: minvers,
 		}
-		mach.Update(ctx, machine, input)
+		mach.Update(ctx, app.Name, machine, input)
 	}
 	fmt.Fprintf(io.Out, "successfully moved %s to %s\n", app.Name, targetOrg.Name)
 
