@@ -9,6 +9,7 @@ import (
 	"os"
 	"path"
 	"path/filepath"
+	"slices"
 	"strconv"
 	"strings"
 
@@ -17,7 +18,6 @@ import (
 	"github.com/samber/lo"
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/iostreams"
-	"golang.org/x/exp/slices"
 
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/build/imgsrc"
@@ -28,6 +28,7 @@ import (
 	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/launchdarkly"
 	"github.com/superfly/flyctl/internal/state"
+	"github.com/superfly/flyctl/internal/uiexutil"
 )
 
 func DetermineImage(ctx context.Context, appName string, imageOrPath string) (img *imgsrc.DeploymentImage, err error) {
@@ -37,7 +38,8 @@ func DetermineImage(ctx context.Context, appName string, imageOrPath string) (im
 		cfg    = appconfig.ConfigFromContext(ctx)
 	)
 
-	appCompact, err := client.GetAppCompact(ctx, appName)
+	flapsClient := flapsutil.ClientFromContext(ctx)
+	app, err := flapsClient.GetApp(ctx, appName)
 	if err != nil {
 		return nil, err
 	}
@@ -45,7 +47,7 @@ func DetermineImage(ctx context.Context, appName string, imageOrPath string) (im
 	// Start the feature flag client, if we haven't already
 	if launchdarkly.ClientFromContext(ctx) == nil {
 		ffClient, err := launchdarkly.NewClient(ctx, launchdarkly.UserInfo{
-			OrganizationID: appCompact.Organization.InternalNumericID,
+			OrganizationID: fmt.Sprint(app.Organization.InternalNumericID),
 			UserID:         0,
 		})
 		if err != nil {
@@ -54,10 +56,19 @@ func DetermineImage(ctx context.Context, appName string, imageOrPath string) (im
 		ctx = launchdarkly.NewContextWithClient(ctx, ffClient)
 	}
 
+	uiexClient := uiexutil.ClientFromContext(ctx)
+	org, err := uiexClient.GetOrganization(ctx, app.Organization.Slug)
+	if err != nil {
+		return nil, err
+	}
+
 	ldClient := launchdarkly.ClientFromContext(ctx)
 	useManagedBuilder := ldClient.ManagedBuilderEnabled()
 	daemonType := imgsrc.NewDockerDaemonType(!flag.GetBool(ctx, "build-remote-only"), !flag.GetBool(ctx, "build-local-only"), env.IsCI(), flag.GetBool(ctx, "build-depot"), flag.GetBool(ctx, "build-nixpacks"), useManagedBuilder)
-	resolver := imgsrc.NewResolver(daemonType, client, appName, io, flag.GetWireguard(ctx), false)
+	resolver := imgsrc.NewResolver(
+		daemonType, client, appName, io, flag.GetWireguard(ctx), false,
+		imgsrc.WithProvisioner(imgsrc.NewProvisionerUiexOrg(org)),
+	)
 
 	// build if relative or absolute path
 	if strings.HasPrefix(imageOrPath, ".") || strings.HasPrefix(imageOrPath, "/") {
@@ -93,14 +104,7 @@ func DetermineImage(ctx context.Context, appName string, imageOrPath string) (im
 		}
 		opts.BuildArgs = extraArgs
 
-		if cfg != nil && cfg.Experimental != nil {
-			opts.UseZstd = cfg.Experimental.UseZstd
-		}
-
-		// use-zstd passed through flags takes precedence over the one set in config
-		if flag.IsSpecified(ctx, "use-zstd") {
-			opts.UseZstd = flag.GetBool(ctx, "use-zstd")
-		}
+		opts.Compression, opts.CompressionLevel = cfg.DetermineCompression(ctx)
 
 		img, err = resolver.BuildImage(ctx, io, opts)
 		if err != nil {
@@ -351,7 +355,7 @@ func parseFiles(ctx context.Context, flagName string, cb func(value string, file
 	return machineFiles, nil
 }
 
-func DetermineMounts(ctx context.Context, mounts []fly.MachineMount, region string) ([]fly.MachineMount, error) {
+func DetermineMounts(ctx context.Context, appName string, mounts []fly.MachineMount, region string) ([]fly.MachineMount, error) {
 	unattachedVolumes := make(map[string][]fly.Volume)
 
 	pathIndex := make(map[string]int)
@@ -373,7 +377,7 @@ func DetermineMounts(ctx context.Context, mounts []fly.MachineMount, region stri
 			// Load app volumes the first time
 			if len(unattachedVolumes) == 0 {
 				var err error
-				unattachedVolumes, err = getUnattachedVolumes(ctx, region)
+				unattachedVolumes, err = getUnattachedVolumes(ctx, appName, region)
 				if err != nil {
 					return nil, err
 				}
@@ -398,7 +402,7 @@ func DetermineMounts(ctx context.Context, mounts []fly.MachineMount, region stri
 	return mounts, nil
 }
 
-func getUnattachedVolumes(ctx context.Context, regionCode string) (map[string][]fly.Volume, error) {
+func getUnattachedVolumes(ctx context.Context, appName, regionCode string) (map[string][]fly.Volume, error) {
 	apiclient := flyutil.ClientFromContext(ctx)
 	flapsClient := flapsutil.ClientFromContext(ctx)
 
@@ -410,7 +414,7 @@ func getUnattachedVolumes(ctx context.Context, regionCode string) (map[string][]
 		regionCode = region.Code
 	}
 
-	volumes, err := flapsClient.GetVolumes(ctx)
+	volumes, err := flapsClient.GetVolumes(ctx, appName)
 	if err != nil {
 		return nil, fmt.Errorf("Error fetching application volumes: %w", err)
 	}
