@@ -6,12 +6,11 @@ import (
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flapsutil"
-	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -32,30 +31,23 @@ secrets and another for config file defined environment variables.`
 }
 
 func runEnv(ctx context.Context) error {
-	apiClient := flyutil.ClientFromContext(ctx)
 	appName := appconfig.NameFromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
+
 	io := iostreams.FromContext(ctx)
 
-	secrets, err := apiClient.GetAppSecrets(ctx, appName)
+	secrets, err := appsecrets.List(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
 
-	secretRows := lo.Map(secrets, func(s fly.Secret, _ int) []string {
-		return []string{s.Name, s.Digest, s.CreatedAt.Format("2006-01-02T15:04:05")}
+	secretRows := lo.Map(secrets, func(s fly.AppSecret, _ int) []string {
+		return []string{s.Name, s.Digest}
 	})
-	if err := render.Table(io.Out, "Secrets", secretRows, "Name", "Digest", "Created At"); err != nil {
+	if err := render.Table(io.Out, "Secrets", secretRows, "Name", "Digest"); err != nil {
 		return err
 	}
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
-
 	cfg, err := appconfig.FromRemoteApp(ctx, appName)
 	if err != nil {
 		return err
