@@ -10,11 +10,12 @@ import (
 	"github.com/google/shlex"
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
+	"github.com/superfly/flyctl/agent"
 
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/cmdutil"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/ssh"
@@ -183,15 +184,6 @@ func runConsole(ctx context.Context) error {
 		return fmt.Errorf("failed to get app network: %w", err)
 	}
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppCompact: app,
-		AppName:    app.Name,
-	})
-	if err != nil {
-		return fmt.Errorf("failed to create flaps client: %w", err)
-	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
-
 	appConfig := appconfig.ConfigFromContext(ctx)
 	if appConfig == nil {
 		appConfig, err = appconfig.FromRemoteApp(ctx, appName)
@@ -214,7 +206,7 @@ func runConsole(ctx context.Context) error {
 		defer cleanup()
 	}
 
-	_, dialer, err := ssh.BringUpAgent(ctx, apiClient, app, *network, false)
+	_, dialer, err := agent.BringUpAgent(ctx, apiClient, app, *network, false)
 	if err != nil {
 		return err
 	}
@@ -239,14 +231,18 @@ func runConsole(ctx context.Context) error {
 		consoleCommand = flag.GetString(ctx, "command")
 	}
 
-	return ssh.Console(ctx, sshClient, consoleCommand, true, params.Container)
+	// Allocate PTY only when no command is specified or when explicitly requested
+	// This matches the behavior of `fly ssh console`
+	allocPTY := consoleCommand == "" || flag.GetBool(ctx, "pty")
+
+	return ssh.Console(ctx, sshClient, consoleCommand, allocPTY, params.Container)
 }
 
 func selectMachine(ctx context.Context, app *fly.AppCompact, appConfig *appconfig.Config) (*fly.Machine, func(), error) {
 	if flag.GetBool(ctx, "select") {
 		return promptForMachine(ctx, app, appConfig)
 	} else if flag.IsSpecified(ctx, "machine") {
-		return getMachineByID(ctx)
+		return getMachineByID(ctx, app.Name)
 	} else {
 		guest, err := determineEphemeralConsoleMachineGuest(ctx, appConfig)
 		if err != nil {
@@ -262,7 +258,7 @@ func promptForMachine(ctx context.Context, app *fly.AppCompact, appConfig *appco
 	}
 
 	flapsClient := flapsutil.ClientFromContext(ctx)
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, app.Name)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -293,7 +289,7 @@ func promptForMachine(ctx context.Context, app *fly.AppCompact, appConfig *appco
 	}
 }
 
-func getMachineByID(ctx context.Context) (*fly.Machine, func(), error) {
+func getMachineByID(ctx context.Context, appName string) (*fly.Machine, func(), error) {
 	if flag.IsSpecified(ctx, "vm-cpus") {
 		return nil, nil, errors.New("--vm-cpus can't be used with --machine")
 	}
@@ -306,7 +302,7 @@ func getMachineByID(ctx context.Context) (*fly.Machine, func(), error) {
 
 	flapsClient := flapsutil.ClientFromContext(ctx)
 	machineID := flag.GetString(ctx, "machine")
-	machine, err := flapsClient.Get(ctx, machineID)
+	machine, err := flapsClient.Get(ctx, appName, machineID)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -340,7 +336,7 @@ func makeEphemeralConsoleMachine(ctx context.Context, app *fly.AppCompact, appCo
 		return nil, nil, fmt.Errorf("failed to generate ephemeral console machine configuration: %w", err)
 	}
 
-	machConfig.Mounts, err = command.DetermineMounts(ctx, machConfig.Mounts, config.FromContext(ctx).Region)
+	machConfig.Mounts, err = command.DetermineMounts(ctx, app.Name, machConfig.Mounts, config.FromContext(ctx).Region)
 	if err != nil {
 		return nil, nil, fmt.Errorf("unable to process mounts: %w", err)
 	}
@@ -394,14 +390,20 @@ func makeEphemeralConsoleMachine(ctx context.Context, app *fly.AppCompact, appCo
 		machConfig.Guest.HostDedicationID = hdid
 	}
 
+	minvers, err := appsecrets.GetMinvers(app.Name)
+	if err != nil {
+		return nil, nil, err
+	}
+
 	input := &machine.EphemeralInput{
 		LaunchInput: fly.LaunchMachineInput{
-			Config: machConfig,
-			Region: config.FromContext(ctx).Region,
+			Config:            machConfig,
+			Region:            config.FromContext(ctx).Region,
+			MinSecretsVersion: minvers,
 		},
 		What: "to run the console",
 	}
-	return machine.LaunchEphemeral(ctx, input)
+	return machine.LaunchEphemeral(ctx, app.Name, input)
 }
 
 func determineEphemeralConsoleMachineGuest(ctx context.Context, appConfig *appconfig.Config) (*fly.MachineGuest, error) {
