@@ -16,11 +16,13 @@ import (
 	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/cmdutil"
 	"github.com/superfly/flyctl/internal/command"
+	"github.com/superfly/flyctl/internal/command/deploycontext"
+	"github.com/superfly/flyctl/internal/command/ips"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/ctrlc"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flag/validation"
 	"github.com/superfly/flyctl/internal/flapsutil"
-	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/launchdarkly"
 	"github.com/superfly/flyctl/internal/metrics"
 	"github.com/superfly/flyctl/internal/render"
@@ -53,6 +55,9 @@ var CommonFlags = flag.Set{
 	flag.Depot(),
 	flag.DepotScope(),
 	flag.Nixpacks(),
+	flag.BuildkitAddr(),
+	flag.BuildkitImage(),
+	flag.Buildkit(),
 	flag.BuildOnly(),
 	flag.BpDockerHost(),
 	flag.BpVolume(),
@@ -183,7 +188,10 @@ var CommonFlags = flag.Set{
 		Default:     "auto",
 		NoOptDefVal: "true",
 		Description: "Experimental: Use pooled builder from Fly.io",
+		Hidden:      true,
 	},
+	flag.Compression(),
+	flag.CompressionLevel(),
 }
 
 type Command struct {
@@ -204,7 +212,6 @@ func New() *Command {
 		command.RequireSession,
 		command.ChangeWorkingDirectoryToFirstArgIfPresent,
 		command.RequireAppName,
-		command.RequireUiex,
 	)
 	cmd.Args = cobra.MaximumNArgs(1)
 
@@ -269,26 +276,14 @@ func (cmd *Command) run(ctx context.Context) (err error) {
 		}
 	}()
 
-	// Instantiate FLAPS client if we haven't initialized one via a unit test.
-	if flapsutil.ClientFromContext(ctx) == nil {
-		flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-			AppName: appName,
-		})
-		if err != nil {
-			return fmt.Errorf("could not create flaps client: %w", err)
-		}
-		ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
+	if err := validation.ValidateCompressionFlag(flag.GetString(ctx, "compression")); err != nil {
+		return err
 	}
 
-	client := flyutil.ClientFromContext(ctx)
-
-	user, err := client.GetCurrentUser(ctx)
-	if err != nil {
-		return fmt.Errorf("failed retrieving current user: %w", err)
+	if err := validation.ValidateCompressionLevelFlag(flag.GetInt(ctx, "compression-level")); err != nil {
+		return err
 	}
 
-	span.SetAttributes(attribute.String("user.id", user.ID))
-
 	var manifestPath = flag.GetString(ctx, "from-manifest")
 
 	switch {
@@ -334,8 +329,8 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, userID i
 
 	io := iostreams.FromContext(ctx)
 	appName := appconfig.NameFromContext(ctx)
-	apiClient := flyutil.ClientFromContext(ctx)
-	appCompact, err := apiClient.GetAppCompact(ctx, appName)
+	flapsClient := flapsutil.ClientFromContext(ctx)
+	app, err := flapsClient.GetApp(ctx, appName)
 	if err != nil {
 		return err
 	}
@@ -343,7 +338,7 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, userID i
 	// Start the feature flag client, if we haven't already
 	if launchdarkly.ClientFromContext(ctx) == nil {
 		ffClient, err := launchdarkly.NewClient(ctx, launchdarkly.UserInfo{
-			OrganizationID: appCompact.Organization.InternalNumericID,
+			OrganizationID: fmt.Sprint(app.Organization.InternalNumericID),
 			UserID:         userID,
 		})
 		if err != nil {
@@ -364,14 +359,14 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, userID i
 	recreateBuilder := flag.GetRecreateBuilder(ctx)
 
 	// Fetch an image ref or build from source to get the final image reference to deploy
-	img, err := determineImage(ctx, appConfig, usingWireguard, recreateBuilder)
+	img, err := determineImage(ctx, app, appConfig, usingWireguard, recreateBuilder)
 	if err != nil {
 		noBuilder := strings.Contains(err.Error(), "Could not find App")
 		recreateBuilder = recreateBuilder || noBuilder
 		if noBuilder || (usingWireguard && httpFailover) {
 			span.SetAttributes(attribute.String("builder.failover_error", err.Error()))
 			span.AddEvent("using http failover")
-			img, err = determineImage(ctx, appConfig, false, recreateBuilder)
+			img, err = determineImage(ctx, app, appConfig, false, recreateBuilder)
 		}
 	}
 
@@ -383,8 +378,9 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, userID i
 		return nil
 	}
 
-	fmt.Fprintf(io.Out, "\nWatch your deployment at https://fly.io/apps/%s/monitoring\n\n", appName)
-	if err := deployToMachines(ctx, appConfig, appCompact, img); err != nil {
+	colorize := io.ColorScheme()
+	fmt.Fprintf(io.Out, "\nWatch your deployment at %s\n\n", colorize.Purple(fmt.Sprintf("https://fly.io/apps/%s/monitoring", appName)))
+	if err := deployToMachines(ctx, appConfig, app, img); err != nil {
 		return err
 	}
 	var ip = "public"
@@ -394,7 +390,75 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, userID i
 		ip = "none"
 	}
 	if appURL := appConfig.URL(); appURL != nil && ip == "public" {
-		fmt.Fprintf(io.Out, "\nVisit your newly deployed app at %s\n", appURL)
+		// Check if this is a first launch (celebratory mode) or regular deploy (simple mode)
+		isFirstLaunch, _ := ctx.Value(deploycontext.IsFirstLaunchKey).(bool)
+		colorize := io.ColorScheme()
+
+		if isFirstLaunch {
+			// First launch: Show celebratory ASCII art and borders
+			// Get terminal width for responsive borders
+			termWidth := io.TerminalWidth()
+			if termWidth > 120 {
+				termWidth = 120 // Cap at 120 for readability
+			}
+			border := strings.Repeat("═", termWidth)
+
+			// Print success box with ASCII art
+			fmt.Fprintln(io.Out)
+			fmt.Fprintln(io.Out, border)
+			fmt.Fprintln(io.Out)
+
+			// Print ASCII art with purple = characters
+			successArt := `                                                %%@
+                                               @%%@
+                                                @@
+                                                @@
+                                                @@
+                                               @@
+                      %%#**=+%%%%              @@
+                  %#+====-     =*+*%%         @@@
+               %#+======-        :+==#%       @@
+              %*========.          -+==*%    @@@
+            %#+========-             *==+%   @@@
+            #*=========.              ++=+% @@@
+           %#+========+               .*==*%@@@
+           %#=========+     ..    ..-..=*=+%@@
+           %#=========+.  :: :     ..   *=+%@
+           %#+========+:            .:  #=+#
+           %%%#+======+=             .=:*=+#
+           @@%+=======++.           :=-++=+%
+           @@%#++======+-       :--=*. #==*%
+          @@  %#*++====++:      .+#*- ++=*%
+         @@    @%#*+++++*+.          +*=*%
+        @@       @%*****+*=         +*+#%
+       @@@         @%#****#:       +*+%@
+       @@@          @@%%***%.     =**%%
+         @@@@@@@@@@@ @@@@#**% ...=##%
+                          %##*::+%%@
+                           @#%=#%@
+                           @@%%@
+                          %%#%%@
+                        %##**+#*%
+                        ##**+*#*%
+                         %%***#%@`
+
+			// Replace = with purple =
+			successArtColored := strings.ReplaceAll(successArt, "=", colorize.Purple("="))
+			fmt.Fprintln(io.Out, successArtColored)
+
+			fmt.Fprintln(io.Out)
+			fmt.Fprintf(io.Out, "%s\n", colorize.Bold("🎉  SUCCESS! Your app is live and ready to use!  🎉"))
+			fmt.Fprintln(io.Out)
+			fmt.Fprintf(io.Out, "%s %s\n", colorize.Bold("Visit:"), colorize.Bold(colorize.Purple(appURL.String())))
+			fmt.Fprintln(io.Out)
+			fmt.Fprintln(io.Out, border)
+			fmt.Fprintln(io.Out)
+		} else {
+			// Regular deploy: Simple, reliable output
+			fmt.Fprintln(io.Out)
+			fmt.Fprintf(io.Out, "Visit your newly deployed app at %s\n", colorize.Green(appURL.String()))
+			fmt.Fprintln(io.Out)
+		}
 	} else if ip == "private" {
 		fmt.Fprintf(io.Out, "\nYour your newly deployed app is available in the organizations' private network under http://%s.flycast\n", appName)
 	} else if ip == "none" {
@@ -435,7 +499,7 @@ func parseDurationFlag(ctx context.Context, flagName string) (*time.Duration, er
 func deployToMachines(
 	ctx context.Context,
 	cfg *appconfig.Config,
-	app *fly.AppCompact,
+	app *flaps.App,
 	img *imgsrc.DeploymentImage,
 ) (err error) {
 	var io = iostreams.FromContext(ctx)
@@ -556,7 +620,7 @@ func deployToMachines(
 		deployRetries = int(retries)
 
 	default:
-		var invalidRetriesErr error = fmt.Errorf("--deploy-retries must be set to a positive integer, 0, or 'auto'")
+		var invalidRetriesErr = fmt.Errorf("--deploy-retries must be set to a positive integer, 0, or 'auto'")
 		retries, err := strconv.Atoi(retriesFlag)
 		if err != nil {
 			return invalidRetriesErr
@@ -577,7 +641,7 @@ func deployToMachines(
 	}
 
 	args := MachineDeploymentArgs{
-		AppCompact:            app,
+		App:                   app,
 		DeploymentImage:       img.Tag,
 		Strategy:              flag.GetString(ctx, "strategy"),
 		EnvFromFlags:          flag.GetStringArray(ctx, "env"),
@@ -606,6 +670,7 @@ func deployToMachines(
 		ProcessGroups:         processGroups,
 		DeployRetries:         deployRetries,
 		BuildID:               img.BuildID,
+		BuilderID:             img.BuilderID,
 	}
 
 	var path = flag.GetString(ctx, "export-manifest")
@@ -630,13 +695,17 @@ func deployToMachines(
 
 	md, err := NewMachineDeployment(ctx, args)
 	if err != nil {
-		sentry.CaptureExceptionWithAppInfo(ctx, err, "deploy", app)
+		sentry.CaptureExceptionWithFlapsAppInfo(ctx, err, "deploy", app)
 		return err
 	}
 
+	// Deployments are a good time to check if the app's egress IP config makes sense
+	// Bluegreen may also require more egress IPs
+	ips.SanityCheckAppScopedEgressIps(ctx, nil, nil, nil, status.Strategy)
+
 	err = md.DeployMachinesApp(ctx)
 	if err != nil {
-		sentry.CaptureExceptionWithAppInfo(ctx, err, "deploy", app)
+		sentry.CaptureExceptionWithFlapsAppInfo(ctx, err, "deploy", app)
 	}
 	return err
 }
