@@ -4,9 +4,11 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"os"
 	"path/filepath"
 
 	"github.com/dustin/go-humanize"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/build/imgsrc"
 	"github.com/superfly/flyctl/internal/cmdutil"
@@ -18,6 +20,7 @@ import (
 	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/internal/state"
 	"github.com/superfly/flyctl/internal/tracing"
+	"github.com/superfly/flyctl/internal/uiexutil"
 	"github.com/superfly/flyctl/iostreams"
 	"github.com/superfly/flyctl/terminal"
 	"go.opentelemetry.io/otel/attribute"
@@ -49,7 +52,7 @@ func multipleDockerfile(ctx context.Context, appConfig *appconfig.Config) error
 
 // determineImage picks the deployment strategy, builds the image and returns a
 // DeploymentImage struct
-func determineImage(ctx context.Context, appConfig *appconfig.Config, useWG, recreateBuilder bool) (img *imgsrc.DeploymentImage, err error) {
+func determineImage(ctx context.Context, app *flaps.App, appConfig *appconfig.Config, useWG, recreateBuilder bool) (img *imgsrc.DeploymentImage, err error) {
 	ctx, span := tracing.GetTracer().Start(ctx, "determine_image")
 	defer span.End()
 
@@ -82,9 +85,17 @@ func determineImage(ctx context.Context, appConfig *appconfig.Config, useWG, rec
 	}
 
 	tb := render.NewTextBlock(ctx, "Building image")
-	daemonType := imgsrc.NewDockerDaemonType(!flag.GetRemoteOnly(ctx), !flag.GetLocalOnly(ctx), env.IsCI(), depotBool, flag.GetBool(ctx, "nixpacks"), useManagedBuilder)
+	daemonType := imgsrc.NewDockerDaemonType(
+		!flag.GetRemoteOnly(ctx),
+		!flag.GetLocalOnly(ctx),
+		env.IsCI(),
+		depotBool,
+		flag.GetBool(ctx, "nixpacks"),
+		useManagedBuilder,
+	)
 
 	client := flyutil.ClientFromContext(ctx)
+	uiexClient := uiexutil.ClientFromContext(ctx)
 	io := iostreams.FromContext(ctx)
 
 	span.SetAttributes(attribute.String("daemon_type", daemonType.String()))
@@ -94,7 +105,27 @@ func determineImage(ctx context.Context, appConfig *appconfig.Config, useWG, rec
 		terminal.Warnf("%s", err.Error())
 	}
 
-	resolver := imgsrc.NewResolver(daemonType, client, appConfig.AppName, io, useWG, recreateBuilder)
+	org, err := uiexClient.GetOrganization(ctx, app.Organization.Slug)
+	if err != nil {
+		return nil, err
+	}
+
+	var provisioner *imgsrc.Provisioner
+	buildkitAddr := flag.GetBuildkitAddr(ctx)
+	buildkitImage := flag.GetBuildkitImage(ctx)
+	if flag.GetBool(ctx, "buildkit") && buildkitImage == "" && buildkitAddr == "" {
+		buildkitImage = imgsrc.DefaultBuildkitImage
+	}
+	if buildkitAddr != "" || buildkitImage != "" {
+		provisioner = imgsrc.NewBuildkitProvisioner(org, buildkitAddr, buildkitImage)
+	} else {
+		provisioner = imgsrc.NewProvisionerUiexOrg(org)
+	}
+	resolver := imgsrc.NewResolver(
+		daemonType, client, appConfig.AppName, io,
+		useWG, recreateBuilder,
+		imgsrc.WithProvisioner(provisioner),
+	)
 
 	var imageRef string
 	if imageRef, err = fetchImageRef(ctx, appConfig); err != nil {
@@ -107,7 +138,7 @@ func determineImage(ctx context.Context, appConfig *appconfig.Config, useWG, rec
 		opts := imgsrc.RefOptions{
 			AppName:    appConfig.AppName,
 			WorkingDir: state.WorkingDirectory(ctx),
-			Publish:    !flag.GetBuildOnly(ctx),
+			Publish:    flag.GetBool(ctx, "push") || !flag.GetBuildOnly(ctx),
 			ImageRef:   imageRef,
 			ImageLabel: flag.GetString(ctx, "image-label"),
 		}
@@ -116,7 +147,16 @@ func determineImage(ctx context.Context, appConfig *appconfig.Config, useWG, rec
 		img, err = resolver.ResolveReference(ctx, io, opts)
 		if err != nil {
 			tracing.RecordError(span, err, "failed to resolve reference for prebuilt docker image")
-			return
+			if trigger := os.Getenv("DEPLOY_TRIGGER"); trigger == "" {
+				return
+			} else {
+				img = &imgsrc.DeploymentImage{
+					ID:  imageRef,
+					Tag: imageRef,
+				}
+				terminal.Debugf("Failed to resolve reference for prebuilt docker image, using imageRef %s: %v\n", img.String(), err)
+				err = nil
+			}
 		}
 
 		span.AddEvent("using pre-built docker image")
@@ -147,10 +187,11 @@ func determineImage(ctx context.Context, appConfig *appconfig.Config, useWG, rec
 
 	if appConfig.Experimental != nil {
 		opts.UseOverlaybd = appConfig.Experimental.LazyLoadImages
-
-		opts.UseZstd = appConfig.Experimental.UseZstd
 	}
 
+	// Determine compression based on CLI flags, then app config, then LaunchDarkly, then default to gzip
+	opts.Compression, opts.CompressionLevel = appConfig.DetermineCompression(ctx)
+
 	// flyctl supports key=value form while Docker supports id=key,src=/path/to/secret form.
 	// https://docs.docker.com/engine/reference/commandline/buildx_build/#secret
 	cliBuildSecrets, err := cmdutil.ParseKVStringsToMap(flag.GetStringArray(ctx, "build-secret"))
