@@ -7,6 +7,7 @@ import (
 	"github.com/docker/go-units"
 	"github.com/samber/lo"
 	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/prompt"
 )
@@ -31,14 +32,16 @@ func (md *machineDeployment) provisionIpsOnFirstDeploy(ctx context.Context, ipTy
 	}
 
 	// Do not touch IPs if there are already allocated
-	ipAddrs, err := md.apiClient.GetIPAddresses(ctx, md.app.Name)
+	ipRes, err := md.flapsClient.GetIPAssignments(ctx, md.app.Name)
 	if err != nil {
 		return fmt.Errorf("error detecting ip addresses allocated to %s app: %w", md.app.Name, err)
 	}
-	if len(ipAddrs) > 0 {
+	if len(ipRes.IPs) > 0 {
 		return nil
 	}
 
+	region, network := "", ""
+
 	switch md.appConfig.DetermineIPType(ipType) {
 	case "dedicated":
 		hasUdpService := md.appConfig.HasUdpService()
@@ -50,43 +53,68 @@ func (md *machineDeployment) provisionIpsOnFirstDeploy(ctx context.Context, ipTy
 
 		confirmDedicatedIp, err := prompt.Confirmf(ctx, "Would you like to allocate %s now?", ipStuffStr)
 		if confirmDedicatedIp && err == nil {
-			v4Dedicated, err := md.apiClient.AllocateIPAddress(ctx, md.app.Name, "v4", "", nil, "")
+			v4Dedicated, err := md.flapsClient.AssignIP(ctx, md.app.Name, flaps.AssignIPRequest{
+				Type:         "v4",
+				Region:       region,
+				Organization: org,
+				Network:      network,
+			})
 			if err != nil {
 				return err
 			}
-			fmt.Fprintf(md.io.Out, "Allocated dedicated ipv4: %s\n", v4Dedicated.Address)
+			fmt.Fprintf(md.io.Out, "Allocated dedicated ipv4: %s\n", v4Dedicated.IP)
 
 			if !hasUdpService {
-				v6Dedicated, err := md.apiClient.AllocateIPAddress(ctx, md.app.Name, "v6", "", nil, "")
+				v6Dedicated, err := md.flapsClient.AssignIP(ctx, md.app.Name, flaps.AssignIPRequest{
+					Type:         "v6",
+					Region:       region,
+					Organization: org,
+					Network:      network,
+				})
 				if err != nil {
 					return err
 				}
-				fmt.Fprintf(md.io.Out, "Allocated dedicated ipv6: %s\n", v6Dedicated.Address)
+				fmt.Fprintf(md.io.Out, "Allocated dedicated ipv6: %s\n", v6Dedicated.IP)
 			}
 		}
 
 	case "shared":
 		fmt.Fprintf(md.io.Out, "Provisioning ips for %s\n", md.colorize.Bold(md.app.Name))
-		v6Addr, err := md.apiClient.AllocateIPAddress(ctx, md.app.Name, "v6", "", nil, "")
+		v6Addr, err := md.flapsClient.AssignIP(ctx, md.app.Name, flaps.AssignIPRequest{
+			Type:         "v6",
+			Region:       region,
+			Organization: org,
+			Network:      network,
+		})
 		if err != nil {
 			return fmt.Errorf("error allocating ipv6 after detecting first deploy and presence of services: %w", err)
 		}
-		fmt.Fprintf(md.io.Out, "  Dedicated ipv6: %s\n", v6Addr.Address)
+		fmt.Fprintf(md.io.Out, "  Dedicated ipv6: %s\n", md.colorize.Purple(v6Addr.IP))
 
-		v4Shared, err := md.apiClient.AllocateSharedIPAddress(ctx, md.app.Name)
+		v4Shared, err := md.flapsClient.AssignIP(ctx, md.app.Name, flaps.AssignIPRequest{
+			Type:         "shared_v4",
+			Region:       region,
+			Organization: org,
+			Network:      network,
+		})
 		if err != nil {
 			return fmt.Errorf("error allocating shared ipv4 after detecting first deploy and presence of services: %w", err)
 		}
-		fmt.Fprintf(md.io.Out, "  Shared ipv4: %s\n", v4Shared)
-		fmt.Fprintf(md.io.Out, "  Add a dedicated ipv4 with: fly ips allocate-v4\n")
+		fmt.Fprintf(md.io.Out, "  Shared ipv4: %s\n", md.colorize.Purple(v4Shared.IP))
+		fmt.Fprintf(md.io.Out, "  Add a dedicated ipv4 with: %s\n", md.colorize.Purple("fly ips allocate-v4"))
 
 	case "private":
 		fmt.Fprintf(md.io.Out, "Provisioning ip address for %s\n", md.colorize.Bold(md.app.Name))
-		v6Addr, err := md.apiClient.AllocateIPAddress(ctx, md.app.Name, "private_v6", org, nil, "")
+		v6Addr, err := md.flapsClient.AssignIP(ctx, md.app.Name, flaps.AssignIPRequest{
+			Type:         "private_v6",
+			Region:       region,
+			Organization: org,
+			Network:      network,
+		})
 		if err != nil {
 			return fmt.Errorf("error allocating ipv6 after detecting first deploy and presence of services: %w", err)
 		}
-		fmt.Fprintf(md.io.Out, "  Private ipv6: %s\n", v6Addr.Address)
+		fmt.Fprintf(md.io.Out, "  Private ipv6: %s\n", v6Addr.IP)
 	}
 
 	fmt.Fprintln(md.io.Out)
@@ -154,9 +182,10 @@ func (md *machineDeployment) provisionVolumesOnFirstDeploy(ctx context.Context)
 				ComputeRequirements: guest,
 				ComputeImage:        md.img,
 				SnapshotRetention:   m.SnapshotRetention,
+				AutoBackupEnabled:   m.ScheduledSnapshots,
 			}
 
-			vol, err := md.flapsClient.CreateVolume(ctx, input)
+			vol, err := md.flapsClient.CreateVolume(ctx, md.app.Name, input)
 			if err != nil {
 				return err
 			}
