@@ -2,6 +2,7 @@ package deploy
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"time"
 
@@ -9,6 +10,7 @@ import (
 	"github.com/samber/lo"
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/internal/statuslogger"
 	"github.com/superfly/flyctl/internal/tracing"
@@ -93,7 +95,7 @@ func (md *machineDeployment) runTestMachines(ctx context.Context, machineToTest
 		return err
 	}
 
-	machineSet := machine.NewMachineSet(flaps, io, lo.FilterMap(machines, func(m createdTestMachine, _ int) (*fly.Machine, bool) {
+	machineSet := machine.NewMachineSet(flaps, io, md.app.Name, lo.FilterMap(machines, func(m createdTestMachine, _ int) (*fly.Machine, bool) {
 		if m.err != nil {
 			tracing.RecordError(span, m.err, "failed to create test machine")
 			sl.LogStatus(statuslogger.StatusFailure, fmt.Sprintf("failed to create test machine: %s", m.err))
@@ -147,7 +149,7 @@ func (md *machineDeployment) runTestMachines(ctx context.Context, machineToTest
 	return nil
 }
 
-const ErrNoLogsFound = "no logs found"
+var errNoLogsFound = errors.New("no logs found")
 
 func (md *machineDeployment) waitForLogs(ctx context.Context, mach *fly.Machine, timeout time.Duration) error {
 	b := backoff.NewExponentialBackOff()
@@ -160,7 +162,7 @@ func (md *machineDeployment) waitForLogs(ctx context.Context, mach *fly.Machine,
 			return nil, err
 		}
 		if len(logs) == 0 {
-			return nil, fmt.Errorf(ErrNoLogsFound)
+			return nil, errNoLogsFound
 		}
 
 		return logs, nil
@@ -176,7 +178,7 @@ func (md *machineDeployment) createTestMachine(ctx context.Context, svc *appconf
 	if err != nil {
 		return nil, err
 	}
-	testMachine, err := md.flapsClient.Launch(ctx, *launchInput)
+	testMachine, err := md.flapsClient.Launch(ctx, md.app.Name, *launchInput)
 	if err != nil {
 		tracing.RecordError(span, err, "failed to create test machines")
 		return nil, fmt.Errorf("error creating a test machine: %w", err)
@@ -206,9 +208,14 @@ func (md *machineDeployment) launchInputForTestMachine(svc *appconfig.ServiceMac
 		mConfig.Guest.HostDedicationID = hdid
 	}
 
+	minvers, err := appsecrets.GetMinvers(md.appConfig.AppName)
+	if err != nil {
+		return nil, err
+	}
 	return &fly.LaunchMachineInput{
-		Config: mConfig,
-		Region: origMachineRaw.Region,
+		Config:            mConfig,
+		Region:            origMachineRaw.Region,
+		MinSecretsVersion: minvers,
 	}, nil
 }
 
@@ -237,7 +244,7 @@ func (md *machineDeployment) waitForTestMachinesToFinish(ctx context.Context, te
 
 	machs := lo.FilterMap(testMachines.GetMachines(), func(lm machine.LeasableMachine, _ int) (*fly.Machine, bool) {
 		mach := lm.Machine()
-		m, err := md.flapsClient.Get(ctx, mach.ID)
+		m, err := md.flapsClient.Get(ctx, md.app.Name, mach.ID)
 		return m, err == nil
 	})
 	for _, mach := range machs {
