@@ -4,6 +4,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"maps"
 	"slices"
 	"strings"
 	"sync"
@@ -22,12 +23,14 @@ import (
 	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/machine"
+	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/internal/tracing"
+	"github.com/superfly/flyctl/internal/uiex"
+	"github.com/superfly/flyctl/internal/uiexutil"
 	"github.com/superfly/flyctl/iostreams"
 	"github.com/superfly/flyctl/terminal"
 	"go.opentelemetry.io/otel/attribute"
 	"go.opentelemetry.io/otel/trace"
-	"golang.org/x/exp/maps"
 )
 
 const (
@@ -44,7 +47,7 @@ type MachineDeployment interface {
 }
 
 type MachineDeploymentArgs struct {
-	AppCompact            *fly.AppCompact
+	App                   *flaps.App
 	DeploymentImage       string
 	Strategy              string
 	EnvFromFlags          []string
@@ -75,12 +78,13 @@ type MachineDeploymentArgs struct {
 	RestartPolicy         *fly.MachineRestartPolicy
 	RestartMaxRetries     int
 	DeployRetries         int
-	BuildID               string
+	BuildID               int64
+	BuilderID             string
 }
 
-func argsFromManifest(manifest *DeployManifest, app *fly.AppCompact) MachineDeploymentArgs {
+func argsFromManifest(manifest *DeployManifest, app *flaps.App) MachineDeploymentArgs {
 	return MachineDeploymentArgs{
-		AppCompact:            app,
+		App:                   app,
 		DeploymentImage:       manifest.DeploymentImage,
 		Strategy:              manifest.Strategy,
 		EnvFromFlags:          manifest.EnvFromFlags,
@@ -113,15 +117,17 @@ func argsFromManifest(manifest *DeployManifest, app *fly.AppCompact) MachineDepl
 }
 
 type machineDeployment struct {
-	// apiClient is a client to use web.
+	// apiClient is a client to use web GraphQL.
 	apiClient webClient
 	// flapsClient is a client to use flaps.
 	flapsClient flapsutil.FlapsClient
-	io          *iostreams.IOStreams
-	colorize    *iostreams.ColorScheme
-	app         *fly.AppCompact
-	appConfig   *appconfig.Config
-	img         string
+	// uiexClient is a client to use api.fly.io, which is implemented by both ui-ex and web.
+	uiexClient uiexutil.Client
+	io         *iostreams.IOStreams
+	colorize   *iostreams.ColorScheme
+	app        *flaps.App
+	appConfig  *appconfig.Config
+	img        string
 	// machineSet is this application's machines.
 	machineSet            machine.MachineSet
 	releaseCommandMachine machine.MachineSet
@@ -154,7 +160,8 @@ type machineDeployment struct {
 	volumeInitialSize     int
 	tigrisStatics         *statics.DeployerState
 	deployRetries         int
-	buildID               string
+	buildID               int64
+	builderID             string
 }
 
 func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (_ MachineDeployment, err error) {
@@ -182,21 +189,11 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (_ Ma
 		return nil, err
 	}
 
-	if args.AppCompact == nil {
-		return nil, fmt.Errorf("BUG: args.AppCompact should be set when calling this method")
+	if args.App == nil {
+		return nil, fmt.Errorf("BUG: args.App should be set when calling this method")
 	}
 
 	flapsClient := flapsutil.ClientFromContext(ctx)
-	if flapsClient == nil {
-		flapsClient, err = flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-			AppCompact: args.AppCompact,
-			AppName:    args.AppCompact.Name,
-		})
-		if err != nil {
-			tracing.RecordError(span, err, "failed to init flaps client")
-			return nil, err
-		}
-	}
 
 	if appConfig.Deploy != nil && appConfig.Deploy.ReleaseCommand != "" {
 		_, err = shlex.Split(appConfig.Deploy.ReleaseCommand)
@@ -240,6 +237,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (_ Ma
 	}
 
 	apiClient := flyutil.ClientFromContext(ctx)
+	uiexClient := uiexutil.ClientFromContext(ctx)
 
 	maxUnavailable := DefaultMaxUnavailable
 	if appConfig.Deploy != nil && appConfig.Deploy.MaxUnavailable != nil {
@@ -254,9 +252,10 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (_ Ma
 	md := &machineDeployment{
 		apiClient:             apiClient,
 		flapsClient:           flapsClient,
+		uiexClient:            uiexClient,
 		io:                    io,
 		colorize:              io.ColorScheme(),
-		app:                   args.AppCompact,
+		app:                   args.App,
 		appConfig:             appConfig,
 		img:                   args.DeploymentImage,
 		skipSmokeChecks:       args.SkipSmokeChecks,
@@ -282,6 +281,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (_ Ma
 		processGroups:         args.ProcessGroups,
 		deployRetries:         args.DeployRetries,
 		buildID:               args.BuildID,
+		builderID:             args.BuilderID,
 	}
 	if err := md.setStrategy(); err != nil {
 		tracing.RecordError(span, err, "failed to set strategy")
@@ -312,7 +312,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (_ Ma
 	}
 
 	// validations must happen after every else
-	if err := md.validateVolumeConfig(); err != nil {
+	if err := md.validateVolumeConfig(ctx); err != nil {
 		tracing.RecordError(span, err, "failed to validate volume config")
 		return nil, err
 	}
@@ -330,7 +330,7 @@ func (md *machineDeployment) setFirstDeploy(_ context.Context) error {
 	// by checking for any existent machine.
 	// This is not exaustive as the app could still be scaled down to zero but the
 	// workaround works better for now until it is fixed
-	md.isFirstDeploy = md.isFirstDeploy || (!md.app.Deployed && md.machineSet.IsEmpty())
+	md.isFirstDeploy = md.isFirstDeploy || (!md.app.Deployed() && md.machineSet.IsEmpty())
 	return nil
 }
 
@@ -338,7 +338,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 	ctx, span := tracing.GetTracer().Start(ctx, "set_machines_for_deployment")
 	defer span.End()
 
-	machines, releaseCmdMachine, err := md.flapsClient.ListFlyAppsMachines(ctx)
+	machines, releaseCmdMachine, err := md.flapsClient.ListFlyAppsMachines(ctx, md.app.Name)
 	if err != nil {
 		tracing.RecordError(span, err, "failed to list machines")
 		return err
@@ -347,7 +347,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 	nMachines := len(machines)
 	if nMachines == 0 {
 		terminal.Debug("Found no machines that are part of Fly Apps Platform. Checking for active machines...")
-		activeMachines, err := md.flapsClient.ListActive(ctx)
+		activeMachines, err := md.flapsClient.ListActive(ctx, md.app.Name)
 		if err != nil {
 			tracing.RecordError(span, err, "failed to list machines")
 			return err
@@ -409,7 +409,7 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 			s = "s"
 		}
 
-		filtersAppliedStr := strings.Join(maps.Keys(filtersApplied), "/")
+		filtersAppliedStr := strings.Join(slices.Collect(maps.Keys(filtersApplied)), "/")
 
 		fmt.Fprintf(md.io.ErrOut, "%s filter%s applied, deploying to %d/%d machines\n", filtersAppliedStr, s, len(machines), nMachines)
 	}
@@ -420,15 +420,18 @@ func (md *machineDeployment) setMachinesForDeployment(ctx context.Context) error
 			if m.Config.Metadata[fly.MachineConfigMetadataKeyFlyProcessGroup] == "" {
 				m.Config.Metadata[fly.MachineConfigMetadataKeyFlyProcessGroup] = md.appConfig.DefaultProcessName()
 			}
+			if md.builderID != "" {
+				m.Config.Metadata["fly_builder_id"] = md.builderID
+			}
 		}
 	}
 
-	md.machineSet = machine.NewMachineSet(md.flapsClient, md.io, machines, true)
+	md.machineSet = machine.NewMachineSet(md.flapsClient, md.io, md.app.Name, machines, true)
 	var releaseCmdSet []*fly.Machine
 	if releaseCmdMachine != nil {
 		releaseCmdSet = []*fly.Machine{releaseCmdMachine}
 	}
-	md.releaseCommandMachine = machine.NewMachineSet(md.flapsClient, md.io, releaseCmdSet, true)
+	md.releaseCommandMachine = machine.NewMachineSet(md.flapsClient, md.io, md.app.Name, releaseCmdSet, true)
 	return nil
 }
 
@@ -437,7 +440,7 @@ func (md *machineDeployment) setVolumes(ctx context.Context) error {
 		return nil
 	}
 
-	volumes, err := md.flapsClient.GetVolumes(ctx)
+	volumes, err := md.flapsClient.GetVolumes(ctx, md.app.Name)
 	if err != nil {
 		return fmt.Errorf("Error fetching application volumes: %w", err)
 	}
@@ -463,7 +466,7 @@ func (md *machineDeployment) popVolumeFor(name, region string) *fly.Volume {
 	return nil
 }
 
-func (md *machineDeployment) validateVolumeConfig() error {
+func (md *machineDeployment) validateVolumeConfig(ctx context.Context) error {
 	machineGroups := lo.GroupBy(
 		lo.Map(md.machineSet.GetMachines(), func(lm machine.LeasableMachine, _ int) *fly.Machine {
 			return lm.Machine()
@@ -492,13 +495,23 @@ func (md *machineDeployment) validateVolumeConfig() error {
 			for _, m := range ms {
 				mConfig := m.GetConfig()
 				if mntDst == "" && len(mConfig.Mounts) != 0 {
-					// TODO: Detaching a volume from a machine is possible, but it usually means a missconfiguration.
-					// We should show a warning and ask the user for confirmation and let it happen instead of failing here.
-					return fmt.Errorf(
-						"machine %s [%s] has a volume mounted but app config does not specify a volume; "+
-							"remove the volume from the machine or add a [mounts] section to fly.toml",
-						m.ID, groupName,
-					)
+					msg := fmt.Sprintf("Warning! machine %s [%s] has a volume mounted but app config does not specify a volume.\nThis usually indicates a misconfiguration.", m.ID, groupName)
+					fmt.Fprintln(md.io.ErrOut, md.colorize.Red(msg))
+
+					switch confirmed, err := prompt.Confirm(ctx, "Do you still want to continue and detach the volume? This will replace the machine."); {
+					case err == nil:
+						if !confirmed {
+							return fmt.Errorf(
+								"deployment cancelled: machine %s [%s] has a volume mounted but app config does not specify a volume; "+
+									"remove the volume from the machine or add a [mounts] section to fly.toml",
+								m.ID, groupName,
+							)
+						}
+					case prompt.IsNonInteractive(err):
+						return prompt.NonInteractiveError("yes flag must be specified when not running interactively")
+					default:
+						return err
+					}
 				}
 
 				if mntDst != "" && len(mConfig.Mounts) == 0 {
@@ -582,20 +595,19 @@ func (md *machineDeployment) createReleaseInBackend(ctx context.Context) error {
 	ctx, span := tracing.GetTracer().Start(ctx, "create_backend_release")
 	defer span.End()
 
-	resp, err := md.apiClient.CreateRelease(ctx, fly.CreateReleaseInput{
-		AppId:           md.app.Name,
-		PlatformVersion: "machines",
-		Strategy:        fly.DeploymentStrategy(strings.ToUpper(md.strategy)),
-		Definition:      md.appConfig,
-		Image:           md.img,
-		BuildId:         md.buildID,
+	resp, err := md.uiexClient.CreateRelease(ctx, uiex.CreateReleaseRequest{
+		AppName:    md.app.Name,
+		Strategy:   uiex.DeploymentStrategy(strings.ToUpper(md.strategy)),
+		Definition: md.appConfig,
+		Image:      md.img,
+		BuildId:    md.buildID,
 	})
 	if err != nil {
 		tracing.RecordError(span, err, "failed to create machine release")
 		return err
 	}
-	md.releaseId = resp.CreateRelease.Release.Id
-	md.releaseVersion = resp.CreateRelease.Release.Version
+	md.releaseId = resp.ID
+	md.releaseVersion = resp.Version
 	return nil
 }
 
@@ -606,13 +618,7 @@ func (md *machineDeployment) updateReleaseInBackend(ctx context.Context, status
 	))
 	defer span.End()
 
-	input := fly.UpdateReleaseInput{
-		ReleaseId: md.releaseId,
-		Status:    status,
-		Metadata:  metadata,
-	}
-
-	_, err := md.apiClient.UpdateRelease(ctx, input)
+	_, err := md.uiexClient.UpdateRelease(ctx, md.releaseId, status, metadata)
 
 	if err != nil {
 		tracing.RecordError(span, err, "failed to update machine release")
