@@ -5,6 +5,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"maps"
 	"math"
 	"net"
 	"slices"
@@ -24,7 +25,6 @@ import (
 	machcmd "github.com/superfly/flyctl/internal/command/machine"
 	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/flyerr"
-	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/internal/statuslogger"
 	"github.com/superfly/flyctl/internal/tracing"
@@ -32,7 +32,6 @@ import (
 	"github.com/superfly/flyctl/terminal"
 	"go.opentelemetry.io/otel/attribute"
 	"go.opentelemetry.io/otel/trace"
-	"golang.org/x/exp/maps"
 	"golang.org/x/sync/errgroup"
 )
 
@@ -46,8 +45,6 @@ func (md *machineDeployment) DeployMachinesApp(ctx context.Context) error {
 	ctx, span := tracing.GetTracer().Start(ctx, "deploy_machines")
 	defer span.End()
 
-	ctx = flapsutil.NewContextWithClient(ctx, md.flapsClient)
-
 	onInterruptContext := context.WithoutCancel(ctx)
 
 	// TODO(allison): Ensure that if we *aren't* using tigris here, we remove the previously attached bucket from
@@ -110,7 +107,9 @@ func (md *machineDeployment) DeployMachinesApp(ctx context.Context) error {
 
 	if updateErr := md.updateReleaseInBackend(ctx, status, metadata); updateErr != nil {
 		if err == nil {
-			err = fmt.Errorf("failed to set final release status: %w", updateErr)
+			// Deployment succeeded, but we couldn't update the release status
+			// This is not critical enough to fail the entire deployment
+			terminal.Warnf("failed to set final release status after successful deployment: %v\n", updateErr)
 		} else {
 			terminal.Warnf("failed to set final release status after deployment failure: %v\n", updateErr)
 		}
@@ -190,7 +189,7 @@ func (md *machineDeployment) waitForMachine(ctx context.Context, e *machineUpdat
 	}
 
 	if !md.skipHealthChecks {
-		if err := lm.WaitForState(ctx, fly.MachineStateStarted, md.waitTimeout, false); err != nil {
+		if err := lm.WaitForState(ctx, fly.MachineStateStarted, md.waitTimeout, machine.WithJustCreated()); err != nil {
 			err = suggestChangeWaitTimeout(err, "wait-timeout")
 			return err
 		}
@@ -222,9 +221,18 @@ func (md *machineDeployment) restartMachinesApp(ctx context.Context) error {
 	ctx, span := tracing.GetTracer().Start(ctx, "restart_machines")
 	defer span.End()
 
+	var jerr error
 	machineUpdateEntries := lo.Map(md.machineSet.GetMachines(), func(lm machine.LeasableMachine, _ int) *machineUpdateEntry {
-		return &machineUpdateEntry{leasableMachine: lm, launchInput: md.launchInputForRestart(lm.Machine())}
+		launchInput, err := md.launchInputForRestart(lm.Machine())
+		if err != nil {
+			jerr = errors.Join(jerr, err)
+			return nil
+		}
+		return &machineUpdateEntry{leasableMachine: lm, launchInput: launchInput}
 	})
+	if jerr != nil {
+		return jerr
+	}
 
 	return md.updateExistingMachines(ctx, machineUpdateEntries)
 }
@@ -289,7 +297,7 @@ func (md *machineDeployment) deployCanaryMachines(ctx context.Context) (err erro
 
 			defer func() {
 				if err == nil {
-					if destroyErr := machcmd.Destroy(ctx, md.app, lm.Machine(), true); destroyErr != nil {
+					if destroyErr := machcmd.Destroy(ctx, md.app.Name, lm.Machine(), true); destroyErr != nil {
 						err = destroyErr
 					}
 				}
@@ -317,7 +325,7 @@ func (md *machineDeployment) deployCanaryMachines(ctx context.Context) (err erro
 func (md *machineDeployment) deployCreateMachinesForGroups(ctx context.Context, processGroupMachineDiff ProcessGroupsDiff) (err error) {
 	groupsWithAutostopEnabled := make(map[string]bool)
 	groupsWithAutosuspendEnabled := make(map[string]bool)
-	groups := maps.Keys(processGroupMachineDiff.groupsNeedingMachines)
+	groups := slices.Collect(maps.Keys(processGroupMachineDiff.groupsNeedingMachines))
 	total := len(groups)
 	slices.Sort(groups)
 
@@ -375,7 +383,8 @@ func (md *machineDeployment) deployCreateMachinesForGroups(ctx context.Context,
 		case len(groupConfig.Mounts) > 0:
 			continue
 		case len(services) > 0:
-			fmt.Fprintf(md.io.Out, "Creating a second machine to increase service availability\n")
+			fmt.Fprintf(md.io.Out, "Creating a second machine for high availability and zero downtime deployments.\n")
+			fmt.Fprintf(md.io.Out, "To disable this, set %s in your fly.toml.\n", md.colorize.Purple("\"min_machines_running = 0\""))
 			if _, err := md.spawnMachineInGroup(ctx, name, nil); err != nil {
 				statuslogger.Failed(ctx, err)
 				return err
@@ -398,18 +407,16 @@ func (md *machineDeployment) deployCreateMachinesForGroups(ctx context.Context,
 		groupNames := lo.Keys(groupsWithAutostopEnabled)
 		slices.Sort(groupNames)
 		fmt.Fprintf(md.io.Out,
-			"\n%s The machines for [%s] have services with 'auto_stop_machines = \"stop\"' that will be stopped when idling\n\n",
-			md.colorize.Yellow("NOTE:"),
-			md.colorize.Bold(strings.Join(groupNames, ",")),
+			"\n\n%s\n\n",
+			md.colorize.Yellow(fmt.Sprintf("NOTE: The machines for [%s] have services with 'auto_stop_machines = \"stop\"' that will be stopped when idling", strings.Join(groupNames, ","))),
 		)
 	}
 	if len(groupsWithAutosuspendEnabled) > 0 {
 		groupNames := lo.Keys(groupsWithAutosuspendEnabled)
 		slices.Sort(groupNames)
 		fmt.Fprintf(md.io.Out,
-			"\n%s The machines for [%s] have services with 'auto_stop_machines = \"suspend\"' that will be suspended when idling\n\n",
-			md.colorize.Yellow("NOTE:"),
-			md.colorize.Bold(strings.Join(groupNames, ",")),
+			"\n\n%s\n\n",
+			md.colorize.Yellow(fmt.Sprintf("NOTE: The machines for [%s] have services with 'auto_stop_machines = \"suspend\"' that will be suspended when idling", strings.Join(groupNames, ","))),
 		)
 	}
 	return nil
@@ -444,7 +451,7 @@ func (md *machineDeployment) deployMachinesApp(ctx context.Context) error {
 		return err
 	}
 	for _, mach := range processGroupMachineDiff.machinesToRemove {
-		if err := machcmd.Destroy(ctx, md.app, mach.Machine(), true); err != nil {
+		if err := machcmd.Destroy(ctx, md.app.Name, mach.Machine(), true); err != nil {
 			return err
 		}
 	}
@@ -521,7 +528,8 @@ func suggestChangeWaitTimeout(err error, flagName string) error {
 			if timeoutErr.DesiredState() == fly.MachineStateStarted {
 				// If we timed out waiting for a machine to start, we want to suggest that there could be a region issue preventing
 				// the machine from finishing its state transition. (e.g. slow image pulls, volume trouble, etc.)
-				descript = "Your machine was created, but never started. This could mean that your app is taking a long time to start,\nbut it could be indicative of a region issue."
+				// We also suggest checking the Dockerfile since an immediate exit can appear as a timeout.
+				descript = "Your machine was created, but never started or exited immediately. This could mean that your app is taking a long time to start,\nbut it could be indicative of a region issue.\n\nAlternatively, your app may have exited immediately due to a startup failure. Check your Dockerfile\nto ensure it specifies a valid start command (e.g., check that your 'CMD' or 'ENTRYPOINT' is correct).\nYou can also try running 'fly logs' to see what happened when the machine tried to start."
 				suggest = fmt.Sprintf("You can try deploying to a different region,\nor you can try %s", suggestIncreaseTimeout)
 			} else {
 				// If we timed out waiting for a different state, we want to suggest that the timeout could be too short.
@@ -983,12 +991,12 @@ func (md *machineDeployment) updateMachineByReplace(ctx context.Context, e *mach
 	// while we wait for its state and/or health checks
 	e.launchInput.LeaseTTL = int(md.waitTimeout.Seconds())
 
-	newMachineRaw, err := md.flapsClient.Launch(ctx, *e.launchInput)
+	newMachineRaw, err := md.flapsClient.Launch(ctx, md.app.Name, *e.launchInput)
 	if err != nil {
 		return err
 	}
 
-	lm = machine.NewLeasableMachine(md.flapsClient, md.io, newMachineRaw, false)
+	lm = machine.NewLeasableMachine(md.flapsClient, md.io, md.app.Name, newMachineRaw, false)
 	defer releaseLease(ctx, lm)
 	e.leasableMachine = lm
 	return nil
@@ -1056,7 +1064,7 @@ func (md *machineDeployment) spawnMachineInGroup(ctx context.Context, groupName
 	// while we wait for its state and/or health checks
 	launchInput.LeaseTTL = int(md.waitTimeout.Seconds())
 
-	newMachineRaw, err := md.flapsClient.Launch(ctx, *launchInput)
+	newMachineRaw, err := md.flapsClient.Launch(ctx, md.app.Name, *launchInput)
 	if err != nil {
 		relCmdWarning := ""
 		if strings.Contains(err.Error(), "please add a payment method") && !md.releaseCommandMachine.IsEmpty() {
@@ -1065,7 +1073,7 @@ func (md *machineDeployment) spawnMachineInGroup(ctx context.Context, groupName
 		return nil, fmt.Errorf("error creating a new machine: %w%s", err, relCmdWarning)
 	}
 
-	lm := machine.NewLeasableMachine(md.flapsClient, md.io, newMachineRaw, false)
+	lm := machine.NewLeasableMachine(md.flapsClient, md.io, md.app.Name, newMachineRaw, false)
 	statuslogger.Logf(ctx, "Machine %s was created", md.colorize.Bold(lm.FormattedMachineId()))
 	defer releaseLease(ctx, lm)
 
@@ -1087,7 +1095,7 @@ func (md *machineDeployment) spawnMachineInGroup(ctx context.Context, groupName
 	// And wait (or not) for successful health checks
 	if !md.skipHealthChecks {
 		// Don't wait for state if the --detach flag isn't specified
-		if err := lm.WaitForState(ctx, fly.MachineStateStarted, md.waitTimeout, false); err != nil {
+		if err := lm.WaitForState(ctx, fly.MachineStateStarted, md.waitTimeout, machine.WithJustCreated()); err != nil {
 			err = suggestChangeWaitTimeout(err, "wait-timeout")
 			return nil, err
 		}
@@ -1202,7 +1210,7 @@ func (md *machineDeployment) warnAboutIncorrectListenAddress(ctx context.Context
 		}
 	}
 
-	processes, err := md.flapsClient.GetProcesses(ctx, lm.Machine().ID)
+	processes, err := md.flapsClient.GetProcesses(ctx, md.app.Name, lm.Machine().ID)
 	// Let's not fail the whole deployment because of this, as listen address check is just a warning
 	if err != nil {
 		return
@@ -1344,12 +1352,13 @@ func (md *machineDeployment) checkDNS(ctx context.Context) error {
 	ctx, cancel := context.WithTimeout(ctx, time.Second*70)
 	defer cancel()
 
-	client := flyutil.ClientFromContext(ctx)
-	ipAddrs, err := client.GetIPAddresses(ctx, md.appConfig.AppName)
+	flapsClient := flapsutil.ClientFromContext(ctx)
+	ipRes, err := flapsClient.GetIPAssignments(ctx, md.appConfig.AppName)
 	if err != nil {
 		tracing.RecordError(span, err, "failed to get ip addresses")
 		return err
 	}
+	ipAddrs := ipRes.IPs
 
 	if appURL := md.appConfig.URL(); appURL != nil && len(ipAddrs) > 0 {
 		iostreams := iostreams.FromContext(ctx)
@@ -1373,9 +1382,9 @@ func (md *machineDeployment) checkDNS(ctx context.Context) error {
 
 			var numIPv4, numIPv6 int
 			for _, ipAddr := range ipAddrs {
-				if ipAddr.Type == "v4" || ipAddr.Type == "shared_v4" {
+				if strings.Contains(ipAddr.IP, ".") && (ipAddr.Region == "global" || ipAddr.Shared) {
 					numIPv4 += 1
-				} else if ipAddr.Type == "v6" {
+				} else if strings.Contains(ipAddr.IP, ":") && ipAddr.Region == "global" {
 					numIPv6 += 1
 				}
 			}
@@ -1409,6 +1418,14 @@ func (md *machineDeployment) checkDNS(ctx context.Context) error {
 
 			return nil, nil
 		}, backoff.WithBackOff(b), backoff.WithMaxElapsedTime(60*time.Second))
+
+		if err != nil {
+			fmt.Fprintf(iostreams.ErrOut, "%s DNS verification failed: %v\n", md.colorize.Yellow("WARNING:"), err)
+			fmt.Fprintf(iostreams.ErrOut, "Your app is deployed but DNS may take a few minutes to propagate globally\n")
+		} else {
+			fmt.Fprintf(iostreams.ErrOut, "%s\n", md.colorize.Green("✓ DNS configuration verified"))
+		}
+
 		return err
 	} else {
 		return nil
