@@ -67,6 +67,7 @@ func testLaunchInputForBasic(t *testing.T) {
 				"fly_flyctl_version":   buildinfo.Version().String(),
 			},
 		},
+		MinSecretsVersion: nil,
 	}
 	li, err := md.launchInputForLaunch("", nil, nil)
 	require.NoError(t, err)
@@ -93,7 +94,8 @@ func testLaunchInputForBasic(t *testing.T) {
 	want.Config.Metadata["fly_release_id"] = "new_release_id"
 	want.Config.Metadata["fly_release_version"] = "4"
 	want.Config.Metadata["user-added-me"] = "keep it"
-	li = md.launchInputForRestart(origMachineRaw)
+	li, err = md.launchInputForRestart(origMachineRaw)
+	assert.NoError(t, err)
 	assert.Equal(t, want, li)
 
 	// Now updating the machines must include changes to appConfig
@@ -448,7 +450,8 @@ func testLaunchInputForUpdateKeepUnmanagedFields(t *testing.T) {
 	assert.Equal(t, &fly.DNSConfig{SkipRegistration: true}, li.Config.DNS)
 	assert.Equal(t, []fly.MachineProcess{{CmdOverride: []string{"foo"}}}, li.Config.Processes)
 
-	li = md.launchInputForRestart(origMachineRaw)
+	li, err = md.launchInputForRestart(origMachineRaw)
+	assert.NoError(t, err)
 	assert.Equal(t, "ab1234567890", li.ID)
 	assert.Equal(t, "ord", li.Region)
 	assert.Equal(t, "24/7", li.Config.Schedule)
@@ -521,6 +524,7 @@ func testLaunchInputForLaunchFiles(t *testing.T) {
 				},
 			},
 		},
+		MinSecretsVersion: nil,
 	}
 	li, err := md.launchInputForLaunch("", nil, nil)
 	require.NoError(t, err)
