@@ -17,6 +17,7 @@ import (
 	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/format"
@@ -87,7 +88,7 @@ func (md *machineDeployment) runReleaseCommand(ctx context.Context, commandType
 		return nil
 	})
 	eg.Go(func() error {
-		stream, err = logs.NewNatsStream(ctx, md.apiClient, logOpts)
+		stream, err = logs.NewNatsStream(ctx, md.apiClient, md.flapsClient, logOpts)
 		if err != nil {
 			// Silently fallback to app logs polling if NATS streaming client is unavailable.
 			stream = logs.NewPollingStream(md.apiClient)
@@ -232,18 +233,22 @@ func (md *machineDeployment) createReleaseCommandMachine(ctx context.Context) er
 	ctx, span := tracing.GetTracer().Start(ctx, "create_release_cmd_machine")
 	defer span.End()
 
-	launchInput := md.launchInputForReleaseCommand(nil)
-	releaseCmdMachine, err := md.flapsClient.Launch(ctx, *launchInput)
+	launchInput, err := md.launchInputForReleaseCommand(nil)
+	if err != nil {
+		return err
+	}
+
+	releaseCmdMachine, err := md.flapsClient.Launch(ctx, md.app.Name, *launchInput)
 	if err != nil {
 		tracing.RecordError(span, err, "failed to get ip addresses")
 		return fmt.Errorf("error creating a release_command machine: %w", err)
 	}
 
 	statuslogger.Logf(ctx, "Created release_command machine %s", md.colorize.Bold(releaseCmdMachine.ID))
-	md.releaseCommandMachine = machine.NewMachineSet(md.flapsClient, md.io, []*fly.Machine{releaseCmdMachine}, true)
+	md.releaseCommandMachine = machine.NewMachineSet(md.flapsClient, md.io, md.app.Name, []*fly.Machine{releaseCmdMachine}, true)
 
 	lm := md.releaseCommandMachine.GetMachines()[0]
-	if err := lm.WaitForState(ctx, fly.MachineStateStopped, md.waitTimeout, false); err != nil {
+	if err := lm.WaitForState(ctx, fly.MachineStateStopped, md.waitTimeout, machine.WithJustCreated()); err != nil {
 		err = suggestChangeWaitTimeout(err, "wait-timeout")
 		return err
 	}
@@ -251,7 +256,7 @@ func (md *machineDeployment) createReleaseCommandMachine(ctx context.Context) er
 	return nil
 }
 
-func (md *machineDeployment) launchInputForReleaseCommand(origMachineRaw *fly.Machine) *fly.LaunchMachineInput {
+func (md *machineDeployment) launchInputForReleaseCommand(origMachineRaw *fly.Machine) (*fly.LaunchMachineInput, error) {
 	if origMachineRaw == nil {
 		origMachineRaw = &fly.Machine{
 			Region: md.appConfig.PrimaryRegion,
@@ -270,11 +275,16 @@ func (md *machineDeployment) launchInputForReleaseCommand(origMachineRaw *fly.Ma
 		mConfig.Guest.HostDedicationID = hdid
 	}
 
-	return &fly.LaunchMachineInput{
-		Config:     mConfig,
-		Region:     origMachineRaw.Region,
-		SkipLaunch: true,
+	minvers, err := appsecrets.GetMinvers(md.appConfig.AppName)
+	if err != nil {
+		return nil, err
 	}
+	return &fly.LaunchMachineInput{
+		Config:            mConfig,
+		Region:            origMachineRaw.Region,
+		SkipLaunch:        true,
+		MinSecretsVersion: minvers,
+	}, nil
 }
 
 func (md *machineDeployment) inferReleaseCommandGuest() *fly.MachineGuest {
@@ -307,7 +317,7 @@ func (md *machineDeployment) inferReleaseCommandGuest() *fly.MachineGuest {
 }
 
 func (md *machineDeployment) waitForReleaseCommandToFinish(ctx context.Context, releaseCmdMachine machine.LeasableMachine) error {
-	err := releaseCmdMachine.WaitForState(ctx, fly.MachineStateStarted, md.waitTimeout, false)
+	err := releaseCmdMachine.WaitForState(ctx, fly.MachineStateStarted, md.waitTimeout)
 	if err != nil {
 		var flapsErr *flaps.FlapsError
 		if errors.As(err, &flapsErr) && flapsErr.ResponseStatusCode == http.StatusNotFound {
@@ -317,7 +327,7 @@ func (md *machineDeployment) waitForReleaseCommandToFinish(ctx context.Context,
 		err = suggestChangeWaitTimeout(err, "wait-timeout")
 		return fmt.Errorf("error waiting for release_command machine %s to start: %w", releaseCmdMachine.Machine().ID, err)
 	}
-	err = releaseCmdMachine.WaitForState(ctx, fly.MachineStateDestroyed, md.releaseCmdTimeout, true)
+	err = releaseCmdMachine.WaitForState(ctx, fly.MachineStateDestroyed, md.releaseCmdTimeout, machine.WithAllowInfinite(true))
 	if err != nil {
 		err = suggestChangeWaitTimeout(err, "release-command-timeout")
 		return fmt.Errorf("error waiting for release_command machine %s to finish running: %w", releaseCmdMachine.Machine().ID, err)
