@@ -6,6 +6,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/machine"
@@ -13,15 +14,15 @@ import (
 
 func stabMachineDeployment(appConfig *appconfig.Config) (*machineDeployment, error) {
 	md := &machineDeployment{
-		app: &fly.AppCompact{
-			ID: "my-cool-app",
-			Organization: &fly.OrganizationBasic{
-				ID: "my-dangling-org",
+		app: &flaps.App{
+			Name: "my-cool-app",
+			Organization: flaps.AppOrganizationInfo{
+				Slug: "my-org",
 			},
 		},
 		img:        "super/balloon",
 		appConfig:  appConfig,
-		machineSet: machine.NewMachineSet(nil, nil, nil, true),
+		machineSet: machine.NewMachineSet(nil, nil, "", nil, true),
 	}
 	return md, nil
 }
@@ -54,6 +55,7 @@ func Test_resolveUpdatedMachineConfig_Basic(t *testing.T) {
 				"fly_flyctl_version":   buildinfo.Version().String(),
 			},
 		},
+		MinSecretsVersion: nil,
 	}, li)
 }
 
@@ -145,9 +147,11 @@ func Test_resolveUpdatedMachineConfig_ReleaseCommand(t *testing.T) {
 				},
 			},
 		},
+		MinSecretsVersion: nil,
 	}, li)
 
-	got := md.launchInputForReleaseCommand(nil)
+	got, err := md.launchInputForReleaseCommand(nil)
+	assert.NoError(t, err)
 
 	// New release command machine
 	assert.Equal(t, &fly.LaunchMachineInput{
@@ -178,7 +182,8 @@ func Test_resolveUpdatedMachineConfig_ReleaseCommand(t *testing.T) {
 			},
 			Guest: fly.MachinePresets["shared-cpu-2x"],
 		},
-		SkipLaunch: true,
+		SkipLaunch:        true,
+		MinSecretsVersion: nil,
 	}, got)
 
 	// Update existing release command machine
@@ -198,7 +203,8 @@ func Test_resolveUpdatedMachineConfig_ReleaseCommand(t *testing.T) {
 		},
 	}
 
-	got = md.launchInputForReleaseCommand(origMachine)
+	got, err = md.launchInputForReleaseCommand(origMachine)
+	assert.NoError(t, err)
 
 	assert.Equal(t, &fly.LaunchMachineInput{
 		Config: &fly.MachineConfig{
@@ -228,7 +234,8 @@ func Test_resolveUpdatedMachineConfig_ReleaseCommand(t *testing.T) {
 			},
 			Guest: fly.MachinePresets["shared-cpu-2x"],
 		},
-		SkipLaunch: true,
+		SkipLaunch:        true,
+		MinSecretsVersion: nil,
 	}, got)
 }
 
@@ -268,6 +275,7 @@ func Test_resolveUpdatedMachineConfig_Mounts(t *testing.T) {
 				Name:   "data",
 			}},
 		},
+		MinSecretsVersion: nil,
 	}, li)
 
 	origMachine := &fly.Machine{
@@ -302,6 +310,7 @@ func Test_resolveUpdatedMachineConfig_Mounts(t *testing.T) {
 				Path:   "/data",
 			}},
 		},
+		MinSecretsVersion: nil,
 	}, li)
 }
 
@@ -327,7 +336,8 @@ func Test_resolveUpdatedMachineConfig_restartOnly(t *testing.T) {
 		},
 	}
 
-	got := md.launchInputForRestart(origMachine)
+	got, err := md.launchInputForRestart(origMachine)
+	assert.NoError(t, err)
 
 	assert.Equal(t, &fly.LaunchMachineInput{
 		ID: "OrigID",
@@ -341,6 +351,7 @@ func Test_resolveUpdatedMachineConfig_restartOnly(t *testing.T) {
 				"fly_flyctl_version":   buildinfo.Version().String(),
 			},
 		},
+		MinSecretsVersion: nil,
 	}, got)
 }
 
@@ -374,7 +385,9 @@ func Test_resolveUpdatedMachineConfig_restartOnlyProcessGroup(t *testing.T) {
 		},
 	}
 
-	got := md.launchInputForRestart(origMachine)
+	got, err := md.launchInputForRestart(origMachine)
+	assert.NoError(t, err)
+
 	assert.Equal(t, &fly.LaunchMachineInput{
 		ID: "OrigID",
 		Config: &fly.MachineConfig{
@@ -387,5 +400,6 @@ func Test_resolveUpdatedMachineConfig_restartOnlyProcessGroup(t *testing.T) {
 				"fly_flyctl_version":   buildinfo.Version().String(),
 			},
 		},
+		MinSecretsVersion: nil,
 	}, got)
 }
