@@ -20,6 +20,7 @@ import (
 	"go.opentelemetry.io/otel/trace"
 
 	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/ctrlc"
 	"github.com/superfly/flyctl/internal/flapsutil"
@@ -78,6 +79,7 @@ type blueGreen struct {
 	hangingBlueMachines []string
 	timestamp           string
 	maxConcurrent       int
+	app                 *flaps.App
 
 	rollbackLog RollbackLog
 
@@ -103,6 +105,7 @@ func BlueGreenStrategy(md *machineDeployment, blueMachines []*machineUpdateEntry
 		hangingBlueMachines: []string{},
 		timestamp:           fmt.Sprintf("%d", time.Now().Unix()),
 		maxConcurrent:       md.maxConcurrent,
+		app:                 md.app,
 		rollbackLog:         RollbackLog{canDeleteGreenMachines: true, disableRollback: false},
 	}
 
@@ -168,13 +171,13 @@ func (bg *blueGreen) CreateGreenMachines(ctx context.Context) error {
 			launchInput.SkipServiceRegistration = true
 			launchInput.Config.Metadata[fly.MachineConfigMetadataKeyFlyctlBGTag] = bg.timestamp
 
-			newMachineRaw, err := bg.flaps.Launch(ctx, *launchInput)
+			newMachineRaw, err := bg.flaps.Launch(ctx, bg.app.Name, *launchInput)
 			if err != nil {
 				tracing.RecordError(span, err, "failed to launch machine")
 				return err
 			}
 
-			greenMachine := machine.NewLeasableMachine(bg.flaps, bg.io, newMachineRaw, true)
+			greenMachine := machine.NewLeasableMachine(bg.flaps, bg.io, bg.app.Name, newMachineRaw, true)
 			defer releaseLease(ctx, greenMachine)
 
 			lock.Lock()
@@ -259,7 +262,7 @@ func (bg *blueGreen) WaitForGreenMachinesToBeStarted(ctx context.Context) error
 		}
 
 		go func(lm machine.LeasableMachine) {
-			err := machine.WaitForStartOrStop(ctx, lm.Machine(), "start", bg.timeout)
+			err := machine.WaitForStartOrStop(ctx, bg.app.Name, lm.Machine(), "start", bg.timeout)
 			if err != nil {
 				errChan <- err
 				return
@@ -403,7 +406,7 @@ func (bg *blueGreen) WaitForGreenMachinesToBeHealthy(ctx context.Context) error
 			time.Sleep(gracePeriod)
 
 			for {
-				updateMachine, err := bg.flaps.Get(waitCtx, m.Machine().ID)
+				updateMachine, err := bg.flaps.Get(waitCtx, bg.app.Name, m.Machine().ID)
 
 				switch {
 				case waitCtx.Err() != nil:
@@ -414,7 +417,7 @@ func (bg *blueGreen) WaitForGreenMachinesToBeHealthy(ctx context.Context) error
 					return
 				}
 
-				status := updateMachine.TopLevelChecks()
+				status := updateMachine.AllHealthChecks()
 				bg.healthLock.Lock()
 				machineIDToHealthStatus[m.FormattedMachineId()] = status
 				bg.healthLock.Unlock()
@@ -467,7 +470,7 @@ func (bg *blueGreen) MarkGreenMachinesAsReadyForTraffic(ctx context.Context) err
 			if bg.isAborted() {
 				return ErrAborted
 			}
-			err := bg.flaps.Uncordon(ctx, gm.Machine().ID, "")
+			err := bg.flaps.Uncordon(ctx, bg.app.Name, gm.Machine().ID, "")
 			if err != nil {
 				return err
 			}
@@ -553,7 +556,7 @@ func (bg *blueGreen) WaitForBlueMachinesToBeStopped(ctx context.Context) error {
 		id := gm.leasableMachine.FormattedMachineId()
 
 		go func(lm machine.LeasableMachine) {
-			err := machine.WaitForStartOrStop(ctx, lm.Machine(), "stop", bg.timeout)
+			err := machine.WaitForStartOrStop(ctx, bg.app.Name, lm.Machine(), "stop", bg.timeout)
 			if err != nil {
 				errChan <- fmt.Errorf("failed to stop machine %s: %v", lm.FormattedMachineId(), err)
 			} else {
@@ -628,43 +631,6 @@ func (bg *blueGreen) DestroyBlueMachines(ctx context.Context) error {
 	return nil
 }
 
-func (bg *blueGreen) attachCustomTopLevelChecks() {
-	for _, entry := range bg.blueMachines {
-		for _, service := range entry.launchInput.Config.Services {
-			servicePort := service.InternalPort
-			serviceProtocol := service.Protocol
-
-			for _, check := range service.Checks {
-				cc := fly.MachineCheck{
-					Port:              check.Port,
-					Type:              check.Type,
-					Interval:          check.Interval,
-					Timeout:           check.Timeout,
-					GracePeriod:       check.GracePeriod,
-					HTTPMethod:        check.HTTPMethod,
-					HTTPPath:          check.HTTPPath,
-					HTTPProtocol:      check.HTTPProtocol,
-					HTTPSkipTLSVerify: check.HTTPSkipTLSVerify,
-					HTTPHeaders:       check.HTTPHeaders,
-				}
-
-				if cc.Port == nil {
-					cc.Port = &servicePort
-				}
-
-				if cc.Type == nil {
-					cc.Type = &serviceProtocol
-				}
-
-				if entry.launchInput.Config.Checks == nil {
-					entry.launchInput.Config.Checks = make(map[string]fly.MachineCheck)
-				}
-				entry.launchInput.Config.Checks[fmt.Sprintf("bg_deployments_%s", *check.Type)] = cc
-			}
-		}
-	}
-}
-
 func (bg *blueGreen) Deploy(ctx context.Context) error {
 	ctx, span := tracing.GetTracer().Start(ctx, "bluegreen")
 	defer span.End()
@@ -696,19 +662,24 @@ func (bg *blueGreen) Deploy(ctx context.Context) error {
 		return err
 	}
 
-	bg.attachCustomTopLevelChecks()
-
-	totalChecks := 0
+	totalMachinesWithChecks := 0
 	for _, entry := range bg.blueMachines {
-		if len(entry.launchInput.Config.Checks) == 0 {
+		machineChecks := len(entry.launchInput.Config.Checks)
+
+		// Also count service-level checks
+		for _, service := range entry.launchInput.Config.Services {
+			machineChecks += len(service.Checks)
+		}
+
+		if machineChecks == 0 {
 			fmt.Fprintf(bg.io.ErrOut, "\n[WARN] Machine %s doesn't have healthchecks setup. We won't check its health.", entry.leasableMachine.FormattedMachineId())
 			continue
 		}
 
-		totalChecks++
+		totalMachinesWithChecks++
 	}
 
-	if totalChecks == 0 && len(bg.blueMachines) != 0 {
+	if totalMachinesWithChecks == 0 && len(bg.blueMachines) != 0 {
 		fmt.Fprintf(bg.io.ErrOut, "\n\nYou need to define at least 1 check in order to use blue-green deployments. Refer to https://fly.io/docs/reference/configuration/#services-tcp_checks\n")
 		return ErrValidationError
 	}
@@ -982,14 +953,14 @@ func (bg *blueGreen) DetectMultipleImageVersions(ctx context.Context) error {
 	if len(safeToDelete) > 0 {
 		fmt.Fprintf(bg.io.ErrOut, "\n  These image(s) can be safely destroyed:\n")
 		for image := range safeToDelete {
-			fmt.Fprintf(bg.io.ErrOut, "    [x] %s - %v machine(s) ('fly machines destroy --force --image=%s')\n", image, len(imageToMachineIDs[image]), image)
+			fmt.Fprintf(bg.io.ErrOut, "    [x] %s - %v machine(s) ('fly machines destroy --force --image=%s --app=%s')\n", image, len(imageToMachineIDs[image]), image, bg.appConfig.AppName)
 		}
 	}
 
 	fmt.Fprintf(bg.io.ErrOut, "\n  Here's how to fix your app so deployments can go through:\n")
 	fmt.Fprintf(bg.io.ErrOut, "    1. Find all the unwanted image versions from the list above.\n")
 	fmt.Fprintf(bg.io.ErrOut, "       Use 'fly machines list' and 'fly releases --image' to help determine unwanted images.\n")
-	fmt.Fprintf(bg.io.ErrOut, "    2. For each unwanted image version, run 'fly machines destroy --force --image=<insert-image-version>'\n")
+	fmt.Fprintf(bg.io.ErrOut, "    2. For each unwanted image version, run 'fly machines destroy --force --image=<image-version> --app <app-name>'\n")
 	fmt.Fprintf(bg.io.ErrOut, "    3. Retry the deployment with 'fly deploy'\n")
 	fmt.Fprintf(bg.io.ErrOut, "\n")
 
