@@ -102,17 +102,17 @@ func ProvisionExtension(ctx context.Context, params ExtensionParams) (extension
 		if override := params.OverrideName; override != nil {
 			name = *override
 		} else {
-			if name == "" {
-				name = flag.GetString(ctx, "name")
-			}
+			name = flag.GetString(ctx, "name")
 
 			if name == "" {
 				if provider.NameSuffix != "" && targetApp.Name != "" {
 					name = targetApp.Name + "-" + provider.NameSuffix
 				}
-				err = prompt.String(ctx, &name, "Choose a name, use the default, or leave blank to generate one:", name, false)
-				if err != nil {
-					return
+				if !flag.GetYes(ctx) {
+					err = prompt.String(ctx, &name, "Choose a name, use the default, or leave blank to generate one:", name, false)
+					if err != nil {
+						return
+					}
 				}
 			}
 		}
@@ -313,6 +313,12 @@ func WaitForProvision(ctx context.Context, name string, provider string) error {
 			return err
 		}
 
+		// Validate that the returned add-on matches the expected provider type
+		if resp.AddOn.AddOnProvider.Name != provider {
+			return fmt.Errorf("found add-on '%s' with provider '%s', but expected provider '%s'",
+				resp.AddOn.Name, resp.AddOn.AddOnProvider.Name, provider)
+		}
+
 		if resp.AddOn.Status == "error" {
 			if resp.AddOn.ErrorMessage != "" {
 				return errors.New(resp.AddOn.ErrorMessage)
@@ -387,6 +393,12 @@ func OpenDashboard(ctx context.Context, extensionName string, provider gql.AddOn
 		return err
 	}
 
+	// Validate that the returned add-on matches the expected provider type
+	if result.AddOn.AddOnProvider.Name != string(provider) {
+		return fmt.Errorf("found add-on '%s' with provider '%s', but expected provider '%s'",
+			result.AddOn.Name, result.AddOn.AddOnProvider.Name, provider)
+	}
+
 	err = AgreeToProviderTos(ctx, result.AddOn.AddOnProvider.ExtensionProviderData)
 	if err != nil {
 		return err
@@ -408,6 +420,12 @@ func Discover(ctx context.Context, provider gql.AddOnType) (addOn *gql.AddOnData
 			return nil, nil, err
 		}
 
+		// Validate that the returned add-on matches the expected provider type
+		if response.AddOn.AddOnProvider.Name != string(provider) {
+			return nil, nil, fmt.Errorf("found add-on '%s' with provider '%s', but expected provider '%s'",
+				response.AddOn.Name, response.AddOn.AddOnProvider.Name, provider)
+		}
+
 		addOn = &response.AddOn.AddOnData
 
 	} else if appName != "" {
@@ -431,9 +449,9 @@ func Discover(ctx context.Context, provider gql.AddOnType) (addOn *gql.AddOnData
 
 func setSecretsFromExtension(ctx context.Context, app *gql.AppData, extension *Extension, overrideSecretKeyNamesMap map[string]string) (err error) {
 	var (
-		io              = iostreams.FromContext(ctx)
-		client          = flyutil.ClientFromContext(ctx).GenqClient()
-		setSecrets bool = true
+		io         = iostreams.FromContext(ctx)
+		client     = flyutil.ClientFromContext(ctx).GenqClient()
+		setSecrets = true
 	)
 
 	environment := extension.Data.Environment
@@ -538,7 +556,7 @@ func Status(ctx context.Context, provider gql.AddOnType) (err error) {
 		},
 	}
 
-	var cols []string = []string{"Name", "Primary Region", "Status"}
+	var cols = []string{"Name", "Primary Region", "Status"}
 
 	if app != nil {
 		obj[0] = append(obj[0], app.Name)
