@@ -6,7 +6,6 @@ import (
 
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/extensions/arcjet"
-	"github.com/superfly/flyctl/internal/command/extensions/enveloop"
 	"github.com/superfly/flyctl/internal/command/extensions/fly_mysql"
 	"github.com/superfly/flyctl/internal/command/extensions/kubernetes"
 	sentry_ext "github.com/superfly/flyctl/internal/command/extensions/sentry"
@@ -32,7 +31,6 @@ func New() (cmd *cobra.Command) {
 		tigris.New(),
 		kubernetes.New(),
 		vector.New(),
-		enveloop.New(),
 		arcjet.New(),
 		fly_mysql.New(),
 		wafris.New(),
