@@ -36,7 +36,11 @@ func runSentryCreate(ctx context.Context) (err error) {
 		Provider: "sentry",
 	})
 	if extension.SetsSecrets {
-		err = secrets.DeploySecrets(ctx, gql.ToAppCompact(*extension.App), false, false)
+		err = secrets.DeploySecrets(ctx, gql.ToAppCompact(*extension.App), secrets.DeploymentArgs{
+			Stage:    false,
+			Detach:   false,
+			CheckDNS: true,
+		})
 	}
 	return
 }
