@@ -51,7 +51,7 @@ func runStatus(ctx context.Context) (err error) {
 		},
 	}
 
-	var cols []string = []string{"Name", "Status", "Region"}
+	var cols = []string{"Name", "Status", "Region"}
 
 	if app != nil {
 		obj[0] = append(obj[0], app.Name)
