@@ -15,14 +15,17 @@ import (
 	"github.com/logrusorgru/aurora"
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
+	"github.com/superfly/flyctl/gql"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/deploy"
 	"github.com/superfly/flyctl/internal/command/launch/plan"
 	"github.com/superfly/flyctl/internal/env"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flag/validation"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/flyerr"
-	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/metrics"
 	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/internal/state"
@@ -37,7 +40,7 @@ func New() (cmd *cobra.Command) {
 		short = `Create and configure a new app from source code or a Docker image`
 	)
 
-	cmd = command.New("launch", short, long, run, command.RequireSession, command.RequireUiex, command.LoadAppConfigIfPresent)
+	cmd = command.New("launch", short, long, run, command.RequireSession, command.LoadAppConfigIfPresent)
 	cmd.Args = cobra.NoArgs
 
 	flags := []flag.Flag{
@@ -141,9 +144,20 @@ func New() (cmd *cobra.Command) {
 			Name:        "yaml",
 			Description: "Generate configuration in YAML format",
 		},
+		// don't try to generate a name
 		flag.Bool{
-			Name:        "no-create",
-			Description: "Do not create an app, only generate configuration files",
+			Name:        "force-name",
+			Description: "Force app name supplied by --name",
+			Default:     false,
+			Hidden:      true,
+		},
+		// like reuse-app, but non-legacy!
+		flag.Bool{
+			Name:        "no-create-app",
+			Description: "Do not create an app",
+			Default:     false,
+			Hidden:      true,
+			Aliases:     []string{"no-create"},
 		},
 		flag.String{
 			Name:        "auto-stop",
@@ -163,13 +177,13 @@ func New() (cmd *cobra.Command) {
 			Name:        "secret",
 			Description: "Set of secrets in the form of NAME=VALUE pairs. Can be specified multiple times.",
 		},
+		flag.String{
+			Name:        "db",
+			Description: "Provision a Postgres database. Options: mpg (managed postgres), upg/legacy (unmanaged postgres), or true (default type)",
+			NoOptDefVal: "true",
+		},
 	}
 
-	flags = append(flags, flag.Bool{
-		Name:        "db",
-		Description: "Force provisioning a Postgres database",
-		Default:     false,
-	})
 	flag.Add(cmd, flags...)
 
 	cmd.AddCommand(NewPlan())
@@ -311,6 +325,19 @@ func run(ctx context.Context) (err error) {
 		return err
 	}
 
+	// Validate conflicting postgres flags
+	if err := validatePostgresFlags(ctx); err != nil {
+		return err
+	}
+
+	if err := validation.ValidateCompressionFlag(flag.GetString(ctx, "compression")); err != nil {
+		return err
+	}
+
+	if err := validation.ValidateCompressionLevelFlag(flag.GetInt(ctx, "compression-level")); err != nil {
+		return err
+	}
+
 	var (
 		launchManifest *LaunchManifest
 		cache          *planBuildCache
@@ -321,6 +348,46 @@ func run(ctx context.Context) (err error) {
 		return err
 	}
 
+	planStep := plan.GetPlanStep(ctx)
+
+	if launchManifest != nil && planStep != "generate" {
+		// we loaded a manifest...
+		cache = &planBuildCache{
+			appConfig:        launchManifest.Config,
+			sourceInfo:       nil,
+			appNameValidated: true,
+			warnedNoCcHa:     true,
+		}
+	}
+
+	// For "generate" step, allow command-line flags to override manifest values.
+	// This is necessary because buildManifest() is skipped when loading a manifest from file.
+	// The "generate" step specifically needs this because it's called after propose/create steps,
+	// and the deployer wrapper needs to be able to override specific values without re-proposing.
+	if launchManifest != nil && planStep == "generate" {
+		// Override org if --org flag was provided
+		if orgRequested := flag.GetOrg(ctx); orgRequested != "" {
+			launchManifest.Plan.OrgSlug = orgRequested
+		}
+
+		// Override app name if --app flag was provided
+		// This allows explicit override while preserving manifest value by default
+		if appRequested := flag.GetApp(ctx); appRequested != "" && flag.IsSpecified(ctx, "app") {
+			launchManifest.Plan.AppName = appRequested
+		}
+
+		// Override region if --region flag was provided
+		if regionRequested := flag.GetRegion(ctx); regionRequested != "" && flag.IsSpecified(ctx, "region") {
+			launchManifest.Plan.RegionCode = regionRequested
+		}
+
+		// Initialize PlanSource if nil (happens when loading from JSON because fields are unexported)
+		// This prevents nil pointer dereference in PlanSummary and other code that accesses PlanSource
+		if launchManifest.PlanSource == nil {
+			launchManifest.PlanSource = newDefaultPlanSource("from manifest")
+		}
+	}
+
 	// "--from" arg handling
 	parentCtx := ctx
 	ctx, parentConfig, err := setupFromTemplate(ctx)
@@ -334,19 +401,20 @@ func run(ctx context.Context) (err error) {
 	recoverableErrors := recoverableErrorBuilder{canEnterUi: canEnterUi}
 
 	if launchManifest == nil {
-
 		launchManifest, cache, err = buildManifest(ctx, parentConfig, &recoverableErrors)
 		if err != nil {
 			var recoverableErr recoverableInUiError
-			if errors.As(err, &recoverableErr) && canEnterUi {
-			} else {
+			if !errors.As(err, &recoverableErr) || !canEnterUi {
 				return err
 			}
 		}
 
-		if flag.GetBool(ctx, "manifest") {
+		manifestFlag := flag.GetBool(ctx, "manifest")
+		manifestPath := flag.GetString(ctx, "manifest-path")
+
+		if manifestFlag {
 			var jsonEncoder *json.Encoder
-			if manifestPath := flag.GetString(ctx, "manifest-path"); manifestPath != "" {
+			if manifestPath != "" {
 				file, err := os.OpenFile(manifestPath, os.O_RDWR|os.O_CREATE|os.O_TRUNC, 0755)
 				if err != nil {
 					return err
@@ -358,7 +426,8 @@ func run(ctx context.Context) (err error) {
 				jsonEncoder = json.NewEncoder(io.Out)
 			}
 			jsonEncoder.SetIndent("", "  ")
-			return jsonEncoder.Encode(launchManifest)
+			encodeErr := jsonEncoder.Encode(launchManifest)
+			return encodeErr
 		}
 	}
 
@@ -381,7 +450,7 @@ func run(ctx context.Context) (err error) {
 		status.VM.ProcessN = len(vm.Processes)
 	}
 
-	status.HasPostgres = launchManifest.Plan.Postgres.FlyPostgres != nil
+	status.HasPostgres = launchManifest.Plan.Postgres.FlyPostgres != nil || launchManifest.Plan.Postgres.SupabasePostgres != nil || launchManifest.Plan.Postgres.ManagedPostgres != nil
 	status.HasRedis = launchManifest.Plan.Redis.UpstashRedis != nil
 	status.HasSentry = launchManifest.Plan.Sentry
 
@@ -403,14 +472,66 @@ func run(ctx context.Context) (err error) {
 		family = state.sourceInfo.Family
 	}
 
-	planStep := plan.GetPlanStep(ctx)
 	if planStep == "" {
-		fmt.Fprintf(
-			io.Out,
-			"We're about to launch your %s on Fly.io. Here's what you're getting:\n\n%s\n",
-			familyToAppType(family),
-			summary,
-		)
+		colorize := io.ColorScheme()
+
+		// Get terminal width for responsive borders
+		termWidth := io.TerminalWidth()
+		if termWidth > 120 {
+			termWidth = 120 // Cap at 120 for readability
+		}
+		border := strings.Repeat("═", termWidth)
+
+		// Print top border
+		fmt.Fprintln(io.Out)
+		fmt.Fprintln(io.Out, border)
+		fmt.Fprintln(io.Out)
+
+		// Print ASCII art with purple = characters
+		art := `
+
+
+                       %%%%%%%
+                  %#+++=.  .:+*+*#%%
+               %#+=====:       :++=+#%
+             %#+======-          .++==#%
+            %*=======+.            .+==+%
+           %#========+               *==+%
+           #+========+              = *==*%
+           #=========+           .. : .*=+#
+           #=========*    ==      .:   *==*%
+           #+========+-             :. +==*%
+           #*=========+              :-*==*%         %@
+           %#**+======+-           .-. #==*%      @%%%%@
+           %%#++=======+:      .::.   :*=+%       @%
+           %%%#*++=====++.            #=+#%      @%@
+          %%  %%#*++++++*+.          **+#@       %@
+         %%     @%#***+++*+         =*+#%%      %%
+        @@        @%%##*****       :*+%@%%%    %%
+        @@        @@@@%#***##     .**%%   %% %%%
+        @      @@@@  @@@%%#**%   .+#%@     @%%
+        @@@@@@@           @%#*#.:*%%
+                            @%#**%@
+                             @@%@@
+                            %%#%%%
+                          @#***+**%
+                          %**+***#%
+                          @@%#+*#%
+
+`
+		// Replace = with purple =
+		artColored := strings.ReplaceAll(art, "=", colorize.Purple("="))
+		fmt.Fprintln(io.Out, artColored)
+
+		// Print header text
+		fmt.Fprintf(io.Out, "%s\n\n", colorize.Bold(fmt.Sprintf("We're about to launch your %s on Fly.io. %s", familyToAppType(family), colorize.Purple("Here's what you're getting:"))))
+
+		// Print summary table
+		fmt.Fprintln(io.Out, summary)
+
+		// Print bottom border
+		fmt.Fprintln(io.Out, border)
+		fmt.Fprintln(io.Out)
 	}
 
 	if errors := recoverableErrors.build(); errors != "" {
@@ -419,13 +540,26 @@ func run(ctx context.Context) (err error) {
 		incompleteLaunchManifest = true
 	}
 
+	// Check billing status and display appropriate message
+	if planStep == "" {
+		shouldContinue, err := checkBillingStatus(ctx, state)
+		if err != nil {
+			return err
+		}
+		if !shouldContinue {
+			return errors.New("payment method required to continue")
+		}
+	}
+
 	editInUi := false
 	if !flag.GetBool(ctx, "yes") && planStep == "" {
+		colorize := io.ColorScheme()
 		if incompleteLaunchManifest {
 			editInUi, err = prompt.ConfirmYes(ctx, "Would you like to continue in the web UI?")
 		} else {
-			editInUi, err = prompt.Confirm(ctx, "Do you want to tweak these settings before proceeding?")
+			editInUi, err = prompt.Confirm(ctx, colorize.Yellow("Do you want to tweak these settings before proceeding?"))
 		}
+		fmt.Fprintln(io.Out)
 
 		if err != nil && !errors.Is(err, prompt.ErrNonInteractive) {
 			return err
@@ -463,8 +597,8 @@ func run(ctx context.Context) (err error) {
 				exports[name] = strings.ReplaceAll(secret, "${FLYCAST_URL}", flycast)
 			}
 
-			apiClient := flyutil.ClientFromContext(parentCtx)
-			_, err := apiClient.SetSecrets(parentCtx, parentConfig.AppName, exports)
+			flapsClient := flapsutil.ClientFromContext(parentCtx)
+			err = appsecrets.Update(parentCtx, flapsClient, parentConfig.AppName, exports, nil)
 			if err != nil {
 				return err
 			}
@@ -500,3 +634,127 @@ func warnLegacyBehavior(ctx context.Context) error {
 	}
 	return nil
 }
+
+// validatePostgresFlags checks for conflicting postgres-related flags
+func validatePostgresFlags(ctx context.Context) error {
+	dbFlag := flag.GetString(ctx, "db")
+	noDb := flag.GetBool(ctx, "no-db")
+
+	// Normalize db flag values
+	switch dbFlag {
+	case "true", "1", "yes":
+		dbFlag = "true"
+	case "mpg", "managed":
+		dbFlag = "mpg"
+	case "upg", "unmanaged", "legacy":
+		dbFlag = "upg"
+	case "false", "0", "no", "":
+		dbFlag = ""
+	default:
+		if dbFlag != "" {
+			return flyerr.GenericErr{
+				Err:     fmt.Sprintf("Invalid value '%s' for --db flag", dbFlag),
+				Suggest: "Valid options: mpg (managed postgres), upg/legacy (unmanaged postgres), or true (default type)",
+			}
+		}
+	}
+
+	// Check if db flag conflicts with --no-db
+	if dbFlag != "" && noDb {
+		return flyerr.GenericErr{
+			Err:     "Cannot specify both --db and --no-db",
+			Suggest: "Remove either --db or --no-db",
+		}
+	}
+
+	return nil
+}
+
+// checkBillingStatus checks the organization's billing status and displays appropriate messaging
+// Returns (shouldContinue, error)
+func checkBillingStatus(ctx context.Context, state *launchState) (bool, error) {
+	io := iostreams.FromContext(ctx)
+	colorize := io.ColorScheme()
+
+	// Skip billing check if running in non-interactive mode or CI
+	if !io.IsInteractive() || env.IsCI() {
+		return true, nil
+	}
+
+	// Fetch organization data including billing status
+	org, err := state.orgCompact(ctx)
+	if err != nil {
+		// If we can't fetch org data, log the error but don't block the launch
+		fmt.Fprintf(io.ErrOut, "Warning: Could not check billing status: %v\n", err)
+		return true, nil
+	}
+
+	fmt.Fprintln(io.Out)
+
+	switch org.BillingStatus {
+	case gql.BillingStatusTrialActive:
+		// User is on active free trial - celebrate!
+		fmt.Fprintf(io.Out, "%s\n", colorize.Purple("✓ Your free trial has you covered - ship it! ✨"))
+
+	case gql.BillingStatusSourceRequired, gql.BillingStatusTrialEnded:
+		// User needs to add a payment method
+		fmt.Fprintf(io.Out, "%s\n", colorize.Yellow("! You'll need to add a payment method in order to proceed."))
+		fmt.Fprintln(io.Out)
+
+		addPayment, err := prompt.Confirm(ctx, "Would you like to do this now?")
+		if err != nil {
+			return false, err
+		}
+
+		if addPayment {
+			// Open billing dashboard URL
+			billingURL := fmt.Sprintf("https://fly.io/dashboard/%s/billing", org.Slug)
+			fmt.Fprintln(io.Out)
+			fmt.Fprintf(io.Out, "Opening billing dashboard: %s\n", colorize.Bold(billingURL))
+			fmt.Fprintln(io.Out)
+			fmt.Fprintf(io.Out, "After adding a payment method, please run %s again.\n", colorize.Purple("'fly launch'"))
+
+			// Try to open the URL in the browser
+			if err := openBrowser(billingURL); err != nil {
+				fmt.Fprintf(io.ErrOut, "Could not open browser automatically. Please visit: %s\n", billingURL)
+			}
+
+			return false, nil
+		} else {
+			return false, nil
+		}
+
+	case gql.BillingStatusCurrent, gql.BillingStatusPastDue, gql.BillingStatusDelinquent:
+		// User has a payment method configured - say nothing per requirements
+		// Just continue silently
+
+	default:
+		// Unknown billing status - log but don't block
+		fmt.Fprintf(io.ErrOut, "Warning: Unknown billing status: %s\n", org.BillingStatus)
+	}
+
+	fmt.Fprintln(io.Out)
+	return true, nil
+}
+
+// openBrowser attempts to open the given URL in the default browser
+func openBrowser(url string) error {
+	var cmd *exec.Cmd
+
+	// Determine the OS and use the appropriate command
+	// We can't use runtime.GOOS directly in exec context, so we check the environment
+	if _, err := exec.LookPath("open"); err == nil {
+		// macOS
+		cmd = exec.Command("open", url)
+	} else if _, err := exec.LookPath("xdg-open"); err == nil {
+		// Linux
+		cmd = exec.Command("xdg-open", url)
+	} else if _, err := exec.LookPath("cmd"); err == nil {
+		// Windows
+		cmd = exec.Command("cmd", "/c", "start", url)
+	} else {
+		return fmt.Errorf("could not determine how to open browser")
+	}
+
+	return cmd.Start()
+}
