@@ -7,6 +7,7 @@ import (
 	"github.com/samber/lo"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command/deploy"
+	"github.com/superfly/flyctl/internal/command/deploycontext"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -29,11 +30,7 @@ func (state *launchState) firstDeploy(ctx context.Context) error {
 	// TODO(Allison): Do we want to make the executive decision to just *always* deploy?
 	// Feedback(Sam): scanners need the abiiity to abort the deploy if they detect a problem
 
-	deployNow := true
-
-	if state.sourceInfo.SkipDeploy || flag.GetBool(ctx, "no-deploy") {
-		deployNow = false
-	}
+	deployNow := !(state.sourceInfo.SkipDeploy || flag.GetBool(ctx, "no-deploy"))
 
 	if flag.GetBool(ctx, "now") {
 		deployNow = true
@@ -84,6 +81,8 @@ func (state *launchState) firstDeploy(ctx context.Context) error {
 				return err
 			}
 		}
+		// Mark this as a first launch to show celebratory output
+		ctx = context.WithValue(ctx, deploycontext.IsFirstLaunchKey, true)
 		return deploy.DeployWithConfig(ctx, state.appConfig, 0, flag.GetBool(ctx, "now"))
 	}
 
