@@ -10,9 +10,9 @@ import (
 
 	"github.com/docker/go-units"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command/launch/plan"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flag/flagnames"
@@ -39,11 +39,11 @@ func (state *launchState) Launch(ctx context.Context) error {
 		return err
 	}
 
-	org, err := state.Org(ctx)
+	org, err := state.orgCompact(ctx)
 	if err != nil {
 		return err
 	}
-	if !planValidateHighAvailability(ctx, state.Plan, org, !state.warnedNoCcHa) {
+	if !planValidateHighAvailability(ctx, state.Plan, org.Billable, !state.warnedNoCcHa) {
 		state.Plan.HighAvailability = false
 		state.warnedNoCcHa = true
 	}
@@ -56,15 +56,18 @@ func (state *launchState) Launch(ctx context.Context) error {
 			return err
 		}
 
-		fmt.Fprintf(io.Out, "Created app '%s' in organization '%s'\n", app.Name, app.Organization.Slug)
-		fmt.Fprintf(io.Out, "Admin URL: https://fly.io/apps/%s\n", app.Name)
-		fmt.Fprintf(io.Out, "Hostname: %s.fly.dev\n", app.Name)
+		colorize := io.ColorScheme()
+		fmt.Fprintf(io.Out, "%s\n\n", colorize.Green(fmt.Sprintf("Created app '%s' in organization '%s'", app.Name, app.Organization.Slug)))
+		fmt.Fprintf(io.Out, "Admin URL: %s\n", colorize.Purple(fmt.Sprintf("https://fly.io/apps/%s", app.Name)))
+		fmt.Fprintf(io.Out, "Hostname: %s\n", colorize.Purple(fmt.Sprintf("%s.fly.dev", app.Name)))
 
 		if planStep == "create" {
 			return nil
 		}
 	}
 
+	flapsClient := flapsutil.ClientFromContext(ctx)
+
 	// TODO: ideally this would be passed as a part of the plan to the Launch UI
 	// and allow choices of what actions are desired to be make there.
 	if state.sourceInfo != nil && state.sourceInfo.GitHubActions.Deploy {
@@ -107,6 +110,13 @@ func (state *launchState) Launch(ctx context.Context) error {
 		}
 	}
 
+	if planStep != "generate" {
+		// Override internal port if requested using --internal-port flag
+		if n := flag.GetInt(ctx, "internal-port"); n > 0 {
+			state.appConfig.SetInternalPort(n)
+		}
+	}
+
 	// if the user specified a command, set it in the app config
 	if flag.GetString(ctx, "command") != "" {
 		if state.appConfig.Processes == nil {
@@ -183,8 +193,7 @@ func (state *launchState) Launch(ctx context.Context) error {
 			secrets[key] = value
 		}
 
-		client := flyutil.ClientFromContext(ctx)
-		if _, err := client.SetSecrets(ctx, state.appConfig.AppName, secrets); err != nil {
+		if err := appsecrets.Update(ctx, flapsClient, state.appConfig.AppName, secrets, nil); err != nil {
 			return err
 		}
 	}
@@ -225,6 +234,12 @@ func ParseMountOptions(mount *appconfig.Mount, options string) error {
 				return fmt.Errorf("invalid value for snapshot_retention: %s", value)
 			}
 			mount.SnapshotRetention = &ret
+		case "scheduled_snapshots":
+			ret, err := strconv.ParseBool(value)
+			if err != nil {
+				return fmt.Errorf("invalid value for scheduled_snapshots: %s", value)
+			}
+			mount.ScheduledSnapshots = &ret
 		case "auto_extend_size_threshold":
 			threshold, err := strconv.Atoi(value)
 			if err != nil {
@@ -268,17 +283,30 @@ func (state *launchState) updateComputeFromDeprecatedGuestFields(ctx context.Con
 	return nil
 }
 
+// isComputeValid checks if a compute configuration is valid and can be safely modified
+func isComputeValid(c *appconfig.Compute) bool {
+	return c != nil && c.MachineGuest != nil
+}
+
 // updateConfig populates the appConfig with the plan's values
 func (state *launchState) updateConfig(ctx context.Context) {
-	state.appConfig.AppName = state.Plan.AppName
-	state.appConfig.PrimaryRegion = state.Plan.RegionCode
-	if state.env != nil {
-		state.appConfig.SetEnvVariables(state.env)
+	appConfig := state.appConfig
+	env := state.env
+	plan := state.Plan
+
+	if plan == nil {
+		return
 	}
 
-	state.appConfig.Compute = state.Plan.Compute
+	appConfig.AppName = plan.AppName
+	appConfig.PrimaryRegion = plan.RegionCode
+	if env != nil {
+		appConfig.SetEnvVariables(env)
+	}
 
-	if state.Plan.HttpServicePort != 0 {
+	appConfig.Compute = plan.Compute
+
+	if plan.HttpServicePort != 0 {
 		autostop := fly.MachineAutostopStop
 		autostopFlag := flag.GetString(ctx, "auto-stop")
 
@@ -288,8 +316,11 @@ func (state *launchState) updateConfig(ctx context.Context) {
 			autostop = fly.MachineAutostopSuspend
 
 			// if any compute has a GPU or more than 2GB of memory, set autostop to stop
-			for _, compute := range state.appConfig.Compute {
-				if compute.MachineGuest != nil && compute.MachineGuest.GPUKind != "" {
+			for _, compute := range appConfig.Compute {
+				if !isComputeValid(compute) {
+					continue
+				}
+				if compute.MachineGuest.GPUKind != "" {
 					autostop = fly.MachineAutostopStop
 					break
 				}
@@ -304,8 +335,8 @@ func (state *launchState) updateConfig(ctx context.Context) {
 			}
 		}
 
-		if state.appConfig.HTTPService == nil {
-			state.appConfig.HTTPService = &appconfig.HTTPService{
+		if appConfig.HTTPService == nil {
+			appConfig.HTTPService = &appconfig.HTTPService{
 				ForceHTTPS:         true,
 				AutoStartMachines:  fly.Pointer(true),
 				AutoStopMachines:   fly.Pointer(autostop),
@@ -313,21 +344,48 @@ func (state *launchState) updateConfig(ctx context.Context) {
 				Processes:          []string{"app"},
 			}
 		}
-		state.appConfig.HTTPService.InternalPort = state.Plan.HttpServicePort
+		appConfig.HTTPService.InternalPort = plan.HttpServicePort
 	} else {
-		state.appConfig.HTTPService = nil
+		appConfig.HTTPService = nil
+	}
+
+	// Apply plan-level compute overrides to all compute configurations
+	// Only set fields that haven't already been set (defensive against updateComputeFromDeprecatedGuestFields)
+	if plan.CPUKind != "" {
+		for i := range appConfig.Compute {
+			if isComputeValid(appConfig.Compute[i]) && appConfig.Compute[i].CPUKind == "" {
+				appConfig.Compute[i].CPUKind = plan.CPUKind
+			}
+		}
+	}
+
+	if plan.CPUs != 0 {
+		for i := range appConfig.Compute {
+			if isComputeValid(appConfig.Compute[i]) && appConfig.Compute[i].CPUs == 0 {
+				appConfig.Compute[i].CPUs = plan.CPUs
+			}
+		}
+	}
+
+	if plan.MemoryMB != 0 {
+		for i := range appConfig.Compute {
+			if isComputeValid(appConfig.Compute[i]) && appConfig.Compute[i].MemoryMB == 0 {
+				appConfig.Compute[i].MemoryMB = plan.MemoryMB
+			}
+		}
 	}
 }
 
 // createApp creates the fly.io app for the plan
 func (state *launchState) createApp(ctx context.Context) (*fly.App, error) {
 	apiClient := flyutil.ClientFromContext(ctx)
-	org, err := state.Org(ctx)
+
+	org, err := state.orgCompact(ctx)
 	if err != nil {
 		return nil, err
 	}
 	app, err := apiClient.CreateApp(ctx, fly.CreateAppInput{
-		OrganizationID:  org.ID,
+		OrganizationID:  org.Id,
 		Name:            state.Plan.AppName,
 		PreferredRegion: &state.Plan.RegionCode,
 		Machines:        true,
@@ -336,10 +394,8 @@ func (state *launchState) createApp(ctx context.Context) (*fly.App, error) {
 		return nil, err
 	}
 
-	f, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{AppName: app.Name})
-	if err != nil {
-		return nil, err
-	} else if err := f.WaitForApp(ctx, app.Name); err != nil {
+	f := flapsutil.ClientFromContext(ctx)
+	if err := f.WaitForApp(ctx, app.Name); err != nil {
 		return nil, err
 	}
 
