@@ -10,12 +10,15 @@ import (
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/flypg"
 	"github.com/superfly/flyctl/gql"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	extensions_core "github.com/superfly/flyctl/internal/command/extensions/core"
 	"github.com/superfly/flyctl/internal/command/launch/plan"
 	"github.com/superfly/flyctl/internal/command/mpg"
 	"github.com/superfly/flyctl/internal/command/postgres"
 	"github.com/superfly/flyctl/internal/command/redis"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/flyutil"
+	"github.com/superfly/flyctl/internal/spinner"
 	"github.com/superfly/flyctl/internal/uiex"
 	"github.com/superfly/flyctl/internal/uiexutil"
 	"github.com/superfly/flyctl/iostreams"
@@ -171,6 +174,11 @@ func (state *launchState) createManagedPostgres(ctx context.Context) error {
 		uiexClient = uiexutil.ClientFromContext(ctx)
 	)
 
+	// Check if we should attach to an existing cluster instead of creating a new one
+	if pgPlan.ClusterID != "" {
+		return state.attachToManagedPostgres(ctx, pgPlan.ClusterID)
+	}
+
 	// Get org
 	org, err := state.Org(ctx)
 	if err != nil {
@@ -232,9 +240,16 @@ func (state *launchState) createManagedPostgres(ctx context.Context) error {
 	}
 
 	// Wait for cluster to be ready
-	fmt.Fprintf(io.Out, "Waiting for cluster %s (%s) to be ready...\n", params.Name, response.Data.Id)
-	fmt.Fprintf(io.Out, "This may take up to 15 minutes. If this is taking too long, you can press Ctrl+C to continue with deployment.\n")
-	fmt.Fprintf(io.Out, "You can check the status later with 'fly mpg status' and attach with 'fly mpg attach'.\n")
+	colorize := io.ColorScheme()
+	fmt.Fprintf(io.Out, "%s\n", colorize.Bold(fmt.Sprintf("Waiting for cluster %s (%s) to be ready...", params.Name, response.Data.Id)))
+	fmt.Fprintf(io.Out, "\n%s\n", colorize.Bold("This'll take a few minutes, but you don't have to wait around if you don't want to!"))
+	fmt.Fprintf(io.Out, "To connect your Managed Postgres cluster later just:\n")
+	fmt.Fprintf(io.Out, "  - Press %s to continue with deployment\n", colorize.Purple("Ctrl+C"))
+	fmt.Fprintf(io.Out, "  - Use %s to confirm that your MPG cluster is ready\n", colorize.Purple("fly mpg status"))
+	fmt.Fprintf(io.Out, "  - Use %s to attach to your app\n", colorize.Purple("fly mpg attach"))
+
+	// Start spinner to show progress
+	s := spinner.Run(io, colorize.Yellow("Provisioning your Managed Postgres cluster..."))
 
 	// Create a separate context for the wait loop with 15 minute timeout
 	waitCtx := context.Background()
@@ -273,13 +288,20 @@ func (state *launchState) createManagedPostgres(ctx context.Context) error {
 		retry.OnRetry(func(n uint, err error) {
 			// Log network-related errors and periodic status updates
 			if containsNetworkError(err.Error()) {
+				s.Stop()
 				fmt.Fprintf(io.Out, "Retrying status check due to network issue: %v\n", err)
+				s = spinner.Run(io, colorize.Yellow("Provisioning your Managed Postgres cluster..."))
 			} else if n%10 == 0 && n > 0 { // Log every 10th attempt to show progress
+				s.Stop()
 				fmt.Fprintf(io.Out, "Still waiting for cluster to be ready (attempt %d)...\n", n+1)
+				s = spinner.Run(io, colorize.Yellow("Provisioning your Managed Postgres cluster..."))
 			}
 		}),
 	)
 
+	// Stop the spinner
+	s.Stop()
+
 	// Handle the result
 	if err != nil {
 		// Check if we hit the timeout
@@ -321,12 +343,72 @@ func (state *launchState) createManagedPostgres(ctx context.Context) error {
 		"DATABASE_URL": cluster.Credentials.ConnectionUri,
 	}
 
-	client := flyutil.ClientFromContext(ctx)
-	if _, err := client.SetSecrets(ctx, state.Plan.AppName, secrets); err != nil {
+	flapsClient := flapsutil.ClientFromContext(ctx)
+	if err := appsecrets.Update(ctx, flapsClient, state.Plan.AppName, secrets, nil); err != nil {
 		return fmt.Errorf("failed setting database secrets: %w", err)
 	}
 
-	fmt.Fprintf(io.Out, "Managed Postgres cluster %s is ready and attached to %s\n", response.Data.Id, state.Plan.AppName)
+	fmt.Fprintf(io.Out, "\n%s\n", colorize.Bold(colorize.Green(fmt.Sprintf("Managed Postgres cluster %s is ready and attached to %s", response.Data.Id, state.Plan.AppName))))
+	fmt.Fprintf(io.Out, "The following secret was added to %s:\n  DATABASE_URL=%s\n", state.Plan.AppName, cluster.Credentials.ConnectionUri)
+
+	return nil
+}
+
+// attachToManagedPostgres attaches an existing Managed Postgres cluster to the app
+func (state *launchState) attachToManagedPostgres(ctx context.Context, clusterID string) error {
+	var (
+		io         = iostreams.FromContext(ctx)
+		uiexClient = uiexutil.ClientFromContext(ctx)
+		client     = flyutil.ClientFromContext(ctx)
+	)
+
+	// Get cluster details to verify it exists and get credentials
+	fmt.Fprintf(io.Out, "Attaching to existing Managed Postgres cluster %s...\n", clusterID)
+
+	var cluster uiex.GetManagedClusterResponse
+	err := retry.Do(
+		func() error {
+			var retryErr error
+			cluster, retryErr = uiexClient.GetManagedClusterById(ctx, clusterID)
+			return retryErr
+		},
+		retry.Context(ctx),
+		retry.Attempts(3),
+		retry.Delay(1*time.Second),
+		retry.DelayType(retry.BackOffDelay),
+		retry.OnRetry(func(n uint, err error) {
+			fmt.Fprintf(io.Out, "Retrying cluster lookup (attempt %d) due to: %v\n", n+1, err)
+		}),
+	)
+	if err != nil {
+		return fmt.Errorf("failed retrieving cluster %s: %w", clusterID, err)
+	}
+
+	// Verify the cluster and app are in the same organization
+	app, err := client.GetAppBasic(ctx, state.Plan.AppName)
+	if err != nil {
+		return fmt.Errorf("failed retrieving app %s: %w", state.Plan.AppName, err)
+	}
+
+	clusterOrgSlug := cluster.Data.Organization.Slug
+	appOrgSlug := app.Organization.RawSlug
+
+	if appOrgSlug != clusterOrgSlug {
+		return fmt.Errorf("app %s is in organization %s, but cluster %s is in organization %s. They must be in the same organization to attach",
+			state.Plan.AppName, appOrgSlug, clusterID, clusterOrgSlug)
+	}
+
+	// Set the connection string as a secret
+	secrets := map[string]string{
+		"DATABASE_URL": cluster.Credentials.ConnectionUri,
+	}
+
+	flapsClient := flapsutil.ClientFromContext(ctx)
+	if err := appsecrets.Update(ctx, flapsClient, state.Plan.AppName, secrets, nil); err != nil {
+		return fmt.Errorf("failed setting database secrets: %w", err)
+	}
+
+	fmt.Fprintf(io.Out, "Managed Postgres cluster %s is now attached to %s\n", clusterID, state.Plan.AppName)
 	fmt.Fprintf(io.Out, "The following secret was added to %s:\n  DATABASE_URL=%s\n", state.Plan.AppName, cluster.Credentials.ConnectionUri)
 
 	return nil
@@ -387,6 +469,10 @@ func (state *launchState) createUpstashRedis(ctx context.Context) error {
 		if err != nil {
 			return err
 		}
+		// Filter out deprecated regions
+		regions = lo.Filter(regions, func(r fly.Region, _ int) bool {
+			return !r.Deprecated
+		})
 		for _, code := range redisPlan.ReadReplicas {
 			if region, ok := lo.Find(regions, func(r fly.Region) bool { return r.Code == code }); ok {
 				readReplicaRegions = append(readReplicaRegions, region)
