@@ -11,6 +11,7 @@ import (
 	"strings"
 	"unicode"
 
+	"github.com/samber/lo"
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/appconfig"
@@ -24,6 +25,7 @@ import (
 	"github.com/superfly/flyctl/internal/haikunator"
 	"github.com/superfly/flyctl/internal/launchdarkly"
 	"github.com/superfly/flyctl/internal/prompt"
+	"github.com/superfly/flyctl/internal/uiexutil"
 	"github.com/superfly/flyctl/iostreams"
 	"github.com/superfly/flyctl/scanner"
 )
@@ -105,8 +107,6 @@ func (r *recoverableErrorBuilder) build() string {
 }
 
 func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recoverableErrors *recoverableErrorBuilder) (*LaunchManifest, *planBuildCache, error) {
-	io := iostreams.FromContext(ctx)
-
 	appConfig, copiedConfig, err := determineBaseAppConfig(ctx)
 	if err != nil {
 		return nil, nil, err
@@ -134,12 +134,6 @@ func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recovera
 		if err := appConfig.SetMachinesPlatform(); err != nil {
 			return nil, nil, fmt.Errorf("can not use configuration for Fly Launch, check fly.toml: %w", err)
 		}
-		if flag.GetBool(ctx, "manifest") {
-			fmt.Fprintln(io.ErrOut,
-				"Warning: --manifest does not serialize an entire app configuration.\n"+
-					"Creating a manifest from an existing fly.toml may be a lossy process!",
-			)
-		}
 		if service := appConfig.HTTPService; service != nil {
 			httpServicePort = service.InternalPort
 		} else {
@@ -220,7 +214,7 @@ func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recovera
 		warnedNoCcHa:     false,
 	}
 
-	if planValidateHighAvailability(ctx, lp, org, true) {
+	if planValidateHighAvailability(ctx, lp, org.Billable, true) {
 		buildCache.warnedNoCcHa = true
 	}
 
@@ -236,8 +230,17 @@ func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recovera
 		if !flag.GetBool(ctx, "no-db") {
 			switch srcInfo.DatabaseDesired {
 			case scanner.DatabaseKindPostgres:
-				lp.Postgres = plan.DefaultPostgres(lp, mpgEnabled)
+				lp.Postgres, err = plan.DefaultPostgres(ctx, lp, mpgEnabled)
+				if err != nil {
+					return nil, nil, err
+				}
 				planSource.postgresSource = scannerSource
+
+				// We offer switching to MPG if interactive session and the region is not the same as the MPG region
+				// App should launch in the MPG region
+				if lp.Postgres.ManagedPostgres != nil && lp.Postgres.ManagedPostgres.Region != region.Code {
+					lp.RegionCode = lp.Postgres.ManagedPostgres.Region
+				}
 			case scanner.DatabaseKindMySQL:
 				// TODO
 			case scanner.DatabaseKindSqlite:
@@ -245,9 +248,19 @@ func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recovera
 			}
 		}
 		// Force Postgres provisioning if --db flag is set
-		if flag.GetBool(ctx, "db") {
-			lp.Postgres = plan.DefaultPostgres(lp, mpgEnabled)
+		dbFlag := flag.GetString(ctx, "db")
+		if dbFlag != "" {
+			lp.Postgres, err = plan.DefaultPostgres(ctx, lp, mpgEnabled)
+			if err != nil {
+				return nil, nil, err
+			}
 			planSource.postgresSource = "forced by --db flag"
+
+			// We offer switching to MPG if interactive session and the region is not the same as the MPG region
+			// App should launch in the MPG region
+			if lp.Postgres.ManagedPostgres != nil && lp.Postgres.ManagedPostgres.Region != region.Code {
+				lp.RegionCode = lp.Postgres.ManagedPostgres.Region
+			}
 		}
 		if !flag.GetBool(ctx, "no-redis") && srcInfo.RedisDesired {
 			lp.Redis = plan.DefaultRedis(lp)
@@ -264,9 +277,12 @@ func buildManifest(ctx context.Context, parentConfig *appconfig.Config, recovera
 		lp.Runtime = srcInfo.Runtime
 	}
 
+	appConfig.AppName = lp.AppName
+
 	return &LaunchManifest{
 		Plan:       lp,
 		PlanSource: planSource,
+		Config:     appConfig,
 	}, buildCache, nil
 }
 
@@ -289,9 +305,11 @@ func nudgeTowardsDeploy(ctx context.Context, appName string) (bool, error) {
 	}
 
 	// The user can see the app. Prompt them to deploy.
-	fmt.Fprintf(io.Out, "App '%s' already exists. You can deploy to it with `fly deploy`.\n", appName)
+	colorize := io.ColorScheme()
+	fmt.Fprintln(io.Out)
+	fmt.Fprintf(io.Out, "%s\n", colorize.Yellow(fmt.Sprintf("App '%s' already exists. You can deploy to it using %s.", appName, colorize.Purple("`fly deploy`"))))
 
-	switch confirmed, err := prompt.Confirm(ctx, "Continue launching a new app? "); {
+	switch confirmed, err := prompt.Confirm(ctx, "Do you still want to launch a new app?"); {
 	case err == nil:
 		if !confirmed {
 			// We've redirected the user to use 'fly deploy'
@@ -308,12 +326,10 @@ func nudgeTowardsDeploy(ctx context.Context, appName string) (bool, error) {
 }
 
 func stateFromManifest(ctx context.Context, m LaunchManifest, optionalCache *planBuildCache, recoverableErrors *recoverableErrorBuilder) (*launchState, error) {
-	var (
-		io     = iostreams.FromContext(ctx)
-		client = flyutil.ClientFromContext(ctx)
-	)
+	io := iostreams.FromContext(ctx)
 
-	org, err := client.GetOrganizationRemoteBuilderBySlug(ctx, m.Plan.OrgSlug)
+	uiexClient := uiexutil.ClientFromContext(ctx)
+	org, err := uiexClient.GetOrganization(ctx, m.Plan.OrgSlug)
 	if err != nil {
 		return nil, err
 	}
@@ -321,7 +337,7 @@ func stateFromManifest(ctx context.Context, m LaunchManifest, optionalCache *pla
 	// If we potentially are deploying, launch a remote builder to prepare for deployment.
 	if !flag.GetBool(ctx, "no-deploy") {
 		// TODO: determine if eager remote builder is still required here
-		go imgsrc.EagerlyEnsureRemoteBuilder(ctx, client, org, flag.GetRecreateBuilder(ctx))
+		go imgsrc.EagerlyEnsureRemoteBuilder(ctx, org, flag.GetRecreateBuilder(ctx))
 	}
 
 	var (
@@ -414,6 +430,7 @@ func stateFromManifest(ctx context.Context, m LaunchManifest, optionalCache *pla
 		LaunchManifest: LaunchManifest{
 			m.Plan,
 			m.PlanSource,
+			appConfig,
 		},
 		env: envVars,
 		planBuildCache: planBuildCache{
@@ -432,8 +449,9 @@ func determineBaseAppConfig(ctx context.Context) (*appconfig.Config, bool, error
 
 	existingConfig := appconfig.ConfigFromContext(ctx)
 	if existingConfig != nil {
+		colorize := io.ColorScheme()
 
-		if existingConfig.AppName != "" {
+		if existingConfig.AppName != "" && !flag.IsSpecified(ctx, "copy-config") {
 			fmt.Fprintln(io.Out, "An existing fly.toml file was found for app", existingConfig.AppName)
 		} else {
 			fmt.Fprintln(io.Out, "An existing fly.toml file was found")
@@ -445,7 +463,8 @@ func determineBaseAppConfig(ctx context.Context) (*appconfig.Config, bool, error
 
 		if !flag.IsSpecified(ctx, "copy-config") && !attach && !flag.GetYes(ctx) {
 			var err error
-			copyConfig, err = prompt.Confirm(ctx, "Would you like to copy its configuration to the new app?")
+			copyConfig, err = prompt.Confirm(ctx, colorize.Yellow("Would you like to use this fly.toml configuration for this app?"))
+			fmt.Fprintln(io.Out)
 			switch {
 			case prompt.IsNonInteractive(err) && !flag.GetYes(ctx):
 				return nil, false, err
@@ -534,6 +553,16 @@ func determineAppName(ctx context.Context, parentConfig *appconfig.Config, appCo
 	appName := flag.GetString(ctx, "name")
 	cause := "specified on the command line"
 
+	if flag.GetBool(ctx, "force-name") {
+		if appName == "" {
+			return "", "", flyerr.GenericErr{
+				Err:     "app name required when using --force-name",
+				Suggest: "Specify the app name with the --name flag",
+			}
+		}
+		return appName, cause, nil
+	}
+
 	if !flag.GetBool(ctx, "generate-name") {
 		// --generate-name wasn't specified, so we try to get a name from the config file or directory name.
 		if appName == "" {
@@ -666,6 +695,48 @@ func determineOrg(ctx context.Context, config *appconfig.Config) (*fly.Organizat
 	return &org, "specified on the command line", nil
 }
 
+// Map of  deprecated region codes and their consolidated replacements
+var deprecatedRegionReplacements = map[string]string{
+	"atl": "dfw",
+	"den": "dfw",
+	"mia": "dfw",
+	"gdl": "dfw",
+	"qro": "dfw",
+	"bos": "ewr",
+	"phx": "lax",
+	"sea": "sjc",
+	"yul": "yyz",
+	"waw": "ams",
+	"mad": "cdg",
+	"otp": "fra",
+	"bog": "gru",
+	"gig": "gru",
+	"scl": "gru",
+	"eze": "gru",
+	"hkg": "sin",
+}
+
+// Check if a region is deprecated and return the replacement region
+func remapDeprecatedRegion(ctx context.Context, region *fly.Region) (*fly.Region, error) {
+	if region == nil || !region.Deprecated {
+		return region, nil
+	}
+
+	replacementCode, ok := deprecatedRegionReplacements[region.Code]
+	if !ok {
+		// If there's no definied replacement, return and error
+		return nil, fmt.Errorf("region %s is deprecated. Please use a supported region.", region.Code)
+	}
+
+	// Get the replacement region
+	replacementRegion, err := getRegionByCode(ctx, replacementCode)
+	if err != nil {
+		return nil, fmt.Errorf("failed to get replacement region %s for deprecated region %s: %w", replacementCode, region.Code, err)
+	}
+
+	return replacementRegion, nil
+}
+
 // determineRegion returns the region to use for a new app. In order, it tries:
 //  1. the primary_region field of the config, if one exists
 //  2. the region specified on the command line, if specified
@@ -684,6 +755,15 @@ func determineRegion(ctx context.Context, config *appconfig.Config, paidPlan boo
 	// TODO(allison): does this return paid regions for free orgs?
 	closestRegion, closestRegionErr := client.GetNearestRegion(ctx)
 
+	// Remap the closest region if it's deprecated
+	if closestRegionErr == nil && closestRegion != nil {
+		remappedRegion, remapErr := remapDeprecatedRegion(ctx, closestRegion)
+		if remapErr == nil {
+			closestRegion = remappedRegion
+		}
+		// If remapping fails, it'll use the original region and hit the "unknown region" error
+	}
+
 	if regionCode != "" {
 		region, err := getRegionByCode(ctx, regionCode)
 		if err != nil {
@@ -706,6 +786,11 @@ func getRegionByCode(ctx context.Context, regionCode string) (*fly.Region, error
 		return nil, err
 	}
 
+	// Filter out deprecated regions
+	allRegions = lo.Filter(allRegions, func(r fly.Region, _ int) bool {
+		return !r.Deprecated
+	})
+
 	for _, r := range allRegions {
 		if r.Code == regionCode {
 			return &r, nil
@@ -780,8 +865,8 @@ func determineCompute(ctx context.Context, config *appconfig.Config, srcInfo *sc
 	return []*appconfig.Compute{guestToCompute(guest)}, reason, nil
 }
 
-func planValidateHighAvailability(ctx context.Context, p *plan.LaunchPlan, org *fly.Organization, print bool) bool {
-	if !org.Billable && p.HighAvailability {
+func planValidateHighAvailability(ctx context.Context, p *plan.LaunchPlan, billable, print bool) bool {
+	if !billable && p.HighAvailability {
 		if print {
 			fmt.Fprintln(iostreams.FromContext(ctx).ErrOut, "Warning: This organization has no payment method, turning off high availability")
 		}
