@@ -10,6 +10,7 @@ import (
 	"github.com/samber/lo"
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/gql"
+	"github.com/superfly/flyctl/internal/appconfig"
 	extensions_core "github.com/superfly/flyctl/internal/command/extensions/core"
 	"github.com/superfly/flyctl/internal/command/launch/plan"
 	"github.com/superfly/flyctl/internal/flag"
@@ -30,9 +31,24 @@ type launchPlanSource struct {
 	sentrySource   string
 }
 
+// newDefaultPlanSource creates a launchPlanSource with all fields set to the provided source description
+func newDefaultPlanSource(source string) *launchPlanSource {
+	return &launchPlanSource{
+		appNameSource:  source,
+		regionSource:   source,
+		orgSource:      source,
+		computeSource:  source,
+		postgresSource: source,
+		redisSource:    source,
+		tigrisSource:   source,
+		sentrySource:   source,
+	}
+}
+
 type LaunchManifest struct {
-	Plan       *plan.LaunchPlan
-	PlanSource *launchPlanSource
+	Plan       *plan.LaunchPlan  `json:"plan,omitempty"`
+	PlanSource *launchPlanSource `json:"plan_source,omitempty"`
+	Config     *appconfig.Config `json:"config,omitempty"`
 }
 
 type launchState struct {
@@ -56,6 +72,15 @@ func cacheGrab[T any](cache map[string]interface{}, key string, cb func() (T, er
 	return val, nil
 }
 
+func (state *launchState) orgCompact(ctx context.Context) (*gql.GetOrganizationOrganization, error) {
+	client := flyutil.ClientFromContext(ctx).GenqClient()
+	res, err := gql.GetOrganization(ctx, client, state.Plan.OrgSlug)
+	if err != nil {
+		return nil, fmt.Errorf("failed to get org %q for state: %w", state.Plan.OrgSlug, err)
+	}
+	return &res.Organization, nil
+}
+
 func (state *launchState) Org(ctx context.Context) (*fly.Organization, error) {
 	apiClient := flyutil.ClientFromContext(ctx)
 	return cacheGrab(state.cache, "org,"+state.Plan.OrgSlug, func() (*fly.Organization, error) {
@@ -70,6 +95,10 @@ func (state *launchState) Region(ctx context.Context) (fly.Region, error) {
 		if err != nil {
 			return nil, err
 		}
+		// Filter out deprecated regions
+		regions = lo.Filter(regions, func(r fly.Region, _ int) bool {
+			return !r.Deprecated
+		})
 		return regions, nil
 	})
 	if err != nil {
@@ -103,7 +132,7 @@ func (state *launchState) PlanSummary(ctx context.Context) (string, error) {
 		guestStr += fmt.Sprintf(", %d more", len(state.appConfig.Compute)-1)
 	}
 
-	org, err := state.Org(ctx)
+	org, err := state.orgCompact(ctx)
 	if err != nil {
 		return "", err
 	}
@@ -118,7 +147,7 @@ func (state *launchState) PlanSummary(ctx context.Context) (string, error) {
 		return "", err
 	}
 
-	redisStr, err := describeRedisPlan(ctx, state.Plan.Redis, org)
+	redisStr, err := describeRedisPlan(ctx, state.Plan.Redis)
 	if err != nil {
 		return "", err
 	}
@@ -160,6 +189,9 @@ func (state *launchState) PlanSummary(ctx context.Context) (string, error) {
 		}
 	}
 
+	io := iostreams.FromContext(ctx)
+	colorize := io.ColorScheme()
+
 	ret := ""
 	for _, row := range rows {
 
@@ -170,7 +202,7 @@ func (state *launchState) PlanSummary(ctx context.Context) (string, error) {
 		labelSpaces := strings.Repeat(" ", colLengths[0]-len(label))
 		valueSpaces := strings.Repeat(" ", colLengths[1]-len(value))
 
-		ret += fmt.Sprintf("%s: %s%s %s(%s)\n", label, labelSpaces, value, valueSpaces, source)
+		ret += fmt.Sprintf("%s: %s%s %s(%s)\n", label, labelSpaces, colorize.Purple(value), valueSpaces, colorize.Yellow(source))
 	}
 	return ret, nil
 }
@@ -183,7 +215,7 @@ func (state *launchState) validateExtensions(ctx context.Context) error {
 	io := iostreams.FromContext(ctx)
 	noConfirm := !io.IsInteractive() || flag.GetBool(ctx, "now")
 
-	org, err := state.Org(ctx)
+	org, err := state.orgCompact(ctx)
 	if err != nil {
 		return err
 	}
