@@ -12,6 +12,7 @@ import (
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flapsutil"
@@ -108,7 +109,7 @@ func runMachineClone(ctx context.Context) (err error) {
 		splitVolumeInfo := strings.Split(volumeInfo, ":")
 		volID := splitVolumeInfo[0]
 
-		vol, err = flapsClient.GetVolume(ctx, volID)
+		vol, err = flapsClient.GetVolume(ctx, appName, volID)
 		if err != nil {
 			return fmt.Errorf("could not get existing volume: %w", err)
 		}
@@ -183,7 +184,7 @@ func runMachineClone(ctx context.Context) (err error) {
 		var vol *fly.Volume
 		if volID != "" {
 			fmt.Fprintf(out, "Attaching existing volume %s\n", colorize.Bold(volID))
-			vol, err = flapsClient.GetVolume(ctx, volID)
+			vol, err = flapsClient.GetVolume(ctx, appName, volID)
 			if err != nil {
 				return fmt.Errorf("could not get existing volume: %w", err)
 			}
@@ -195,7 +196,7 @@ func runMachineClone(ctx context.Context) (err error) {
 			var snapshotID *string
 			switch snapID := flag.GetString(ctx, "from-snapshot"); snapID {
 			case "last":
-				snapshots, err := flapsClient.GetVolumeSnapshots(ctx, mnt.Volume)
+				snapshots, err := flapsClient.GetVolumeSnapshots(ctx, appName, mnt.Volume)
 				if err != nil {
 					return err
 				}
@@ -224,7 +225,7 @@ func runMachineClone(ctx context.Context) (err error) {
 				ComputeRequirements: targetConfig.Guest,
 				ComputeImage:        targetConfig.Image,
 			}
-			vol, err = flapsClient.CreateVolume(ctx, volInput)
+			vol, err = flapsClient.CreateVolume(ctx, appName, volInput)
 			if err != nil {
 				return err
 			}
@@ -255,16 +256,22 @@ func runMachineClone(ctx context.Context) (err error) {
 		)
 	}
 
+	minvers, err := appsecrets.GetMinvers(appName)
+	if err != nil {
+		return err
+	}
+
 	input := fly.LaunchMachineInput{
-		Name:       flag.GetString(ctx, "name"),
-		Region:     region,
-		Config:     targetConfig,
-		SkipLaunch: len(targetConfig.Standbys) > 0,
+		Name:              flag.GetString(ctx, "name"),
+		Region:            region,
+		Config:            targetConfig,
+		SkipLaunch:        len(targetConfig.Standbys) > 0,
+		MinSecretsVersion: minvers,
 	}
 
 	fmt.Fprintf(out, "Provisioning a new Machine with image %s...\n", source.Config.Image)
 
-	launchedMachine, err := flapsClient.Launch(ctx, input)
+	launchedMachine, err := flapsClient.Launch(ctx, appName, input)
 	if err != nil {
 		return err
 	}
@@ -279,12 +286,12 @@ func runMachineClone(ctx context.Context) (err error) {
 		fmt.Fprintf(out, "  Waiting for Machine %s to start...\n", colorize.Bold(launchedMachine.ID))
 
 		// wait for a machine to be started
-		err = mach.WaitForStartOrStop(ctx, launchedMachine, "start", time.Minute*5)
+		err = mach.WaitForStartOrStop(ctx, appName, launchedMachine, "start", time.Minute*5)
 		if err != nil {
 			return err
 		}
 
-		if err = watch.MachinesChecks(ctx, []*fly.Machine{launchedMachine}); err != nil {
+		if err = watch.MachinesChecks(ctx, appName, []*fly.Machine{launchedMachine}); err != nil {
 			return fmt.Errorf("error while watching health checks: %w", err)
 		}
 	}
