@@ -56,17 +56,17 @@ This command requires a machine to be in a stopped or suspended state unless the
 }
 
 func runMachineDestroy(ctx context.Context) (err error) {
-	ctx, err = buildContextFromAppName(ctx, appconfig.NameFromContext(ctx))
-	if err != nil {
-		return err
+	image := strings.TrimSpace(flag.GetString(ctx, "image"))
+
+	if image != "" && appconfig.NameFromContext(ctx) == "" {
+		return fmt.Errorf("--image requires --app flag or must be run from app directory")
 	}
 
 	var machinesToBeDeleted []*fly.Machine
-	image := strings.TrimSpace(flag.GetString(ctx, "image"))
 
 	switch {
 	case image != "":
-		machines, err := flapsutil.ClientFromContext(ctx).ListActive(ctx)
+		machines, err := flapsutil.ClientFromContext(ctx).ListActive(ctx, appconfig.NameFromContext(ctx))
 		if err != nil {
 			return err
 		}
@@ -113,7 +113,9 @@ func runMachineDestroy(ctx context.Context) (err error) {
 		return nil
 	}
 
-	machines, release, err := mach.AcquireLeases(ctx, machinesToBeDeleted)
+	appName := appconfig.NameFromContext(ctx)
+
+	machines, release, err := mach.AcquireLeases(ctx, appName, machinesToBeDeleted)
 	defer release()
 	if err != nil {
 		return err
@@ -144,7 +146,7 @@ func singleDestroyRun(ctx context.Context, machine *fly.Machine) error {
 		return fmt.Errorf("could not get app '%s': %w", appName, err)
 	}
 
-	err = Destroy(ctx, app, machine, force)
+	err = Destroy(ctx, app.Name, machine, force)
 	if err != nil {
 		return err
 	}
@@ -154,7 +156,7 @@ func singleDestroyRun(ctx context.Context, machine *fly.Machine) error {
 	return nil
 }
 
-func Destroy(ctx context.Context, app *fly.AppCompact, machine *fly.Machine, force bool) error {
+func Destroy(ctx context.Context, appName string, machine *fly.Machine, force bool) error {
 	var (
 		out         = iostreams.FromContext(ctx).Out
 		flapsClient = flapsutil.ClientFromContext(ctx)
@@ -181,7 +183,7 @@ func Destroy(ctx context.Context, app *fly.AppCompact, machine *fly.Machine, for
 	}
 	fmt.Fprintf(out, "machine %s was found and is currently in %s state, attempting to destroy...\n", machine.ID, machine.State)
 
-	err := flapsClient.Destroy(ctx, input, machine.LeaseNonce)
+	err := flapsClient.Destroy(ctx, appName, input, machine.LeaseNonce)
 	if err != nil {
 		if err := rewriteMachineNotFoundErrors(ctx, err, machine.ID); err != nil {
 			return err
@@ -190,7 +192,7 @@ func Destroy(ctx context.Context, app *fly.AppCompact, machine *fly.Machine, for
 	}
 
 	// Best effort post-deletion hook.
-	runOnDeletionHook(ctx, app, machine)
+	runOnDeletionHook(ctx, appName, machine)
 
 	return nil
 }
