@@ -14,10 +14,12 @@ import (
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
+	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/cmdutil"
 	"github.com/superfly/flyctl/internal/command"
+	"github.com/superfly/flyctl/internal/command/ips"
 	"github.com/superfly/flyctl/internal/command/ssh"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
@@ -107,7 +109,7 @@ var sharedFlags = flag.Set{
 	},
 	flag.String{
 		Name:        "schedule",
-		Description: `Schedule a Machine run at hourly, daily and monthly intervals`,
+		Description: `Schedule a Machine run at hourly, daily, weekly and monthly intervals`,
 	},
 	flag.Bool{
 		Name:        "skip-dns-registration",
@@ -375,20 +377,19 @@ func runMachineRun(ctx context.Context) error {
 		},
 	}
 
-	input := fly.LaunchMachineInput{
-		Name:   flag.GetString(ctx, "name"),
-		Region: flag.GetString(ctx, "region"),
-		LSVD:   flag.GetBool(ctx, "lsvd"),
+	minvers, err := appsecrets.GetMinvers(app.Name)
+	if err != nil {
+		return err
 	}
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppCompact: app,
-		AppName:    app.Name,
-	})
-	if err != nil {
-		return fmt.Errorf("could not make API client: %w", err)
+	input := fly.LaunchMachineInput{
+		Name:              flag.GetString(ctx, "name"),
+		Region:            flag.GetString(ctx, "region"),
+		LSVD:              flag.GetBool(ctx, "lsvd"),
+		MinSecretsVersion: minvers,
 	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
+
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	imageOrPath := flag.FirstArg(ctx)
 	if imageOrPath == "" && shell {
@@ -425,7 +426,7 @@ func runMachineRun(ctx context.Context) error {
 	input.SkipLaunch = (len(machineConf.Standbys) > 0 || isCreate)
 	input.Config = machineConf
 
-	machine, err := flapsClient.Launch(ctx, input)
+	machine, err := flapsClient.Launch(ctx, app.Name, input)
 	if err != nil {
 		return fmt.Errorf("could not launch machine: %w", err)
 	}
@@ -455,14 +456,14 @@ func runMachineRun(ctx context.Context) error {
 
 	s.Start()
 	// wait for machine to be started
-	err = mach.WaitForStartOrStop(ctx, machine, "start", time.Minute*5)
+	err = mach.WaitForStartOrStop(ctx, app.Name, machine, "start", time.Minute*5)
 	s.Stop()
 	if err != nil {
 		return err
 	}
 
 	if interact {
-		_, dialer, err := ssh.BringUpAgent(ctx, client, app, *network, false)
+		_, dialer, err := agent.BringUpAgent(ctx, client, app, *network, false)
 		if err != nil {
 			return err
 		}
@@ -488,7 +489,7 @@ func runMachineRun(ctx context.Context) error {
 
 		err = ssh.Console(ctx, sshClient, flag.GetString(ctx, "command"), true, "")
 		if destroy {
-			err = soManyErrors("console", err, "destroy machine", Destroy(ctx, app, machine, true))
+			err = soManyErrors("console", err, "destroy machine", Destroy(ctx, app.Name, machine, true))
 		}
 
 		if err != nil {
@@ -503,7 +504,7 @@ func runMachineRun(ctx context.Context) error {
 	if !flag.GetDetach(ctx) {
 		fmt.Fprintln(io.Out, colorize.Green("==> "+"Monitoring health checks"))
 
-		if err := watch.MachinesChecks(ctx, []*fly.Machine{machine}); err != nil {
+		if err := watch.MachinesChecks(ctx, app.Name, []*fly.Machine{machine}); err != nil {
 			return err
 		}
 		fmt.Fprintln(io.Out)
@@ -512,6 +513,10 @@ func runMachineRun(ctx context.Context) error {
 	fmt.Fprintf(io.Out, "Machine started, you can connect via the following private ip\n")
 	fmt.Fprintf(io.Out, "  %s\n", privateIP)
 
+	// We created a new machine, this might change how many app-scoped egress IPs are needed
+	// But only check the relevant region
+	ips.SanityCheckAppScopedEgressIps(ctx, map[string]any{machine.Region: nil}, nil, nil, "")
+
 	return nil
 }
 
@@ -548,10 +553,8 @@ func getOrCreateEphemeralShellApp(ctx context.Context, client flyutil.Client) (*
 			return nil, fmt.Errorf("create interactive shell app: %w", err)
 		}
 
-		f, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{AppName: appc.Name})
-		if err != nil {
-			return nil, err
-		} else if err := f.WaitForApp(ctx, appc.Name); err != nil {
+		f := flapsutil.ClientFromContext(ctx)
+		if err := f.WaitForApp(ctx, appc.Name); err != nil {
 			return nil, err
 		}
 	}
@@ -597,10 +600,8 @@ func createApp(ctx context.Context, message, name string, client flyutil.Client)
 		return nil, err
 	}
 
-	f, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{AppName: app.Name})
-	if err != nil {
-		return nil, err
-	} else if err := f.WaitForApp(ctx, app.Name); err != nil {
+	f := flapsutil.ClientFromContext(ctx)
+	if err := f.WaitForApp(ctx, app.Name); err != nil {
 		return nil, err
 	}
 
@@ -807,7 +808,7 @@ func determineMachineConfig(
 		return machineConf, errors.New("invalid restart provided")
 	}
 
-	machineConf.Mounts, err = command.DetermineMounts(ctx, machineConf.Mounts, input.region)
+	machineConf.Mounts, err = command.DetermineMounts(ctx, input.appName, machineConf.Mounts, input.region)
 	if err != nil {
 		return machineConf, err
 	}
