@@ -95,6 +95,16 @@ func runMachineStatus(ctx context.Context) (err error) {
 
 	mConfig := machine.GetConfig()
 
+	// When -d/--display-config is set, print only the machine config as JSON and return.
+	if flag.GetBool(ctx, "display-config") {
+		prettyConfig, err := json.MarshalIndent(mConfig, "", "  ")
+		if err != nil {
+			return fmt.Errorf("failed to marshal machine config: %w", err)
+		}
+		_, _ = fmt.Fprintln(io.Out, string(prettyConfig))
+		return nil
+	}
+
 	fmt.Fprintf(io.Out, "Machine ID: %s\n", machine.ID)
 	fmt.Fprintf(io.Out, "Instance ID: %s\n", machine.InstanceID)
 	fmt.Fprintf(io.Out, "State: %s\n", machine.State)
@@ -121,7 +131,7 @@ func runMachineStatus(ctx context.Context) (err error) {
 		},
 	}
 
-	var cols []string = []string{"ID", "Instance ID", "State", "Image", "Name", "Private IP", "Region", "Process Group", "CPU Kind", "vCPUs", "Memory", "Created", "Updated", "Entrypoint", "Command"}
+	var cols = []string{"ID", "Instance ID", "State", "Image", "Name", "Private IP", "Region", "Process Group", "CPU Kind", "vCPUs", "Memory", "Created", "Updated", "Entrypoint", "Command"}
 
 	if len(mConfig.Mounts) > 0 {
 		cols = append(cols, "Volume")
