@@ -11,6 +11,7 @@ import (
 	"github.com/superfly/flyctl/iostreams"
 
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flyerr"
@@ -66,6 +67,9 @@ func newUpdate() *cobra.Command {
 			Description: "Container to update with the new image, files, etc; defaults to \"app\" or the first container in the config.",
 			Hidden:      false,
 		},
+		flag.BuildkitAddr(),
+		flag.BuildkitImage(),
+		flag.Buildkit(),
 	)
 
 	cmd.Args = cobra.RangeArgs(0, 1)
@@ -98,7 +102,7 @@ func runUpdate(ctx context.Context) (err error) {
 	}
 
 	// Acquire lease
-	machine, releaseLeaseFunc, err := mach.AcquireLease(ctx, machine)
+	machine, releaseLeaseFunc, err := mach.AcquireLease(ctx, appName, machine)
 	defer releaseLeaseFunc()
 	if err != nil {
 		return err
@@ -142,16 +146,22 @@ func runUpdate(ctx context.Context) (err error) {
 		}
 	}
 
+	minvers, err := appsecrets.GetMinvers(appName)
+	if err != nil {
+		return err
+	}
+
 	// Perform update
 	input := &fly.LaunchMachineInput{
-		Name:             machine.Name,
-		Region:           machine.Region,
-		Config:           machineConf,
-		SkipLaunch:       len(machineConf.Standbys) > 0 || skipStart,
-		SkipHealthChecks: skipHealthChecks,
-		Timeout:          flag.GetInt(ctx, "wait-timeout"),
+		Name:              machine.Name,
+		Region:            machine.Region,
+		Config:            machineConf,
+		SkipLaunch:        len(machineConf.Standbys) > 0 || skipStart,
+		SkipHealthChecks:  skipHealthChecks,
+		Timeout:           flag.GetInt(ctx, "wait-timeout"),
+		MinSecretsVersion: minvers,
 	}
-	if err := mach.Update(ctx, machine, input); err != nil {
+	if err := mach.Update(ctx, appName, machine, input); err != nil {
 		var timeoutErr mach.WaitTimeoutErr
 		if errors.As(err, &timeoutErr) {
 			return flyerr.GenericErr{
@@ -167,7 +177,7 @@ func runUpdate(ctx context.Context) (err error) {
 	if !(input.SkipLaunch || flag.GetDetach(ctx)) {
 		fmt.Fprintln(io.Out, colorize.Green("==> "+"Monitoring health checks"))
 
-		if err := watch.MachinesChecks(ctx, []*fly.Machine{machine}); err != nil {
+		if err := watch.MachinesChecks(ctx, appName, []*fly.Machine{machine}); err != nil {
 			return err
 		}
 		fmt.Fprintln(io.Out)
