@@ -10,7 +10,6 @@ import (
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	"github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
@@ -19,10 +18,6 @@ import (
 	"github.com/superfly/flyctl/iostreams"
 )
 
-// Hardcoded list of regions with GPUs
-// TODO: fetch this list from the graphql endpoint once it is there
-var gpuRegions = []string{"iad", "sjc", "syd", "ams"}
-
 const RegionsCommandDesc = `View a list of regions where Fly has datacenters.
 'Capacity' shows how many performance-1x VMs can currently be launched in each region.
 `
@@ -42,14 +37,18 @@ func newRegions() (cmd *cobra.Command) {
 }
 
 func runRegions(ctx context.Context) error {
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{})
-	if err != nil {
-		return err
-	}
-	regions, err := flapsClient.GetRegions(ctx, "")
+	flapsClient := flapsutil.ClientFromContext(ctx)
+	regionsRes, err := flapsClient.GetRegions(ctx)
 	if err != nil {
 		return fmt.Errorf("failed retrieving regions: %w", err)
 	}
+	regions := regionsRes.Regions
+
+	// Filter out deprecated regions
+	regions = lo.Filter(regions, func(r fly.Region, _ int) bool {
+		return !r.Deprecated
+	})
+
 	sort.Slice(regions, func(i, j int) bool {
 		return regions[i].Name < regions[j].Name
 	})
@@ -69,32 +68,16 @@ func runRegions(ctx context.Context) error {
 		rows = append(rows, []string{""})
 		rows = append(rows, []string{io.ColorScheme().Underline(key.String())})
 		for _, region := range regionGroup {
-			gateway := ""
-			if region.GatewayAvailable {
-				gateway = "✓"
-			}
-			paidPlan := ""
-			if region.RequiresPaidPlan {
-				paidPlan = "✓"
-			}
-			gpuAvailable := ""
-			if slices.Contains(gpuRegions, region.Code) {
-				gpuAvailable = "✓"
-			}
-
 			capacity := fmt.Sprint(region.Capacity)
 			capacity = io.ColorScheme().RedGreenGradient(capacity, float64(region.Capacity)/1000)
 
 			rows = append(rows, []string{
 				region.Name,
 				region.Code,
-				gateway,
-				gpuAvailable,
 				capacity,
-				paidPlan,
 			})
 		}
 	}
 
-	return render.Table(out, "", rows, "Name", "Code", "Gateway", "GPUs", "Capacity", "Launch Plan+")
+	return render.Table(out, "", rows, "Name", "Code", "Capacity")
 }
