@@ -7,6 +7,7 @@ import (
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/apps"
 	"github.com/superfly/flyctl/internal/flag"
@@ -59,21 +60,21 @@ func runAddFlycast(ctx context.Context) error {
 		return err
 	}
 
-	if err := doAddFlycast(ctx); err != nil {
+	if err := doAddFlycast(ctx, appName); err != nil {
 		return err
 	}
 
 	return nil
 }
 
-func doAddFlycast(ctx context.Context) error {
-	machines, err := mach.ListActive(ctx)
+func doAddFlycast(ctx context.Context, appName string) error {
+	machines, err := mach.ListActive(ctx, appName)
 	if err != nil {
 		return fmt.Errorf("machines could not be retrieved %w", err)
 	}
 
-	var bouncerPort int = 5432
-	var pgPort int = 5433
+	var bouncerPort = 5432
+	var pgPort = 5433
 	for _, machine := range machines {
 		for _, service := range machine.Config.Services {
 			if service.InternalPort == 5432 || service.InternalPort == 5433 {
@@ -124,8 +125,14 @@ func doAddFlycast(ctx context.Context) error {
 			},
 		}
 
-		err = mach.Update(ctx, machine, &fly.LaunchMachineInput{
-			Config: conf,
+		minvers, err := appsecrets.GetMinvers(appName)
+		if err != nil {
+			return err
+		}
+
+		err = mach.Update(ctx, appName, machine, &fly.LaunchMachineInput{
+			Config:            conf,
+			MinSecretsVersion: minvers,
 		})
 		if err != nil {
 			return err
