@@ -7,9 +7,9 @@ import (
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/flypg"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/iostreams"
 
@@ -86,14 +86,9 @@ func runBackupRestore(ctx context.Context) error {
 		destAppName = flag.FirstArg(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return fmt.Errorf("failed to initialize flaps client: %w", err)
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, appName)
 	if err != nil {
 		return fmt.Errorf("list of machines could not be retrieved: %w", err)
 	}
@@ -112,7 +107,7 @@ func runBackupRestore(ctx context.Context) error {
 		return fmt.Errorf("backups are only supported on Flexclusters")
 	}
 
-	enabled, err := isBackupEnabled(ctx, appName)
+	enabled, err := isBackupEnabled(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
@@ -133,7 +128,7 @@ func runBackupRestore(ctx context.Context) error {
 		Cmd: "bash -c \"echo $S3_ARCHIVE_CONFIG\"",
 	}
 
-	out, err := flapsClient.Exec(ctx, leader.ID, in)
+	out, err := flapsClient.Exec(ctx, appName, leader.ID, in)
 	if err != nil {
 		return err
 	}
@@ -216,14 +211,9 @@ func runBackupCreate(ctx context.Context) error {
 		appName = appconfig.NameFromContext(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return fmt.Errorf("list of machines could not be retrieved: %w", err)
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, appName)
 	if err != nil {
 		return err
 	}
@@ -242,7 +232,7 @@ func runBackupCreate(ctx context.Context) error {
 		return fmt.Errorf("backups are only supported on Flexclusters")
 	}
 
-	enabled, err := isBackupEnabled(ctx, appName)
+	enabled, err := isBackupEnabled(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
@@ -270,7 +260,7 @@ func runBackupCreate(ctx context.Context) error {
 		cmd += " -n " + name
 	}
 
-	return ExecOnLeader(ctx, flapsClient, cmd)
+	return ExecOnLeader(ctx, flapsClient, appName, cmd)
 }
 
 func newBackupEnable() *cobra.Command {
@@ -307,12 +297,14 @@ func runBackupEnable(ctx context.Context) error {
 		return err
 	}
 
+	flapsClient := flapsutil.ClientFromContext(ctx)
+
 	if !app.IsPostgresApp() {
 		return fmt.Errorf("app %s is not a postgres app", appName)
 	}
 
 	// Check to see if backups are already enabled
-	enabled, err := isBackupEnabled(ctx, appName)
+	enabled, err := isBackupEnabled(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
@@ -322,14 +314,7 @@ func runBackupEnable(ctx context.Context) error {
 		return fmt.Errorf("backups are already enabled")
 	}
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return fmt.Errorf("failed to initialize flaps client: %w", err)
-	}
-
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, appName)
 	if err != nil {
 		return err
 	}
@@ -374,7 +359,7 @@ func runBackupEnable(ctx context.Context) error {
 		flypg.BarmanSecretName: pgInput.BarmanSecret,
 	}
 
-	if _, err := client.SetSecrets(ctx, appName, secrets); err != nil {
+	if err := appsecrets.Update(ctx, flapsClient, appName, secrets, nil); err != nil {
 		return fmt.Errorf("failed to set secrets: %w", err)
 	}
 
@@ -409,14 +394,9 @@ func runBackupList(ctx context.Context) error {
 		appName = appconfig.NameFromContext(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return fmt.Errorf("list of machines could not be retrieved: %w", err)
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, appName)
 	if err != nil {
 		return err
 	}
@@ -431,7 +411,7 @@ func runBackupList(ctx context.Context) error {
 		return fmt.Errorf("backups are only supported on Flexclusters")
 	}
 
-	enabled, err := isBackupEnabled(ctx, appName)
+	enabled, err := isBackupEnabled(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
@@ -444,7 +424,7 @@ func runBackupList(ctx context.Context) error {
 		return err
 	}
 
-	return ExecOnMachine(ctx, flapsClient, machine.ID, "flexctl backup list")
+	return ExecOnMachine(ctx, flapsClient, appName, machine.ID, "flexctl backup list")
 }
 
 func resolveRestoreTarget(ctx context.Context) string {
@@ -465,12 +445,8 @@ func resolveRestoreTarget(ctx context.Context) string {
 	return target
 }
 
-func isBackupEnabled(ctx context.Context, appName string) (bool, error) {
-	var (
-		client = flyutil.ClientFromContext(ctx)
-	)
-
-	secrets, err := client.GetAppSecrets(ctx, appName)
+func isBackupEnabled(ctx context.Context, flapsClient flapsutil.FlapsClient, appName string) (bool, error) {
+	secrets, err := appsecrets.List(ctx, flapsClient, appName)
 	if err != nil {
 		return false, err
 	}
@@ -556,14 +532,9 @@ func runBackupConfigShow(ctx context.Context) error {
 		appName = appconfig.NameFromContext(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return fmt.Errorf("failed to initialize flaps client: %w", err)
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, appName)
 	if err != nil {
 		return fmt.Errorf("list of machines could not be retrieved: %w", err)
 	}
@@ -576,7 +547,7 @@ func runBackupConfigShow(ctx context.Context) error {
 		return fmt.Errorf("backups are only supported on Flexclusters")
 	}
 
-	enabled, err := isBackupEnabled(ctx, appName)
+	enabled, err := isBackupEnabled(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
@@ -590,7 +561,7 @@ func runBackupConfigShow(ctx context.Context) error {
 		return err
 	}
 
-	return ExecOnLeader(ctx, flapsClient, "flexctl backup config show")
+	return ExecOnLeader(ctx, flapsClient, appName, "flexctl backup config show")
 }
 
 func runBackupConfigUpdate(ctx context.Context) error {
@@ -598,14 +569,9 @@ func runBackupConfigUpdate(ctx context.Context) error {
 		appName = appconfig.NameFromContext(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return fmt.Errorf("failed to initialize flaps client: %w", err)
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, appName)
 	if err != nil {
 		return fmt.Errorf("list of machines could not be retrieved: %w", err)
 	}
@@ -623,7 +589,7 @@ func runBackupConfigUpdate(ctx context.Context) error {
 		return err
 	}
 
-	enabled, err := isBackupEnabled(ctx, appName)
+	enabled, err := isBackupEnabled(ctx, flapsClient, appName)
 	if err != nil {
 		return err
 	}
@@ -650,5 +616,5 @@ func runBackupConfigUpdate(ctx context.Context) error {
 		command += " --minimum-redundancy " + flag.GetString(ctx, "minimum-redundancy")
 	}
 
-	return ExecOnLeader(ctx, flapsClient, command)
+	return ExecOnLeader(ctx, flapsClient, appName, command)
 }
