@@ -10,9 +10,9 @@ import (
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/appsecrets"
 	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/apps"
@@ -99,13 +99,7 @@ func runBarmanCreate(ctx context.Context) error {
 		appName = appconfig.NameFromContext(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	// pre-fetch platform regions for later use
 	prompt.PlatformRegions(ctx)
@@ -216,7 +210,7 @@ func runBarmanCreate(ctx context.Context) error {
 	}
 
 	if *volInput.SizeGb == 0 {
-		otherVolumes, err := flapsClient.GetVolumes(ctx)
+		otherVolumes, err := flapsClient.GetVolumes(ctx, appName)
 		if err != nil {
 			return err
 		}
@@ -235,7 +229,7 @@ func runBarmanCreate(ctx context.Context) error {
 
 	fmt.Fprintf(io.Out, "Provisioning volume with %dGB\n", volInput.SizeGb)
 
-	vol, err = flapsClient.CreateVolume(ctx, volInput)
+	vol, err = flapsClient.CreateVolume(ctx, appName, volInput)
 	if err != nil {
 		return fmt.Errorf("failed to create volume: %w", err)
 	}
@@ -245,15 +239,21 @@ func runBarmanCreate(ctx context.Context) error {
 		Path:   volumePath,
 	})
 
+	minvers, err := appsecrets.GetMinvers(appName)
+	if err != nil {
+		return err
+	}
+
 	launchInput := fly.LaunchMachineInput{
-		Name:   "barman",
-		Region: volInput.Region,
-		Config: &machineConfig,
+		Name:              "barman",
+		Region:            volInput.Region,
+		Config:            &machineConfig,
+		MinSecretsVersion: minvers,
 	}
 
 	fmt.Fprintf(io.Out, "Provisioning barman machine with image %s\n", machineConfig.Image)
 
-	machine, err := flapsClient.Launch(ctx, launchInput)
+	machine, err := flapsClient.Launch(ctx, appName, launchInput)
 	if err != nil {
 		return err
 	}
@@ -262,7 +262,7 @@ func runBarmanCreate(ctx context.Context) error {
 
 	waitTimeout := time.Minute * 5
 
-	err = mach.WaitForStartOrStop(ctx, machine, "start", waitTimeout)
+	err = mach.WaitForStartOrStop(ctx, appName, machine, "start", waitTimeout)
 	if err != nil {
 		return err
 	}
@@ -468,7 +468,7 @@ func runConsole(ctx context.Context, cmd string) error {
 		return fmt.Errorf("get app: %w", err)
 	}
 
-	agentclient, dialer, err := ssh.BringUpAgent(ctx, client, app, "", false)
+	agentclient, dialer, err := agent.BringUpAgent(ctx, client, app, "", false)
 	if err != nil {
 		return err
 	}
@@ -520,15 +520,9 @@ func lookupAddress(ctx context.Context, cli *agent.Client, dialer agent.Dialer,
 
 func addrForMachines(ctx context.Context, app *fly.AppCompact, console bool) (addr string, err error) {
 	// out := iostreams.FromContext(ctx).Out
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppCompact: app,
-		AppName:    app.Name,
-	})
-	if err != nil {
-		return "", err
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, app.Name)
 	if err != nil {
 		return "", err
 	}
