@@ -88,7 +88,7 @@ func runMachineListDbs(ctx context.Context, app *fly.AppCompact) error {
 		MinPostgresStandaloneVersion = "0.0.7"
 	)
 
-	machines, err := mach.ListActive(ctx)
+	machines, err := mach.ListActive(ctx, app.Name)
 	if err != nil {
 		return fmt.Errorf("machines could not be retrieved %w", err)
 	}
