@@ -105,7 +105,7 @@ func runListEvents(ctx context.Context) error {
 		return err
 	}
 
-	machines, err := mach.ListActive(ctx)
+	machines, err := mach.ListActive(ctx, appName)
 	if err != nil {
 		return err
 	}
