@@ -9,19 +9,19 @@ import (
 	"github.com/hashicorp/go-version"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/flypg"
 	"github.com/superfly/flyctl/internal/command"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	mach "github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/iostreams"
 )
 
 func New() *cobra.Command {
 	const (
-		short      = `Deprecated: Unmanaged Postgres cluster commands'`
-		deprecated = "DEPRECATED: Unmanaged Fly Postgres is deprecated in favor of 'fly mpg' (Managed Postgres).\n" +
+		short  = `Unmanaged Postgres cluster commands`
+		notice = "Unmanaged Fly Postgres is not supported by Fly.io Support and users are responsible for operations, management, and disaster recovery. If you'd like a managed, supported solution, try 'fly mpg' (Managed Postgres).\n" +
 			"Please visit https://fly.io/docs/mpg/overview/ for more information about Managed Postgres.\n"
-		long = deprecated
+		long = notice
 	)
 
 	cmd := command.New("postgres", short, long, nil)
@@ -30,7 +30,7 @@ func New() *cobra.Command {
 	// Add PreRun to show deprecation notice
 	cmd.PreRun = func(cmd *cobra.Command, args []string) {
 		io := iostreams.FromContext(cmd.Context())
-		fmt.Fprintf(io.ErrOut, "\n%s\n", deprecated)
+		fmt.Fprintf(io.ErrOut, "\n%s\n", notice)
 	}
 
 	// Add the same PreRun to all subcommands
@@ -206,7 +206,7 @@ func hasRequiredMemoryForBackup(machine fly.Machine) bool {
 }
 
 func UnregisterMember(ctx context.Context, app *fly.AppCompact, machine *fly.Machine) error {
-	machines, err := mach.ListActive(ctx)
+	machines, err := mach.ListActive(ctx, app.Name)
 	if err != nil {
 		return err
 	}
@@ -254,7 +254,7 @@ func UnregisterMember(ctx context.Context, app *fly.AppCompact, machine *fly.Mac
 }
 
 // Runs a command on the specified machine ID in the named app.
-func ExecOnMachine(ctx context.Context, client *flaps.Client, machineId, command string) error {
+func ExecOnMachine(ctx context.Context, client flapsutil.FlapsClient, appName, machineId, command string) error {
 	var (
 		io = iostreams.FromContext(ctx)
 	)
@@ -263,7 +263,7 @@ func ExecOnMachine(ctx context.Context, client *flaps.Client, machineId, command
 		Cmd: command,
 	}
 
-	out, err := client.Exec(ctx, machineId, in)
+	out, err := client.Exec(ctx, appName, machineId, in)
 	if err != nil {
 		return err
 	}
@@ -280,8 +280,8 @@ func ExecOnMachine(ctx context.Context, client *flaps.Client, machineId, command
 }
 
 // Runs a command on the leader of the named cluster.
-func ExecOnLeader(ctx context.Context, client *flaps.Client, command string) error {
-	machines, err := client.ListActive(ctx)
+func ExecOnLeader(ctx context.Context, client flapsutil.FlapsClient, appName, command string) error {
+	machines, err := client.ListActive(ctx, appName)
 	if err != nil {
 		return err
 	}
@@ -291,5 +291,5 @@ func ExecOnLeader(ctx context.Context, client *flaps.Client, command string) err
 		return err
 	}
 
-	return ExecOnMachine(ctx, client, leader.ID, command)
+	return ExecOnMachine(ctx, client, appName, leader.ID, command)
 }
