@@ -12,6 +12,7 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/flyctl"
+	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/agent"
 	"github.com/superfly/flyctl/internal/command/apps"
@@ -27,10 +28,8 @@ import (
 	"github.com/superfly/flyctl/internal/command/deploy"
 	"github.com/superfly/flyctl/internal/command/destroy"
 	"github.com/superfly/flyctl/internal/command/dig"
-	"github.com/superfly/flyctl/internal/command/dnsrecords"
 	"github.com/superfly/flyctl/internal/command/docs"
 	"github.com/superfly/flyctl/internal/command/doctor"
-	"github.com/superfly/flyctl/internal/command/domains"
 	"github.com/superfly/flyctl/internal/command/extensions"
 	"github.com/superfly/flyctl/internal/command/history"
 	"github.com/superfly/flyctl/internal/command/image"
@@ -92,6 +91,7 @@ func New() *cobra.Command {
 	}
 
 	root := command.New(exe, short, long, run)
+	root.Version = buildinfo.Version().String()
 	root.PersistentPreRun = func(cmd *cobra.Command, args []string) {
 		cmd.SilenceUsage = true
 		cmd.SilenceErrors = true
@@ -154,15 +154,13 @@ func New() *cobra.Command {
 		group(storage.New(), "dbs_and_extensions"),
 		metrics.New(),
 		synthetics.New(),
-		curl.New(),       // TODO: deprecate
-		domains.New(),    // TODO: deprecate
-		open.New(),       // TODO: deprecate
-		create.New(),     // TODO: deprecate
-		destroy.New(),    // TODO: deprecate
-		move.New(),       // TODO: deprecate
-		suspend.New(),    // TODO: deprecate
-		resume.New(),     // TODO: deprecate
-		dnsrecords.New(), // TODO: deprecate
+		curl.New(),    // TODO: deprecate
+		open.New(),    // TODO: deprecate
+		create.New(),  // TODO: deprecate
+		destroy.New(), // TODO: deprecate
+		move.New(),    // TODO: deprecate
+		suspend.New(), // TODO: deprecate
+		resume.New(),  // TODO: deprecate
 
 		regions.New(), // TODO: deprecate
 	)
@@ -246,6 +244,8 @@ func run(ctx context.Context) error {
 
 	cmd.Println()
 	cmd.Println("For a full list of commands, run `fly help`.")
+	cmd.Println()
+	cmd.Printf("Running %s v%s\n", buildinfo.Name(), buildinfo.Version())
 
 	return nil
 }
