@@ -3,6 +3,7 @@ package scale
 import (
 	"context"
 	"fmt"
+	"maps"
 	"slices"
 	"strconv"
 	"strings"
@@ -10,13 +11,10 @@ import (
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/flag/completion"
-	"github.com/superfly/flyctl/internal/flapsutil"
-	"golang.org/x/exp/maps"
 )
 
 func newScaleCount() *cobra.Command {
@@ -48,13 +46,6 @@ For pricing, see https://fly.io/docs/about/pricing/`
 
 func runScaleCount(ctx context.Context) error {
 	appName := appconfig.NameFromContext(ctx)
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
 
 	appConfig, err := appconfig.FromRemoteApp(ctx, appName)
 	if err != nil {
@@ -75,7 +66,7 @@ func runScaleCount(ctx context.Context) error {
 		return err
 	}
 
-	unknownNames := lo.Filter(maps.Keys(groups), func(x string, _ int) bool {
+	unknownNames := lo.Filter(slices.Collect(maps.Keys(groups)), func(x string, _ int) bool {
 		return !slices.Contains(processNames, x)
 	})
 	if len(unknownNames) > 0 {
