@@ -7,8 +7,10 @@ import (
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/fly-go/flaps"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -52,12 +54,10 @@ func runKeyDelete(ctx context.Context) (err error) {
 		return err
 	}
 
-	flapsClient, err := getFlapsClient(ctx)
-	if err != nil {
-		return err
-	}
+	appName := appconfig.NameFromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	secrets, err := flapsClient.ListSecretKeys(ctx, nil)
+	secrets, err := flapsClient.ListSecretKeys(ctx, appName, nil)
 	if err != nil {
 		return err
 	}
@@ -97,7 +97,7 @@ func runKeyDelete(ctx context.Context) (err error) {
 			}
 		}
 
-		err = flapsClient.DeleteSecretKey(ctx, secret.Name)
+		err = flapsClient.DeleteSecretKey(ctx, appName, secret.Name)
 		if err != nil {
 			var ferr *flaps.FlapsError
 			if errors.As(err, &ferr) && ferr.ResponseStatusCode == 404 {
