@@ -6,8 +6,10 @@ import (
 	"fmt"
 
 	"github.com/spf13/cobra"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/iostreams"
 )
 
@@ -78,12 +80,10 @@ func runKeySetOrGenerate(ctx context.Context) (err error) {
 		}
 	}
 
-	flapsClient, err := getFlapsClient(ctx)
-	if err != nil {
-		return err
-	}
+	appName := appconfig.NameFromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	secrets, err := flapsClient.ListSecretKeys(ctx, nil)
+	secrets, err := flapsClient.ListSecretKeys(ctx, appName, nil)
 	if err != nil {
 		return err
 	}
@@ -135,9 +135,9 @@ func runKeySetOrGenerate(ctx context.Context) (err error) {
 	}
 
 	if gen {
-		_, err = flapsClient.GenerateSecretKey(ctx, label, typ)
+		_, err = flapsClient.GenerateSecretKey(ctx, appName, label, typ)
 	} else {
-		_, err = flapsClient.SetSecretKey(ctx, label, typ, val)
+		_, err = flapsClient.SetSecretKey(ctx, appName, label, typ, val)
 	}
 	if err != nil {
 		return err
