@@ -8,9 +8,11 @@ import (
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -66,12 +68,11 @@ type jsonSecret struct {
 func runKeysList(ctx context.Context) (err error) {
 	cfg := config.FromContext(ctx)
 	out := iostreams.FromContext(ctx).Out
-	flapsClient, err := getFlapsClient(ctx)
-	if err != nil {
-		return err
-	}
 
-	secrets, err := flapsClient.ListSecretKeys(ctx, nil)
+	appName := appconfig.NameFromContext(ctx)
+	flapsClient := flapsutil.ClientFromContext(ctx)
+
+	secrets, err := flapsClient.ListSecretKeys(ctx, appName, nil)
 	if err != nil {
 		return err
 	}
