@@ -14,45 +14,15 @@ import (
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/flyutil"
-	"github.com/superfly/flyctl/iostreams"
 	"github.com/superfly/flyctl/ssh"
 	"github.com/superfly/flyctl/terminal"
 )
 
 const DefaultSshUsername = "root"
 
-func BringUpAgent(ctx context.Context, client flyutil.Client, app *fly.AppCompact, network string, quiet bool) (*agent.Client, agent.Dialer, error) {
-	io := iostreams.FromContext(ctx)
-
-	agentclient, err := agent.Establish(ctx, client)
-	if err != nil {
-		captureError(ctx, err, app)
-		return nil, nil, errors.Wrap(err, "can't establish agent")
-	}
-
-	dialer, err := agentclient.Dialer(ctx, app.Organization.Slug, network)
-	if err != nil {
-		captureError(ctx, err, app)
-		return nil, nil, fmt.Errorf("ssh: can't build tunnel for %s: %s\n", app.Organization.Slug, err)
-	}
-
-	if !quiet {
-		io.StartProgressIndicatorMsg("Connecting to tunnel")
-	}
-	if err := agentclient.WaitForTunnel(ctx, app.Organization.Slug, network); err != nil {
-		captureError(ctx, err, app)
-		return nil, nil, errors.Wrapf(err, "tunnel unavailable")
-	}
-	if !quiet {
-		io.StopProgressIndicator()
-	}
-
-	return agentclient, dialer, nil
-}
-
 type ConnectParams struct {
 	Ctx            context.Context
-	Org            fly.OrganizationImpl
+	Org            OrganizationImpl
 	Username       string
 	Dialer         agent.Dialer
 	DisableSpinner bool
@@ -60,6 +30,11 @@ type ConnectParams struct {
 	AppNames       []string
 }
 
+type OrganizationImpl interface {
+	GetID() string
+	GetSlug() string
+}
+
 func Connect(p *ConnectParams, addr string) (*ssh.Client, error) {
 	terminal.Debugf("Fetching certificate for %s\n", addr)
 
@@ -102,7 +77,7 @@ func Connect(p *ConnectParams, addr string) (*ssh.Client, error) {
 	return sshClient, nil
 }
 
-func singleUseSSHCertificate(ctx context.Context, org fly.OrganizationImpl, appNames []string, user string) (*fly.IssuedCertificate, ed25519.PrivateKey, error) {
+func singleUseSSHCertificate(ctx context.Context, org OrganizationImpl, appNames []string, user string) (*fly.IssuedCertificate, ed25519.PrivateKey, error) {
 	client := flyutil.ClientFromContext(ctx)
 	hours := 1
 
@@ -111,7 +86,7 @@ func singleUseSSHCertificate(ctx context.Context, org fly.OrganizationImpl, appN
 		return nil, nil, err
 	}
 
-	icert, err := client.IssueSSHCertificate(ctx, org, []string{user, "fly"}, appNames, &hours, pub)
+	icert, err := client.IssueSSHCertificate(ctx, org.GetID(), []string{user, "fly"}, appNames, &hours, pub)
 	if err != nil {
 		return nil, nil, err
 	}
