@@ -14,7 +14,6 @@ import (
 	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
@@ -172,7 +171,7 @@ func runConsole(ctx context.Context) error {
 		return fmt.Errorf("get app network: %w", err)
 	}
 
-	agentclient, dialer, err := BringUpAgent(ctx, client, app, *network, quiet(ctx))
+	agentclient, dialer, err := agent.BringUpAgent(ctx, client, app, *network, quiet(ctx))
 	if err != nil {
 		return err
 	}
@@ -246,15 +245,9 @@ func Console(ctx context.Context, sshClient *ssh.Client, cmd string, allocPTY bo
 
 func selectMachine(ctx context.Context, app *fly.AppCompact) (machine *fly.Machine, err error) {
 	out := iostreams.FromContext(ctx).Out
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppCompact: app,
-		AppName:    app.Name,
-	})
-	if err != nil {
-		return nil, err
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	machines, err := flapsClient.ListActive(ctx)
+	machines, err := flapsClient.ListActive(ctx, app.Name)
 	if err != nil {
 		return nil, err
 	}
@@ -343,12 +336,12 @@ func selectMachine(ctx context.Context, app *fly.AppCompact) (machine *fly.Machi
 	if selectedMachine != nil {
 		if selectedMachine.State != "started" {
 			fmt.Fprintf(out, "Starting machine %s..", selectedMachine.ID)
-			_, err := flapsClient.Start(ctx, selectedMachine.ID, "")
+			_, err := flapsClient.Start(ctx, app.Name, selectedMachine.ID, "")
 			if err != nil {
 				return nil, err
 			}
 
-			err = flapsClient.Wait(ctx, selectedMachine, "started", 60*time.Second)
+			err = flapsClient.Wait(ctx, app.Name, selectedMachine, "started", 60*time.Second)
 
 			if err != nil {
 				return nil, err
