@@ -6,7 +6,6 @@ import (
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/deploy"
@@ -48,6 +47,11 @@ func newCreate() *cobra.Command {
 			Default:     5,
 			Description: "Snapshot retention in days",
 		},
+		flag.Bool{
+			Name:        "scheduled-snapshots",
+			Description: "Enable scheduled automatic snapshots",
+			Default:     true,
+		},
 		flag.Bool{
 			Name:        "no-encryption",
 			Description: "Do not encrypt the volume contents. Volume contents are encrypted by default.",
@@ -97,13 +101,7 @@ func runCreate(ctx context.Context) error {
 		count      = flag.GetInt(ctx, "count")
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	// pre-fetch platform regions from API in background
 	prompt.PlatformRegions(ctx)
@@ -162,9 +160,14 @@ func runCreate(ctx context.Context) error {
 		SnapshotRetention:   fly.Pointer(flag.GetInt(ctx, "snapshot-retention")),
 		FSType:              fsType,
 	}
+
+	if flag.IsSpecified(ctx, "scheduled-snapshots") {
+		input.AutoBackupEnabled = fly.BoolPointer(flag.GetBool(ctx, "scheduled-snapshots"))
+	}
+
 	out := iostreams.FromContext(ctx).Out
 	for i := 0; i < count; i++ {
-		volume, err := flapsClient.CreateVolume(ctx, input)
+		volume, err := flapsClient.CreateVolume(ctx, appName, input)
 		if err != nil {
 			return err
 		}
@@ -195,7 +198,7 @@ func confirmVolumeCreate(ctx context.Context, appName string) (bool, error) {
 	}
 
 	// If we have more than 0 volumes with this name already, return early
-	if matches, err := countVolumesMatchingName(ctx, volumeName); err != nil {
+	if matches, err := countVolumesMatchingName(ctx, appName, volumeName); err != nil {
 		return false, err
 	} else if matches > 0 {
 		return true, nil
