@@ -6,7 +6,6 @@ import (
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
@@ -59,13 +58,7 @@ func runDestroy(ctx context.Context) error {
 		appName = *n
 	}
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
-	ctx = flapsutil.NewContextWithClient(ctx, flapsClient)
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	if len(volIDs) == 0 {
 		app, err := client.GetAppBasic(ctx, appName)
@@ -80,13 +73,13 @@ func runDestroy(ctx context.Context) error {
 	}
 
 	for _, volID := range volIDs {
-		if confirm, err := confirmVolumeDelete(ctx, volID); err != nil {
+		if confirm, err := confirmVolumeDelete(ctx, appName, volID); err != nil {
 			return err
 		} else if !confirm {
 			return nil
 		}
 
-		data, err := flapsClient.DeleteVolume(ctx, volID)
+		data, err := flapsClient.DeleteVolume(ctx, appName, volID)
 		if err != nil {
 			return fmt.Errorf("failed destroying volume: %w", err)
 		}
@@ -97,7 +90,7 @@ func runDestroy(ctx context.Context) error {
 	return nil
 }
 
-func confirmVolumeDelete(ctx context.Context, volID string) (bool, error) {
+func confirmVolumeDelete(ctx context.Context, appName string, volID string) (bool, error) {
 	var (
 		flapsClient = flapsutil.ClientFromContext(ctx)
 		io          = iostreams.FromContext(ctx)
@@ -112,13 +105,13 @@ func confirmVolumeDelete(ctx context.Context, volID string) (bool, error) {
 
 	// fetch the volume so we can get the associated app
 	var volume *fly.Volume
-	if volume, err = flapsClient.GetVolume(ctx, volID); err != nil {
+	if volume, err = flapsClient.GetVolume(ctx, appName, volID); err != nil {
 		return false, err
 	}
 
 	// fetch the set of volumes for this app. If > 0 we skip the prompt
 	var matches int32
-	if matches, err = countVolumesMatchingName(ctx, volume.Name); err != nil {
+	if matches, err = countVolumesMatchingName(ctx, appName, volume.Name); err != nil {
 		return false, err
 	}
 
