@@ -6,7 +6,6 @@ import (
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
@@ -71,16 +70,15 @@ func runFork(ctx context.Context) error {
 		client  = flyutil.ClientFromContext(ctx)
 	)
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
-	var vol *fly.Volume
+	var (
+		vol *fly.Volume
+		err error
+	)
 	if volID == "" {
-		app, err := client.GetAppBasic(ctx, appName)
+		var app *fly.AppBasic
+		app, err = client.GetAppBasic(ctx, appName)
 		if err != nil {
 			return err
 		}
@@ -89,7 +87,7 @@ func runFork(ctx context.Context) error {
 			return err
 		}
 	} else {
-		vol, err = flapsClient.GetVolume(ctx, volID)
+		vol, err = flapsClient.GetVolume(ctx, appName, volID)
 		if err != nil {
 			return fmt.Errorf("failed to get volume: %w", err)
 		}
@@ -105,7 +103,7 @@ func runFork(ctx context.Context) error {
 	var attachedMachineImage string
 	var attachedMachineGuest *fly.MachineGuest
 	if vol.AttachedMachine != nil {
-		m, err := flapsClient.Get(ctx, *vol.AttachedMachine)
+		m, err := flapsClient.Get(ctx, appName, *vol.AttachedMachine)
 		if err != nil {
 			return err
 		}
@@ -128,7 +126,7 @@ func runFork(ctx context.Context) error {
 		Region:              region,
 	}
 
-	volume, err := flapsClient.CreateVolume(ctx, input)
+	volume, err := flapsClient.CreateVolume(ctx, appName, input)
 	if err != nil {
 		return fmt.Errorf("failed to fork volume: %w", err)
 	}
