@@ -6,7 +6,6 @@ import (
 
 	"github.com/spf13/cobra"
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
@@ -55,18 +54,13 @@ func runList(ctx context.Context) error {
 		return err
 	}
 
-	flapsClient, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{
-		AppName: appName,
-	})
-	if err != nil {
-		return err
-	}
+	flapsClient := flapsutil.ClientFromContext(ctx)
 
 	var volumes []fly.Volume
 	if flag.GetBool(ctx, "all") {
-		volumes, err = flapsClient.GetAllVolumes(ctx)
+		volumes, err = flapsClient.GetAllVolumes(ctx, appName)
 	} else {
-		volumes, err = flapsClient.GetVolumes(ctx)
+		volumes, err = flapsClient.GetVolumes(ctx, appName)
 	}
 	if err != nil {
 		return fmt.Errorf("failed retrieving volumes: %w", err)
