@@ -36,7 +36,7 @@ func makeAlias[T any](template T, name string) T {
 	useAliasShortHandField := reflect.ValueOf(template).FieldByName("UseAliasShortHand")
 	if useAliasShortHandField.IsValid() {
 		useAliasShortHand := useAliasShortHandField.Interface().(bool)
-		if useAliasShortHand == true {
+		if useAliasShortHand {
 			value.FieldByName("Shorthand").SetString(string(name[0]))
 		}
 	}
@@ -323,6 +323,7 @@ func Org() String {
 func MPGCluster() String {
 	return String{
 		Name:        "cluster",
+		Shorthand:   "c",
 		Description: "The target cluster ID",
 	}
 }
@@ -584,6 +585,47 @@ func Nixpacks() Bool {
 	}
 }
 
+func BuildkitAddr() String {
+	return String{
+		Name:        "buildkit-addr",
+		Description: "Address of remote buildkit daemon (e.g. tcp://127.0.0.1:1234 or unix:///path/to/socket)",
+		EnvName:     "BUILDKIT_ADDR",
+		Hidden:      true,
+	}
+}
+
+func BuildkitImage() String {
+	return String{
+		Name:        "buildkit-image",
+		Description: "Image to use for remote buildkit daemon",
+		EnvName:     "BUILDKIT_IMAGE",
+		Hidden:      true,
+	}
+}
+
+func Buildkit() Bool {
+	return Bool{
+		Name:        "buildkit",
+		Description: "Deploy using buildkit-based remote builder",
+	}
+}
+
+func Compression() String {
+	return String{
+		Name:        "compression",
+		Description: `Compression algorithm to use for the image. Options are "zstd" or "gzip". Defaults to "gzip".`,
+		Default:     "gzip",
+	}
+}
+
+func CompressionLevel() Int {
+	return Int{
+		Name:        "compression-level",
+		Description: `Compression level to use for the image. Defaults to 7.`,
+		Default:     7,
+	}
+}
+
 func Strategy() String {
 	return String{
 		Name:        "strategy",
