@@ -49,9 +49,15 @@ const (
 	// BindAddr denotes the name of the local bind address flag.
 	BindAddr = "bind-addr"
 
+	// LocalPort denotes the name of the local MPG proxy port flag.
+	LocalPort = "local-port"
+
 	// ProcessGroup denotes the name of the process group flag.
 	ProcessGroup = "process-group"
 
 	// MPGClusterID denotes the name of the MPG cluster ID flag.
 	MPGClusterID = "cluster"
+
+	// MPGDatabase denotes the name of the MPG database flag.
+	MPGDatabase = "database"
 )
