@@ -40,7 +40,11 @@ func (m *Client) AddCertificate(ctx context.Context, appName, hostname string) (
 	panic("TODO")
 }
 
-func (m *Client) AllocateIPAddress(ctx context.Context, appName string, addrType string, region string, org *fly.Organization, network string) (*fly.IPAddress, error) {
+func (m *Client) AllocateAppScopedEgressIPAddress(ctx context.Context, appName string, region string) (net.IP, net.IP, error) {
+	panic("TODO")
+}
+
+func (m *Client) AllocateIPAddress(ctx context.Context, appName string, addrType string, region string, orgID string, network string) (*fly.IPAddress, error) {
 	panic("TODO")
 }
 
@@ -72,18 +76,10 @@ func (m *Client) CheckAppCertificate(ctx context.Context, appName, hostname stri
 	panic("TODO")
 }
 
-func (m *Client) CheckDomain(ctx context.Context, name string) (*fly.CheckDomainResult, error) {
-	panic("TODO")
-}
-
 func (m *Client) ClosestWireguardGatewayRegion(ctx context.Context) (*fly.Region, error) {
 	panic("TODO")
 }
 
-func (m *Client) CreateAndRegisterDomain(organizationID string, name string) (*fly.Domain, error) {
-	panic("TODO")
-}
-
 func (m *Client) CreateApp(ctx context.Context, input fly.CreateAppInput) (*fly.App, error) {
 	panic("TODO")
 }
@@ -100,7 +96,7 @@ func (m *Client) CreateBuild(ctx context.Context, input fly.CreateBuildInput) (*
 	return &resp, nil
 }
 
-func (m *Client) CreateDelegatedWireGuardToken(ctx context.Context, org *fly.Organization, name string) (*fly.DelegatedWireGuardToken, error) {
+func (m *Client) CreateDelegatedWireGuardToken(ctx context.Context, orgID string, name string) (*fly.DelegatedWireGuardToken, error) {
 	panic("TODO")
 }
 
@@ -108,10 +104,6 @@ func (m *Client) CreateDoctorUrl(ctx context.Context) (putUrl string, err error)
 	panic("TODO")
 }
 
-func (m *Client) CreateDomain(organizationID string, name string) (*fly.Domain, error) {
-	panic("TODO")
-}
-
 func (m *Client) CreateOrganization(ctx context.Context, organizationname string) (*fly.Organization, error) {
 	panic("TODO")
 }
@@ -132,7 +124,7 @@ func (m *Client) CreateRelease(ctx context.Context, input fly.CreateReleaseInput
 	return &resp, nil
 }
 
-func (m *Client) CreateWireGuardPeer(ctx context.Context, org *fly.Organization, region, name, pubkey, network string) (*fly.CreatedWireGuardPeer, error) {
+func (m *Client) CreateWireGuardPeer(ctx context.Context, orgID string, region, name, pubkey, network string) (*fly.CreatedWireGuardPeer, error) {
 	panic("TODO")
 }
 
@@ -144,7 +136,7 @@ func (m *Client) DeleteCertificate(ctx context.Context, appName, hostname string
 	panic("TODO")
 }
 
-func (m *Client) DeleteDelegatedWireGuardToken(ctx context.Context, org *fly.Organization, name, token *string) error {
+func (m *Client) DeleteDelegatedWireGuardToken(ctx context.Context, orgID string, name, token *string) error {
 	panic("TODO")
 }
 
@@ -172,10 +164,6 @@ func (m *Client) EnsureDepotRemoteBuilder(ctx context.Context, input *fly.Ensure
 	panic("TODO")
 }
 
-func (m *Client) ExportDNSRecords(ctx context.Context, domainId string) (string, error) {
-	panic("TODO")
-}
-
 func (m *Client) FinishBuild(ctx context.Context, input fly.FinishBuildInput) (*fly.FinishBuildResponse, error) {
 	build, err := m.server.FinishBuild(ctx, input.BuildId, input.Status)
 	if err != nil {
@@ -216,6 +204,10 @@ func (m *Client) GetAppCurrentReleaseMachines(ctx context.Context, appName strin
 	panic("TODO")
 }
 
+func (m *Client) GetAppCNAMETarget(ctx context.Context, appName string) (string, error) {
+	panic("TODO")
+}
+
 func (m *Client) GetAppHostIssues(ctx context.Context, appName string) ([]fly.HostIssue, error) {
 	panic("TODO")
 }
@@ -264,12 +256,12 @@ func (m *Client) GetAppsForOrganization(ctx context.Context, orgID string) ([]fl
 	panic("TODO")
 }
 
-func (m *Client) GetCurrentUser(ctx context.Context) (*fly.User, error) {
-	return m.CurrentUser, nil
+func (m *Client) GetAppScopedEgressIPAddresses(ctx context.Context, appName string) (map[string][]fly.EgressIPAddress, error) {
+	return make(map[string][]fly.EgressIPAddress), nil
 }
 
-func (m *Client) GetDNSRecords(ctx context.Context, domainName string) ([]*fly.DNSRecord, error) {
-	panic("TODO")
+func (m *Client) GetCurrentUser(ctx context.Context) (*fly.User, error) {
+	return m.CurrentUser, nil
 }
 
 func (m *Client) GetDelegatedWireGuardTokens(ctx context.Context, slug string) ([]*fly.DelegatedWireGuardTokenHandle, error) {
@@ -280,19 +272,11 @@ func (m *Client) GetDetailedOrganizationBySlug(ctx context.Context, slug string)
 	panic("TODO")
 }
 
-func (m *Client) GetDomain(ctx context.Context, name string) (*fly.Domain, error) {
-	panic("TODO")
-}
-
-func (m *Client) GetDomains(ctx context.Context, organizationSlug string) ([]*fly.Domain, error) {
-	panic("TODO")
-}
-
 func (m *Client) GetIPAddresses(ctx context.Context, appName string) ([]fly.IPAddress, error) {
 	return nil, nil // TODO
 }
 
-func (c *Client) GetEgressIPAddresses(ctx context.Context, appName string) (map[string][]fly.EgressIPAddress, error) {
+func (m *Client) GetEgressIPAddresses(ctx context.Context, appName string) (map[string][]fly.EgressIPAddress, error) {
 	panic("TODO")
 }
 
@@ -317,7 +301,11 @@ func (m *Client) GetNearestRegion(ctx context.Context) (*fly.Region, error) {
 }
 
 func (m *Client) GetOrganizationByApp(ctx context.Context, appName string) (*fly.Organization, error) {
-	panic("TODO")
+	app, err := m.GetAppCompact(ctx, appName)
+	if err != nil {
+		return nil, err
+	}
+	return &fly.Organization{ID: app.Organization.ID}, nil
 }
 
 func (m *Client) GetOrganizationBySlug(ctx context.Context, slug string) (*fly.Organization, error) {
@@ -332,6 +320,18 @@ func (m *Client) GetOrganizations(ctx context.Context, filters ...fly.Organizati
 	panic("TODO")
 }
 
+func (m *Client) GetAllowedReplaySourceOrgSlugs(ctx context.Context, slug string) ([]string, error) {
+	panic("TODO")
+}
+
+func (m *Client) AddAllowedReplaySourceOrgs(ctx context.Context, orgSlug string, sourceOrgSlugs []string) (*fly.Organization, error) {
+	panic("TODO")
+}
+
+func (m *Client) RemoveAllowedReplaySourceOrgs(ctx context.Context, orgSlug string, orgSlugsToRemove []string) (*fly.Organization, error) {
+	panic("TODO")
+}
+
 func (m *Client) GetSnapshotsFromVolume(ctx context.Context, volID string) ([]fly.VolumeSnapshot, error) {
 	panic("TODO")
 }
@@ -352,11 +352,7 @@ func (m *Client) LatestImage(ctx context.Context, appName string) (string, error
 	panic("TODO")
 }
 
-func (m *Client) ImportDNSRecords(ctx context.Context, domainId string, zonefile string) ([]fly.ImportDnsWarning, []fly.ImportDnsChange, error) {
-	panic("TODO")
-}
-
-func (m *Client) IssueSSHCertificate(ctx context.Context, org fly.OrganizationImpl, principals []string, appNames []string, valid_hours *int, publicKey ed25519.PublicKey) (*fly.IssuedCertificate, error) {
+func (m *Client) IssueSSHCertificate(ctx context.Context, orgID string, principals []string, appNames []string, valid_hours *int, publicKey ed25519.PublicKey) (*fly.IssuedCertificate, error) {
 	panic("TODO")
 }
 
@@ -380,6 +376,10 @@ func (m *Client) PlatformRegions(ctx context.Context) ([]fly.Region, *fly.Region
 	panic("TODO")
 }
 
+func (m *Client) ReleaseAppScopedEgressIPAddress(ctx context.Context, appName, ip string) error {
+	panic("TODO")
+}
+
 func (m *Client) ReleaseEgressIPAddress(ctx context.Context, appName string, machineID string) (net.IP, net.IP, error) {
 	panic("TODO")
 }
@@ -388,7 +388,7 @@ func (m *Client) ReleaseIPAddress(ctx context.Context, appName string, ip string
 	panic("TODO")
 }
 
-func (m *Client) RemoveWireGuardPeer(ctx context.Context, org *fly.Organization, name string) error {
+func (m *Client) RemoveWireGuardPeer(ctx context.Context, orgID string, name string) error {
 	panic("TODO")
 }
 
