@@ -22,6 +22,25 @@ import (
 	"go.opentelemetry.io/otel/trace"
 )
 
+type WaitOptions struct {
+	allowInfinite bool
+	justCreated   bool
+}
+
+type WaitOption func(*WaitOptions)
+
+func WithAllowInfinite(allow bool) WaitOption {
+	return func(opts *WaitOptions) {
+		opts.allowInfinite = allow
+	}
+}
+
+func WithJustCreated() WaitOption {
+	return func(opts *WaitOptions) {
+		opts.justCreated = true
+	}
+}
+
 type LeasableMachine interface {
 	Machine() *fly.Machine
 	HasLease() bool
@@ -34,7 +53,7 @@ type LeasableMachine interface {
 	Stop(context.Context, string) error
 	Destroy(context.Context, bool) error
 	Cordon(context.Context) error
-	WaitForState(context.Context, string, time.Duration, bool) error
+	WaitForState(context.Context, string, time.Duration, ...WaitOption) error
 	WaitForSmokeChecksToPass(context.Context) error
 	WaitForHealthchecksToPass(context.Context, time.Duration) error
 	WaitForEventType(context.Context, string, time.Duration, bool) (*fly.MachineEvent, error)
@@ -49,6 +68,7 @@ type leasableMachine struct {
 	flapsClient            flapsutil.FlapsClient
 	io                     *iostreams.IOStreams
 	colorize               *iostreams.ColorScheme
+	appName                string
 	machine                *fly.Machine
 	leaseRefreshCancelFunc context.CancelFunc
 	destroyed              bool
@@ -62,12 +82,13 @@ type leasableMachine struct {
 
 // NewLeasableMachine creates a wrapper for the given machine.
 // A lease must be held before calling this function.
-func NewLeasableMachine(flapsClient flapsutil.FlapsClient, io *iostreams.IOStreams, machine *fly.Machine, showLogs bool) LeasableMachine {
+func NewLeasableMachine(flapsClient flapsutil.FlapsClient, io *iostreams.IOStreams, appName string, machine *fly.Machine, showLogs bool) LeasableMachine {
 	// TODO: make sure the other functions handle showLogs correctly
 	return &leasableMachine{
 		flapsClient: flapsClient,
 		io:          io,
 		colorize:    io.ColorScheme(),
+		appName:     appName,
 		machine:     machine,
 		leaseNonce:  machine.LeaseNonce,
 		showLogs:    showLogs,
@@ -82,7 +103,7 @@ func (lm *leasableMachine) Update(ctx context.Context, input fly.LaunchMachineIn
 		return fmt.Errorf("no current lease for machine %s", lm.machine.ID)
 	}
 	input.ID = lm.machine.ID
-	updateMachine, err := lm.flapsClient.Update(ctx, input, lm.leaseNonce)
+	updateMachine, err := lm.flapsClient.Update(ctx, lm.appName, input, lm.leaseNonce)
 	if err != nil {
 		return err
 	}
@@ -100,7 +121,7 @@ func (lm *leasableMachine) Stop(ctx context.Context, signal string) error {
 		Signal: signal,
 	}
 
-	return lm.flapsClient.Stop(ctx, input, lm.leaseNonce)
+	return lm.flapsClient.Stop(ctx, lm.appName, input, lm.leaseNonce)
 }
 
 func (lm *leasableMachine) Destroy(ctx context.Context, kill bool) error {
@@ -111,7 +132,7 @@ func (lm *leasableMachine) Destroy(ctx context.Context, kill bool) error {
 		ID:   lm.machine.ID,
 		Kill: kill,
 	}
-	err := lm.flapsClient.Destroy(ctx, input, lm.leaseNonce)
+	err := lm.flapsClient.Destroy(ctx, lm.appName, input, lm.leaseNonce)
 	if err != nil {
 		return err
 	}
@@ -124,7 +145,7 @@ func (lm *leasableMachine) Cordon(ctx context.Context) error {
 		return fmt.Errorf("cannon cordon machine %s that was already destroyed", lm.machine.ID)
 	}
 
-	return lm.flapsClient.Cordon(ctx, lm.machine.ID, lm.leaseNonce)
+	return lm.flapsClient.Cordon(ctx, lm.appName, lm.machine.ID, lm.leaseNonce)
 }
 
 func (lm *leasableMachine) FormattedMachineId() string {
@@ -169,7 +190,7 @@ func (lm *leasableMachine) Start(ctx context.Context) error {
 	if lm.showLogs {
 		lm.logStatusWaiting(ctx, fly.MachineStateStarted)
 	}
-	_, err := lm.flapsClient.Start(ctx, lm.machine.ID, "")
+	_, err := lm.flapsClient.Start(ctx, lm.appName, lm.machine.ID, "")
 	if err != nil {
 		return err
 	}
@@ -196,8 +217,13 @@ func resolveTimeoutContext(ctx context.Context, timeout time.Duration, allowInfi
 	}
 }
 
-func (lm *leasableMachine) WaitForState(ctx context.Context, desiredState string, timeout time.Duration, allowInfinite bool) error {
-	waitCtx, cancel, timeout := resolveTimeoutContext(ctx, timeout, allowInfinite)
+func (lm *leasableMachine) WaitForState(ctx context.Context, desiredState string, timeout time.Duration, opts ...WaitOption) error {
+	options := &WaitOptions{}
+	for _, opt := range opts {
+		opt(options)
+	}
+
+	waitCtx, cancel, timeout := resolveTimeoutContext(ctx, timeout, options.allowInfinite)
 	waitCtx, cancel = ctrlc.HookCancelableContext(waitCtx, cancel)
 	defer cancel()
 	b := &backoff.Backoff{
@@ -210,7 +236,7 @@ func (lm *leasableMachine) WaitForState(ctx context.Context, desiredState string
 		lm.logStatusWaiting(ctx, desiredState)
 	}
 	for {
-		err := lm.flapsClient.Wait(waitCtx, lm.Machine(), desiredState, timeout)
+		err := lm.flapsClient.Wait(waitCtx, lm.appName, lm.Machine(), desiredState, timeout)
 		notFoundResponse := false
 		if err != nil {
 			var flapsErr *flaps.FlapsError
@@ -227,14 +253,27 @@ func (lm *leasableMachine) WaitForState(ctx context.Context, desiredState string
 				timeout:      timeout,
 				desiredState: desiredState,
 			}
-		case notFoundResponse && desiredState != fly.MachineStateDestroyed:
-			return err
-		case !notFoundResponse && err != nil:
+		case notFoundResponse && desiredState == fly.MachineStateDestroyed:
+			// We're waiting for destroyed state and the machine no longer exists - success
+		case notFoundResponse && options.justCreated:
+			// Machine not found but we just created it - retry with backoff (it may not be visible yet)
 			select {
 			case <-time.After(b.Duration()):
 			case <-waitCtx.Done():
 			}
 			continue
+		case notFoundResponse:
+			// Machine not found and we didn't just create it - return error immediately
+			return err
+		case err != nil:
+			// Otherwise retry with backoff
+			select {
+			case <-time.After(b.Duration()):
+			case <-waitCtx.Done():
+			}
+			continue
+		default:
+			// Success
 		}
 		if lm.showLogs {
 			lm.logStatusFinished(ctx, desiredState)
@@ -282,7 +321,7 @@ func (lm *leasableMachine) WaitForSmokeChecksToPass(ctx context.Context) error {
 	}
 
 	for {
-		machine, err := lm.flapsClient.Get(waitCtx, lm.Machine().ID)
+		machine, err := lm.flapsClient.Get(waitCtx, lm.appName, lm.Machine().ID)
 		startedAt, startedAtErr := machine.MostRecentStartTimeAfterLaunch()
 		uptime := 0 * time.Second
 		if startedAtErr == nil {
@@ -331,7 +370,7 @@ func (lm *leasableMachine) WaitForHealthchecksToPass(ctx context.Context, timeou
 
 	printedFirst := false
 	for {
-		updateMachine, err := lm.flapsClient.Get(waitCtx, lm.Machine().ID)
+		updateMachine, err := lm.flapsClient.Get(waitCtx, lm.appName, lm.Machine().ID)
 		switch {
 		case errors.Is(waitCtx.Err(), context.Canceled):
 			span.RecordError(err)
@@ -374,7 +413,7 @@ func (lm *leasableMachine) WaitForEventType(ctx context.Context, eventType strin
 		statuslogger.Logf(ctx, "Waiting for %s to get %s event", lm.colorize.Bold(lm.FormattedMachineId()), lm.colorize.Yellow(eventType))
 	}
 	for {
-		updateMachine, err := lm.flapsClient.Get(waitCtx, lm.Machine().ID)
+		updateMachine, err := lm.flapsClient.Get(waitCtx, lm.appName, lm.Machine().ID)
 		switch {
 		case errors.Is(waitCtx.Err(), context.Canceled):
 			return nil, err
@@ -409,7 +448,7 @@ func (lm *leasableMachine) WaitForEventTypeAfterType(ctx context.Context, eventT
 	}
 	statuslogger.Logf(ctx, "Waiting for %s to get %s event", lm.colorize.Bold(lm.FormattedMachineId()), lm.colorize.Yellow(eventType1))
 	for {
-		updateMachine, err := lm.flapsClient.Get(waitCtx, lm.Machine().ID)
+		updateMachine, err := lm.flapsClient.Get(waitCtx, lm.appName, lm.Machine().ID)
 		switch {
 		case errors.Is(waitCtx.Err(), context.Canceled):
 			return nil, err
@@ -447,7 +486,7 @@ func (lm *leasableMachine) AcquireLease(ctx context.Context, duration time.Durat
 		return nil
 	}
 	seconds := int(duration.Seconds())
-	lease, err := lm.flapsClient.AcquireLease(ctx, lm.machine.ID, &seconds)
+	lease, err := lm.flapsClient.AcquireLease(ctx, lm.appName, lm.machine.ID, &seconds)
 	if err != nil {
 		return err
 	}
@@ -467,7 +506,7 @@ func (lm *leasableMachine) RefreshLease(ctx context.Context, duration time.Durat
 	defer lm.mu.Unlock()
 
 	seconds := int(duration.Seconds())
-	refreshedLease, err := lm.flapsClient.RefreshLease(ctx, lm.machine.ID, &seconds, lm.leaseNonce)
+	refreshedLease, err := lm.flapsClient.RefreshLease(ctx, lm.appName, lm.machine.ID, &seconds, lm.leaseNonce)
 	if err != nil {
 		return err
 	}
@@ -531,7 +570,7 @@ func (lm *leasableMachine) ReleaseLease(ctx context.Context) error {
 		defer cancel()
 	}
 
-	return lm.flapsClient.ReleaseLease(ctx, lm.machine.ID, nonce)
+	return lm.flapsClient.ReleaseLease(ctx, lm.appName, lm.machine.ID, nonce)
 }
 
 func (lm *leasableMachine) resetLease() {
@@ -570,9 +609,9 @@ func (lm *leasableMachine) GetMinIntervalAndMinGracePeriod() (time.Duration, tim
 }
 
 func (lm *leasableMachine) GetMetadata(ctx context.Context) (map[string]string, error) {
-	return lm.flapsClient.GetMetadata(ctx, lm.machine.ID)
+	return lm.flapsClient.GetMetadata(ctx, lm.appName, lm.machine.ID)
 }
 
 func (lm *leasableMachine) SetMetadata(ctx context.Context, k, v string) error {
-	return lm.flapsClient.SetMetadata(ctx, lm.machine.ID, k, v)
+	return lm.flapsClient.SetMetadata(ctx, lm.appName, lm.machine.ID, k, v)
 }
