@@ -32,10 +32,10 @@ type machineSet struct {
 	machines []LeasableMachine
 }
 
-func NewMachineSet(flapsClient flapsutil.FlapsClient, io *iostreams.IOStreams, machines []*fly.Machine, showLogs bool) *machineSet {
+func NewMachineSet(flapsClient flapsutil.FlapsClient, io *iostreams.IOStreams, appName string, machines []*fly.Machine, showLogs bool) *machineSet {
 	leaseMachines := make([]LeasableMachine, 0)
 	for _, m := range machines {
-		leaseMachines = append(leaseMachines, NewLeasableMachine(flapsClient, io, m, showLogs))
+		leaseMachines = append(leaseMachines, NewLeasableMachine(flapsClient, io, appName, m, showLogs))
 	}
 	return &machineSet{
 		machines: leaseMachines,
@@ -162,7 +162,7 @@ func (ms *machineSet) WaitForMachineSetState(ctx context.Context, state string,
 		wg.Add(1)
 		go func(m LeasableMachine) {
 			defer wg.Done()
-			err := m.WaitForState(ctx, state, timeout, allowInfinite)
+			err := m.WaitForState(ctx, state, timeout, WithAllowInfinite(allowInfinite))
 
 			var flapsErr *flaps.FlapsError
 			if errors.As(err, &flapsErr) {
