@@ -11,7 +11,7 @@ import (
 	"github.com/superfly/flyctl/iostreams"
 )
 
-func Restart(ctx context.Context, m *fly.Machine, input *fly.RestartMachineInput, nonce string) error {
+func Restart(ctx context.Context, appName string, m *fly.Machine, input *fly.RestartMachineInput, nonce string) error {
 	var (
 		flapsClient = flapsutil.ClientFromContext(ctx)
 		io          = iostreams.FromContext(ctx)
@@ -20,16 +20,16 @@ func Restart(ctx context.Context, m *fly.Machine, input *fly.RestartMachineInput
 
 	fmt.Fprintf(io.Out, "Restarting machine %s\n", colorize.Bold(m.ID))
 	input.ID = m.ID
-	if err := flapsClient.Restart(ctx, *input, nonce); err != nil {
+	if err := flapsClient.Restart(ctx, appName, *input, nonce); err != nil {
 		return fmt.Errorf("could not stop machine %s: %w", input.ID, err)
 	}
 
-	if err := WaitForStartOrStop(ctx, &fly.Machine{ID: input.ID}, "start", time.Minute*5); err != nil {
+	if err := WaitForStartOrStop(ctx, appName, &fly.Machine{ID: input.ID}, "start", time.Minute*5); err != nil {
 		return err
 	}
 
 	if !input.SkipHealthChecks {
-		if err := watch.MachinesChecks(ctx, []*fly.Machine{m}); err != nil {
+		if err := watch.MachinesChecks(ctx, appName, []*fly.Machine{m}); err != nil {
 			return fmt.Errorf("failed to wait for health checks to pass: %w", err)
 		}
 	}
