@@ -3,6 +3,7 @@ package machine
 import (
 	"context"
 	"fmt"
+	"maps"
 	"slices"
 	"time"
 
@@ -10,7 +11,6 @@ import (
 	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/watch"
 	"github.com/superfly/flyctl/iostreams"
-	"golang.org/x/exp/maps"
 )
 
 var cpusPerKind = map[string][]int{
@@ -18,7 +18,7 @@ var cpusPerKind = map[string][]int{
 	"performance": {1, 2, 4, 6, 8, 10, 12, 14, 16, 32, 64, 128},
 }
 
-func Update(ctx context.Context, m *fly.Machine, input *fly.LaunchMachineInput) error {
+func Update(ctx context.Context, appName string, m *fly.Machine, input *fly.LaunchMachineInput) error {
 	var (
 		flapsClient    = flapsutil.ClientFromContext(ctx)
 		io             = iostreams.FromContext(ctx)
@@ -80,7 +80,7 @@ func Update(ctx context.Context, m *fly.Machine, input *fly.LaunchMachineInput)
 	fmt.Fprintf(io.Out, "Updating machine %s\n", colorize.Bold(m.ID))
 
 	input.ID = m.ID
-	updatedMachine, err = flapsClient.Update(ctx, *input, m.LeaseNonce)
+	updatedMachine, err = flapsClient.Update(ctx, appName, *input, m.LeaseNonce)
 	if err != nil {
 		return fmt.Errorf("could not update machine %s: %w", m.ID, err)
 	}
@@ -95,13 +95,13 @@ func Update(ctx context.Context, m *fly.Machine, input *fly.LaunchMachineInput)
 		waitTimeout = time.Duration(input.Timeout) * time.Second
 	}
 
-	if err := WaitForStartOrStop(ctx, updatedMachine, waitForAction, waitTimeout); err != nil {
+	if err := WaitForStartOrStop(ctx, appName, updatedMachine, waitForAction, waitTimeout); err != nil {
 		return err
 	}
 
 	if !input.SkipLaunch {
 		if !input.SkipHealthChecks {
-			if err := watch.MachinesChecks(ctx, []*fly.Machine{updatedMachine}); err != nil {
+			if err := watch.MachinesChecks(ctx, appName, []*fly.Machine{updatedMachine}); err != nil {
 				return fmt.Errorf("failed to wait for health checks to pass: %w", err)
 			}
 		}
@@ -151,7 +151,7 @@ func (e InvalidConfigErr) Suggestion() string {
 		validNumCpus := cpusPerKind[e.guest.CPUKind]
 		return fmt.Sprintf("Valid numbers are %v", validNumCpus)
 	case invalidMemorySize:
-		var incrementSize int = 1024
+		var incrementSize = 1024
 		switch e.guest.CPUKind {
 		case "shared":
 			incrementSize = 256
