@@ -15,36 +15,33 @@ var _ flyutil.Client = (*Client)(nil)
 
 type Client struct {
 	AddCertificateFunc                     func(ctx context.Context, appName, hostname string) (*fly.AppCertificate, *fly.HostnameCheck, error)
-	AllocateIPAddressFunc                  func(ctx context.Context, appName string, addrType string, region string, org *fly.Organization, network string) (*fly.IPAddress, error)
+	AllocateIPAddressFunc                  func(ctx context.Context, appName string, addrType string, region string, orgID string, network string) (*fly.IPAddress, error)
 	AllocateSharedIPAddressFunc            func(ctx context.Context, appName string) (net.IP, error)
+	AllocateAppScopedEgressIPAddressFunc   func(ctx context.Context, appName string, region string) (net.IP, net.IP, error)
 	AllocateEgressIPAddressFunc            func(ctx context.Context, appName string, machineId string) (net.IP, net.IP, error)
 	AppNameAvailableFunc                   func(ctx context.Context, appName string) (bool, error)
 	AttachPostgresClusterFunc              func(ctx context.Context, input fly.AttachPostgresClusterInput) (*fly.AttachPostgresClusterPayload, error)
 	AuthenticatedFunc                      func() bool
 	CanPerformBluegreenDeploymentFunc      func(ctx context.Context, appName string) (bool, error)
 	CheckAppCertificateFunc                func(ctx context.Context, appName, hostname string) (*fly.AppCertificate, *fly.HostnameCheck, error)
-	CheckDomainFunc                        func(ctx context.Context, name string) (*fly.CheckDomainResult, error)
 	ClosestWireguardGatewayRegionFunc      func(ctx context.Context) (*fly.Region, error)
-	CreateAndRegisterDomainFunc            func(organizationID string, name string) (*fly.Domain, error)
 	CreateAppFunc                          func(ctx context.Context, input fly.CreateAppInput) (*fly.App, error)
 	CreateBuildFunc                        func(ctx context.Context, input fly.CreateBuildInput) (*fly.CreateBuildResponse, error)
-	CreateDelegatedWireGuardTokenFunc      func(ctx context.Context, org *fly.Organization, name string) (*fly.DelegatedWireGuardToken, error)
+	CreateDelegatedWireGuardTokenFunc      func(ctx context.Context, orgID string, name string) (*fly.DelegatedWireGuardToken, error)
 	CreateDoctorUrlFunc                    func(ctx context.Context) (putUrl string, err error)
-	CreateDomainFunc                       func(organizationID string, name string) (*fly.Domain, error)
 	CreateOrganizationFunc                 func(ctx context.Context, organizationname string) (*fly.Organization, error)
 	CreateOrganizationInviteFunc           func(ctx context.Context, id, email string) (*fly.Invitation, error)
 	CreateReleaseFunc                      func(ctx context.Context, input fly.CreateReleaseInput) (*fly.CreateReleaseResponse, error)
-	CreateWireGuardPeerFunc                func(ctx context.Context, org *fly.Organization, region, name, pubkey, network string) (*fly.CreatedWireGuardPeer, error)
+	CreateWireGuardPeerFunc                func(ctx context.Context, orgID string, region, name, pubkey, network string) (*fly.CreatedWireGuardPeer, error)
 	DeleteAppFunc                          func(ctx context.Context, appName string) error
 	DeleteCertificateFunc                  func(ctx context.Context, appName, hostname string) (*fly.DeleteCertificatePayload, error)
-	DeleteDelegatedWireGuardTokenFunc      func(ctx context.Context, org *fly.Organization, name, token *string) error
+	DeleteDelegatedWireGuardTokenFunc      func(ctx context.Context, orgID string, name, token *string) error
 	DeleteOrganizationFunc                 func(ctx context.Context, id string) (deletedid string, err error)
 	DeleteOrganizationMembershipFunc       func(ctx context.Context, orgId, userId string) (string, string, error)
 	DetachPostgresClusterFunc              func(ctx context.Context, input fly.DetachPostgresClusterInput) error
 	EnablePostgresConsulFunc               func(ctx context.Context, appName string) (*fly.PostgresEnableConsulPayload, error)
 	EnsureDepotRemoteBuilderFunc           func(ctx context.Context, input *fly.EnsureDepotRemoteBuilderInput) (*fly.EnsureDepotRemoteBuilderResponse, error)
 	EnsureRemoteBuilderFunc                func(ctx context.Context, orgID, appName, region string) (*fly.GqlMachine, *fly.App, error)
-	ExportDNSRecordsFunc                   func(ctx context.Context, domainId string) (string, error)
 	FinishBuildFunc                        func(ctx context.Context, input fly.FinishBuildInput) (*fly.FinishBuildResponse, error)
 	GetAppFunc                             func(ctx context.Context, appName string) (*fly.App, error)
 	GetAppRemoteBuilderFunc                func(ctx context.Context, appName string) (*fly.App, error)
@@ -53,6 +50,7 @@ type Client struct {
 	GetAppCompactFunc                      func(ctx context.Context, appName string) (*fly.AppCompact, error)
 	GetDeployerAppByOrgFunc                func(ctx context.Context, orgID string) (*fly.App, error)
 	GetAppCurrentReleaseMachinesFunc       func(ctx context.Context, appName string) (*fly.Release, error)
+	GetAppCNAMETargetFunc                  func(ctx context.Context, appName string) (string, error)
 	GetAppHostIssuesFunc                   func(ctx context.Context, appName string) ([]fly.HostIssue, error)
 	GetAppLimitedAccessTokensFunc          func(ctx context.Context, appName string) ([]fly.LimitedAccessToken, error)
 	GetAppLogsFunc                         func(ctx context.Context, appName, token, region, instanceID string) (entries []fly.LogEntry, nextToken string, err error)
@@ -60,15 +58,13 @@ type Client struct {
 	GetAppNameStateFromVolumeFunc          func(ctx context.Context, volID string) (*string, *string, error)
 	GetAppNetworkFunc                      func(ctx context.Context, appName string) (*string, error)
 	GetAppReleasesMachinesFunc             func(ctx context.Context, appName, status string, limit int) ([]fly.Release, error)
+	GetAppScopedEgressIPAddressesFunc      func(ctx context.Context, appName string) (map[string][]fly.EgressIPAddress, error)
 	GetAppSecretsFunc                      func(ctx context.Context, appName string) ([]fly.Secret, error)
 	GetAppsFunc                            func(ctx context.Context, role *string) ([]fly.App, error)
 	GetAppsForOrganizationFunc             func(ctx context.Context, orgID string) ([]fly.App, error)
 	GetCurrentUserFunc                     func(ctx context.Context) (*fly.User, error)
-	GetDNSRecordsFunc                      func(ctx context.Context, domainName string) ([]*fly.DNSRecord, error)
 	GetDelegatedWireGuardTokensFunc        func(ctx context.Context, slug string) ([]*fly.DelegatedWireGuardTokenHandle, error)
 	GetDetailedOrganizationBySlugFunc      func(ctx context.Context, slug string) (*fly.OrganizationDetails, error)
-	GetDomainFunc                          func(ctx context.Context, name string) (*fly.Domain, error)
-	GetDomainsFunc                         func(ctx context.Context, organizationSlug string) ([]*fly.Domain, error)
 	GetIPAddressesFunc                     func(ctx context.Context, appName string) ([]fly.IPAddress, error)
 	GetEgressIPAddressesFunc               func(ctx context.Context, appName string) (map[string][]fly.EgressIPAddress, error)
 	GetLatestImageDetailsFunc              func(ctx context.Context, image string, flyVersion string) (*fly.ImageVersion, error)
@@ -80,12 +76,14 @@ type Client struct {
 	GetOrganizationRemoteBuilderBySlugFunc func(ctx context.Context, slug string) (*fly.Organization, error)
 	GetOrganizationByAppFunc               func(ctx context.Context, appName string) (*fly.Organization, error)
 	GetOrganizationsFunc                   func(ctx context.Context, filters ...fly.OrganizationFilter) ([]fly.Organization, error)
+	GetAllowedReplaySourceOrgSlugsFunc     func(ctx context.Context, slug string) ([]string, error)
+	AddAllowedReplaySourceOrgsFunc         func(ctx context.Context, orgSlug string, sourceOrgSlugs []string) (*fly.Organization, error)
+	RemoveAllowedReplaySourceOrgsFunc      func(ctx context.Context, orgSlug string, orgSlugsToRemove []string) (*fly.Organization, error)
 	GetSnapshotsFromVolumeFunc             func(ctx context.Context, volID string) ([]fly.VolumeSnapshot, error)
 	GetWireGuardPeerFunc                   func(ctx context.Context, slug, name string) (*fly.WireGuardPeer, error)
 	GetWireGuardPeersFunc                  func(ctx context.Context, slug string) ([]*fly.WireGuardPeer, error)
 	GenqClientFunc                         func() genq.Client
-	ImportDNSRecordsFunc                   func(ctx context.Context, domainId string, zonefile string) ([]fly.ImportDnsWarning, []fly.ImportDnsChange, error)
-	IssueSSHCertificateFunc                func(ctx context.Context, org fly.OrganizationImpl, principals []string, appNames []string, valid_hours *int, publicKey ed25519.PublicKey) (*fly.IssuedCertificate, error)
+	IssueSSHCertificateFunc                func(ctx context.Context, orgID string, principals []string, appNames []string, valid_hours *int, publicKey ed25519.PublicKey) (*fly.IssuedCertificate, error)
 	LatestImageFunc                        func(ctx context.Context, appName string) (string, error)
 	ListPostgresClusterAttachmentsFunc     func(ctx context.Context, appName, postgresAppName string) ([]*fly.PostgresClusterAttachment, error)
 	LoggerFunc                             func() fly.Logger
@@ -93,8 +91,9 @@ type Client struct {
 	NewRequestFunc                         func(q string) *graphql.Request
 	PlatformRegionsFunc                    func(ctx context.Context) ([]fly.Region, *fly.Region, error)
 	ReleaseIPAddressFunc                   func(ctx context.Context, appName string, ip string) error
+	ReleaseAppScopedEgressIPAddressFunc    func(ctx context.Context, appName, ip string) error
 	ReleaseEgressIPAddressFunc             func(ctx context.Context, appName string, machineID string) (net.IP, net.IP, error)
-	RemoveWireGuardPeerFunc                func(ctx context.Context, org *fly.Organization, name string) error
+	RemoveWireGuardPeerFunc                func(ctx context.Context, orgID string, name string) error
 	ResolveImageForAppFunc                 func(ctx context.Context, appName, imageRef string) (*fly.Image, error)
 	RevokeLimitedAccessTokenFunc           func(ctx context.Context, id string) error
 	RunFunc                                func(req *graphql.Request) (fly.Query, error)
@@ -111,8 +110,12 @@ func (m *Client) AddCertificate(ctx context.Context, appName, hostname string) (
 	return m.AddCertificateFunc(ctx, appName, hostname)
 }
 
-func (m *Client) AllocateIPAddress(ctx context.Context, appName string, addrType string, region string, org *fly.Organization, network string) (*fly.IPAddress, error) {
-	return m.AllocateIPAddressFunc(ctx, appName, addrType, region, org, network)
+func (m *Client) AllocateAppScopedEgressIPAddress(ctx context.Context, appName string, region string) (net.IP, net.IP, error) {
+	return m.AllocateAppScopedEgressIPAddressFunc(ctx, appName, region)
+}
+
+func (m *Client) AllocateIPAddress(ctx context.Context, appName string, addrType string, region string, orgID string, network string) (*fly.IPAddress, error) {
+	return m.AllocateIPAddressFunc(ctx, appName, addrType, region, orgID, network)
 }
 
 func (m *Client) AllocateSharedIPAddress(ctx context.Context, appName string) (net.IP, error) {
@@ -143,18 +146,10 @@ func (m *Client) CheckAppCertificate(ctx context.Context, appName, hostname stri
 	return m.CheckAppCertificateFunc(ctx, appName, hostname)
 }
 
-func (m *Client) CheckDomain(ctx context.Context, name string) (*fly.CheckDomainResult, error) {
-	return m.CheckDomainFunc(ctx, name)
-}
-
 func (m *Client) ClosestWireguardGatewayRegion(ctx context.Context) (*fly.Region, error) {
 	return m.ClosestWireguardGatewayRegionFunc(ctx)
 }
 
-func (m *Client) CreateAndRegisterDomain(organizationID string, name string) (*fly.Domain, error) {
-	return m.CreateAndRegisterDomainFunc(organizationID, name)
-}
-
 func (m *Client) CreateApp(ctx context.Context, input fly.CreateAppInput) (*fly.App, error) {
 	return m.CreateAppFunc(ctx, input)
 }
@@ -163,18 +158,14 @@ func (m *Client) CreateBuild(ctx context.Context, input fly.CreateBuildInput) (*
 	return m.CreateBuildFunc(ctx, input)
 }
 
-func (m *Client) CreateDelegatedWireGuardToken(ctx context.Context, org *fly.Organization, name string) (*fly.DelegatedWireGuardToken, error) {
-	return m.CreateDelegatedWireGuardTokenFunc(ctx, org, name)
+func (m *Client) CreateDelegatedWireGuardToken(ctx context.Context, orgID string, name string) (*fly.DelegatedWireGuardToken, error) {
+	return m.CreateDelegatedWireGuardTokenFunc(ctx, orgID, name)
 }
 
 func (m *Client) CreateDoctorUrl(ctx context.Context) (putUrl string, err error) {
 	return m.CreateDoctorUrlFunc(ctx)
 }
 
-func (m *Client) CreateDomain(organizationID string, name string) (*fly.Domain, error) {
-	return m.CreateDomainFunc(organizationID, name)
-}
-
 func (m *Client) CreateOrganization(ctx context.Context, organizationname string) (*fly.Organization, error) {
 	return m.CreateOrganizationFunc(ctx, organizationname)
 }
@@ -187,8 +178,8 @@ func (m *Client) CreateRelease(ctx context.Context, input fly.CreateReleaseInput
 	return m.CreateReleaseFunc(ctx, input)
 }
 
-func (m *Client) CreateWireGuardPeer(ctx context.Context, org *fly.Organization, region, name, pubkey, network string) (*fly.CreatedWireGuardPeer, error) {
-	return m.CreateWireGuardPeerFunc(ctx, org, region, name, pubkey, network)
+func (m *Client) CreateWireGuardPeer(ctx context.Context, orgID string, region, name, pubkey, network string) (*fly.CreatedWireGuardPeer, error) {
+	return m.CreateWireGuardPeerFunc(ctx, orgID, region, name, pubkey, network)
 }
 
 func (m *Client) DeleteApp(ctx context.Context, appName string) error {
@@ -199,8 +190,8 @@ func (m *Client) DeleteCertificate(ctx context.Context, appName, hostname string
 	return m.DeleteCertificateFunc(ctx, appName, hostname)
 }
 
-func (m *Client) DeleteDelegatedWireGuardToken(ctx context.Context, org *fly.Organization, name, token *string) error {
-	return m.DeleteDelegatedWireGuardTokenFunc(ctx, org, name, token)
+func (m *Client) DeleteDelegatedWireGuardToken(ctx context.Context, orgID string, name, token *string) error {
+	return m.DeleteDelegatedWireGuardTokenFunc(ctx, orgID, name, token)
 }
 
 func (m *Client) DeleteOrganization(ctx context.Context, id string) (deletedid string, err error) {
@@ -227,10 +218,6 @@ func (m *Client) EnsureDepotRemoteBuilder(ctx context.Context, input *fly.Ensure
 	return m.EnsureDepotRemoteBuilderFunc(ctx, input)
 }
 
-func (m *Client) ExportDNSRecords(ctx context.Context, domainId string) (string, error) {
-	return m.ExportDNSRecordsFunc(ctx, domainId)
-}
-
 func (m *Client) FinishBuild(ctx context.Context, input fly.FinishBuildInput) (*fly.FinishBuildResponse, error) {
 	return m.FinishBuildFunc(ctx, input)
 }
@@ -263,6 +250,10 @@ func (m *Client) GetAppCurrentReleaseMachines(ctx context.Context, appName strin
 	return m.GetAppCurrentReleaseMachinesFunc(ctx, appName)
 }
 
+func (m *Client) GetAppCNAMETarget(ctx context.Context, appName string) (string, error) {
+	return m.GetAppCNAMETargetFunc(ctx, appName)
+}
+
 func (m *Client) GetAppHostIssues(ctx context.Context, appName string) ([]fly.HostIssue, error) {
 	return m.GetAppHostIssuesFunc(ctx, appName)
 }
@@ -291,6 +282,10 @@ func (m *Client) GetAppReleasesMachines(ctx context.Context, appName, status str
 	return m.GetAppReleasesMachinesFunc(ctx, appName, status, limit)
 }
 
+func (m *Client) GetAppScopedEgressIPAddresses(ctx context.Context, appName string) (map[string][]fly.EgressIPAddress, error) {
+	return m.GetAppScopedEgressIPAddressesFunc(ctx, appName)
+}
+
 func (m *Client) GetAppSecrets(ctx context.Context, appName string) ([]fly.Secret, error) {
 	return m.GetAppSecretsFunc(ctx, appName)
 }
@@ -307,10 +302,6 @@ func (m *Client) GetCurrentUser(ctx context.Context) (*fly.User, error) {
 	return m.GetCurrentUserFunc(ctx)
 }
 
-func (m *Client) GetDNSRecords(ctx context.Context, domainName string) ([]*fly.DNSRecord, error) {
-	return m.GetDNSRecordsFunc(ctx, domainName)
-}
-
 func (m *Client) GetDelegatedWireGuardTokens(ctx context.Context, slug string) ([]*fly.DelegatedWireGuardTokenHandle, error) {
 	return m.GetDelegatedWireGuardTokensFunc(ctx, slug)
 }
@@ -319,14 +310,6 @@ func (m *Client) GetDetailedOrganizationBySlug(ctx context.Context, slug string)
 	return m.GetDetailedOrganizationBySlugFunc(ctx, slug)
 }
 
-func (m *Client) GetDomain(ctx context.Context, name string) (*fly.Domain, error) {
-	return m.GetDomainFunc(ctx, name)
-}
-
-func (m *Client) GetDomains(ctx context.Context, organizationSlug string) ([]*fly.Domain, error) {
-	return m.GetDomainsFunc(ctx, organizationSlug)
-}
-
 func (m *Client) GetIPAddresses(ctx context.Context, appName string) ([]fly.IPAddress, error) {
 	return m.GetIPAddressesFunc(ctx, appName)
 }
@@ -371,6 +354,18 @@ func (m *Client) GetOrganizations(ctx context.Context, filters ...fly.Organizati
 	return m.GetOrganizationsFunc(ctx, filters...)
 }
 
+func (m *Client) GetAllowedReplaySourceOrgSlugs(ctx context.Context, slug string) ([]string, error) {
+	return m.GetAllowedReplaySourceOrgSlugsFunc(ctx, slug)
+}
+
+func (m *Client) AddAllowedReplaySourceOrgs(ctx context.Context, orgSlug string, sourceOrgSlugs []string) (*fly.Organization, error) {
+	return m.AddAllowedReplaySourceOrgsFunc(ctx, orgSlug, sourceOrgSlugs)
+}
+
+func (m *Client) RemoveAllowedReplaySourceOrgs(ctx context.Context, orgSlug string, orgSlugsToRemove []string) (*fly.Organization, error) {
+	return m.RemoveAllowedReplaySourceOrgsFunc(ctx, orgSlug, orgSlugsToRemove)
+}
+
 func (m *Client) GetSnapshotsFromVolume(ctx context.Context, volID string) ([]fly.VolumeSnapshot, error) {
 	return m.GetSnapshotsFromVolumeFunc(ctx, volID)
 }
@@ -391,12 +386,8 @@ func (m *Client) LatestImage(ctx context.Context, appName string) (string, error
 	return m.LatestImageFunc(ctx, appName)
 }
 
-func (m *Client) ImportDNSRecords(ctx context.Context, domainId string, zonefile string) ([]fly.ImportDnsWarning, []fly.ImportDnsChange, error) {
-	return m.ImportDNSRecordsFunc(ctx, domainId, zonefile)
-}
-
-func (m *Client) IssueSSHCertificate(ctx context.Context, org fly.OrganizationImpl, principals []string, appNames []string, valid_hours *int, publicKey ed25519.PublicKey) (*fly.IssuedCertificate, error) {
-	return m.IssueSSHCertificateFunc(ctx, org, principals, appNames, valid_hours, publicKey)
+func (m *Client) IssueSSHCertificate(ctx context.Context, orgID string, principals []string, appNames []string, valid_hours *int, publicKey ed25519.PublicKey) (*fly.IssuedCertificate, error) {
+	return m.IssueSSHCertificateFunc(ctx, orgID, principals, appNames, valid_hours, publicKey)
 }
 
 func (m *Client) ListPostgresClusterAttachments(ctx context.Context, appName, postgresAppName string) ([]*fly.PostgresClusterAttachment, error) {
@@ -419,6 +410,10 @@ func (m *Client) PlatformRegions(ctx context.Context) ([]fly.Region, *fly.Region
 	return m.PlatformRegionsFunc(ctx)
 }
 
+func (m *Client) ReleaseAppScopedEgressIPAddress(ctx context.Context, appName, ip string) error {
+	return m.ReleaseAppScopedEgressIPAddressFunc(ctx, appName, ip)
+}
+
 func (m *Client) ReleaseEgressIPAddress(ctx context.Context, appName string, machineID string) (net.IP, net.IP, error) {
 	return m.ReleaseEgressIPAddressFunc(ctx, appName, machineID)
 }
@@ -427,8 +422,8 @@ func (m *Client) ReleaseIPAddress(ctx context.Context, appName string, ip string
 	return m.ReleaseIPAddressFunc(ctx, appName, ip)
 }
 
-func (m *Client) RemoveWireGuardPeer(ctx context.Context, org *fly.Organization, name string) error {
-	return m.RemoveWireGuardPeerFunc(ctx, org, name)
+func (m *Client) RemoveWireGuardPeer(ctx context.Context, orgID string, name string) error {
+	return m.RemoveWireGuardPeerFunc(ctx, orgID, name)
 }
 
 func (m *Client) ResolveImageForApp(ctx context.Context, appName, imageRef string) (*fly.Image, error) {
