@@ -182,8 +182,10 @@ func ConfirmYes(ctx context.Context, message string) (confirm bool, err error) {
 }
 
 func ConfirmOverwrite(ctx context.Context, filename string) (confirm bool, err error) {
+	io := iostreams.FromContext(ctx)
+	colorize := io.ColorScheme()
 	prompt := &survey.Confirm{
-		Message: fmt.Sprintf(`Overwrite "%s"?`, filename),
+		Message: colorize.Yellow(fmt.Sprintf(`Overwrite "%s"?`, filename)),
 	}
 	err = survey.AskOne(prompt, &confirm)
 
@@ -242,6 +244,8 @@ var errOrgSlugRequired = NonInteractiveError("org slug must be specified when no
 func Org(ctx context.Context) (*fly.Organization, error) {
 	client := flyutil.ClientFromContext(ctx)
 
+	slug := config.FromContext(ctx).Organization
+
 	orgs, err := client.GetOrganizations(ctx)
 	if err != nil {
 		return nil, err
@@ -249,7 +253,6 @@ func Org(ctx context.Context) (*fly.Organization, error) {
 	sort.OrganizationsByTypeAndName(orgs)
 
 	io := iostreams.FromContext(ctx)
-	slug := config.FromContext(ctx).Organization
 
 	switch {
 	case slug == "" && len(orgs) == 1 && orgs[0].Type == "PERSONAL":
@@ -313,11 +316,21 @@ var (
 // Fetches all Fly regions and app's default region.
 // Only the first call to this function will issue an HTTP request using ctx.
 // Subsequent calls will return the same future as the first.
+// Deprecated regions are automatically filtered out.
 func PlatformRegions(ctx context.Context) *future.Future[RegionInfo] {
 	regionsOnce.Do(func() {
 		regionsFuture = future.Spawn(func() (RegionInfo, error) {
 			client := flyutil.ClientFromContext(ctx)
 			regions, defaultRegion, err := client.PlatformRegions(ctx)
+			if err != nil {
+				return RegionInfo{}, err
+			}
+
+			// Filter out deprecated regions
+			regions = lo.Filter(regions, func(r fly.Region, _ int) bool {
+				return !r.Deprecated
+			})
+
 			regionInfo := RegionInfo{
 				Regions:       regions,
 				DefaultRegion: defaultRegion,
