@@ -8,15 +8,14 @@ import (
 	"github.com/pkg/errors"
 
 	fly "github.com/superfly/fly-go"
-	"github.com/superfly/flyctl/internal/flyutil"
 )
 
 type pollingStream struct {
 	err       error
-	apiClient flyutil.Client
+	apiClient WebClient
 }
 
-func NewPollingStream(client flyutil.Client) LogStream {
+func NewPollingStream(client WebClient) LogStream {
 	return &pollingStream{apiClient: client}
 }
 
@@ -36,7 +35,7 @@ func (s *pollingStream) Err() error {
 	return s.err
 }
 
-func Poll(ctx context.Context, out chan<- LogEntry, client flyutil.Client, opts *LogOptions) error {
+func Poll(ctx context.Context, out chan<- LogEntry, client WebClient, opts *LogOptions) error {
 	const (
 		minWait = time.Millisecond << 6
 		maxWait = minWait << 6
