@@ -8,7 +8,10 @@ import (
 	"os/exec"
 	"strings"
 
+	"golang.org/x/mod/semver"
+
 	"github.com/superfly/flyctl/helpers"
+	"github.com/superfly/flyctl/internal/command/launch/plan"
 )
 
 func configureNode(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
@@ -49,23 +52,28 @@ func configureNode(sourceDir string, config *ScannerConfig) (*SourceInfo, error)
 
 	vars := make(map[string]interface{})
 
-	var yarnVersion string = "latest"
+	var yarnVersion = "latest"
 
 	// node-build requires a version, so either use the same version as install locally,
 	// or default to an LTS version
-	var nodeLtsVersion string = "18.16.0"
-	var nodeVersion string = nodeLtsVersion
+	var nodeLtsVersion = "18.16.0"
+	var nodeVersion = nodeLtsVersion
 
 	out, err := exec.Command("node", "-v").Output()
 
 	if err == nil {
-		nodeVersion = strings.TrimSpace(string(out))
-		if nodeVersion[:1] == "v" {
-			nodeVersion = nodeVersion[1:]
+		versionWithV := strings.TrimSpace(string(out))
+		// Ensure version starts with 'v' for semver comparison
+		if !strings.HasPrefix(versionWithV, "v") {
+			versionWithV = "v" + versionWithV
 		}
-		if nodeVersion < "16" {
+		// Check if node version is less than 16 using proper semver comparison
+		if semver.IsValid(versionWithV) && semver.Compare(versionWithV, "v16.0.0") < 0 {
+			nodeVersion = strings.TrimPrefix(versionWithV, "v")
 			s.Notice += fmt.Sprintf("\n[WARNING] It looks like you have NodeJS v%s installed, but it has reached it's end of support. Using NodeJS v%s (LTS) to build your image instead.\n", nodeVersion, nodeLtsVersion)
 			nodeVersion = nodeLtsVersion
+		} else {
+			nodeVersion = strings.TrimPrefix(versionWithV, "v")
 		}
 	}
 
@@ -78,7 +86,16 @@ func configureNode(sourceDir string, config *ScannerConfig) (*SourceInfo, error)
 	package_files := []string{"package.json"}
 
 	_, err = os.Stat("yarn.lock")
-	vars["yarn"] = !os.IsNotExist(err)
+	// install yarn if there's a yarn.lock and if nodejs version is under 18
+	yarnLockExists := !os.IsNotExist(err)
+	shouldInstallYarn := false
+	if yarnLockExists {
+		versionWithV := "v" + nodeVersion
+		if semver.IsValid(versionWithV) && semver.Compare(versionWithV, "v18.0.0") < 0 {
+			shouldInstallYarn = true
+		}
+	}
+	vars["yarn"] = shouldInstallYarn
 
 	if os.IsNotExist(err) {
 		vars["packager"] = "npm"
@@ -136,21 +153,15 @@ func configureNode(sourceDir string, config *ScannerConfig) (*SourceInfo, error)
 
 	vars["build"] = scripts["build"] != nil
 
-	if !ok || scripts["start"] == nil {
-		s.DeployDocs = `
-Your Node app doesn't define a start script in package.json.  You will need
-to add one before you deploy.  Also be sure to set your listen port
-to 8080 using code similar to the following:
+	hasStartScript := ok && scripts["start"] != nil
 
-    const port = process.env.PORT || "8080";
-`
+	if !hasStartScript {
+		// No start script - might be a static site, let it fall through to configureStatic
+		return nil, nil
 	} else if remix {
-		s.DeployDocs = `
-Your Remix app is prepared for deployment.
-`
+		s.DeployDocs = "Your Remix app is prepared for deployment.\n"
 	} else {
-		s.DeployDocs = `
-Your Node app is prepared for deployment.  Be sure to set your listen port
+		s.DeployDocs = `Your Node app is prepared for deployment. Be sure to set your listen port
 to 8080 using code similar to the following:
 
     const port = process.env.PORT || "8080";
@@ -177,5 +188,7 @@ Now: run 'fly deploy' to deploy your Node app.
 
 	s.Env = env
 
+	s.Runtime = plan.RuntimeStruct{Language: "node", Version: nodeVersion}
+
 	return s, nil
 }
