@@ -2,8 +2,12 @@ package scanner
 
 import (
 	"bufio"
+	"encoding/json"
+	"fmt"
 	"os"
+	"os/exec"
 	"path/filepath"
+	"regexp"
 	"slices"
 	"strings"
 	"unicode"
@@ -11,6 +15,7 @@ import (
 	"github.com/pkg/errors"
 
 	"github.com/pelletier/go-toml/v2"
+	"github.com/superfly/flyctl/internal/command/launch/plan"
 	"github.com/superfly/flyctl/terminal"
 )
 
@@ -51,6 +56,17 @@ type PyProjectToml struct {
 
 type Pipfile struct {
 	Packages map[string]interface{}
+	Requires PipfileRequires `json:"requires" toml:"requires"`
+}
+
+type PipfileRequires struct {
+	PythonVersion string `json:"python_version" toml:"python_version"`
+}
+
+type PipfileLock struct {
+	Meta struct {
+		Requires PipfileRequires `json:"requires" toml:"requires"`
+	} `json:"_meta"`
 }
 
 type PyCfg struct {
@@ -139,6 +155,9 @@ func intoSource(cfg PyCfg) (*SourceInfo, error) {
 			return nil, nil
 		}
 	}
+
+	runtime := plan.RuntimeStruct{Language: "python"}
+
 	vars[string(cfg.depStyle)] = true
 	objectStorage := slices.Contains(cfg.deps, "boto3") || slices.Contains(cfg.deps, "boto")
 	if app == "" {
@@ -151,6 +170,7 @@ func intoSource(cfg PyCfg) (*SourceInfo, error) {
 			Family:               "FastAPI",
 			Port:                 8000,
 			ObjectStorageDesired: objectStorage,
+			Runtime:              runtime,
 		}, nil
 	} else if app == Flask {
 		vars["flask"] = true
@@ -159,6 +179,7 @@ func intoSource(cfg PyCfg) (*SourceInfo, error) {
 			Family:               "Flask",
 			Port:                 8080,
 			ObjectStorageDesired: objectStorage,
+			Runtime:              runtime,
 		}, nil
 	} else if app == Streamlit {
 		vars["streamlit"] = true
@@ -173,6 +194,7 @@ func intoSource(cfg PyCfg) (*SourceInfo, error) {
 			Family:               "Streamlit",
 			Port:                 8501,
 			ObjectStorageDesired: objectStorage,
+			Runtime:              runtime,
 		}, nil
 	} else {
 		return nil, nil
@@ -273,10 +295,12 @@ func configPipfile(sourceDir string, _ *ScannerConfig) (*SourceInfo, error) {
 		dep := parsePyDep(dep)
 		depList = append(depList, dep)
 	}
+
 	pyVersion, _, err := extractPythonVersion()
 	if err != nil {
 		return nil, err
 	}
+
 	appName := filepath.Base(sourceDir)
 	cfg := PyCfg{pyVersion, appName, depList, Pipenv}
 	return intoSource(cfg)
@@ -339,6 +363,11 @@ func configurePython(sourceDir string, _ *ScannerConfig) (*SourceInfo, error) {
 		return nil, nil
 	}
 
+	pythonVersion, _, err := extractPythonVersion()
+	if err != nil {
+		return nil, err
+	}
+
 	s := &SourceInfo{
 		Files:   templates("templates/python"),
 		Builder: "paketobuildpacks/builder:base",
@@ -349,7 +378,49 @@ func configurePython(sourceDir string, _ *ScannerConfig) (*SourceInfo, error) {
 		},
 		SkipDeploy: true,
 		DeployDocs: `We have generated a simple Procfile for you. Modify it to fit your needs and run "fly deploy" to deploy your application.`,
+		Runtime:    plan.RuntimeStruct{Language: "python", Version: pythonVersion},
 	}
 
 	return s, nil
 }
+
+func extractPythonVersion() (string, bool, error) {
+	var pipfileLock PipfileLock
+	contents, err := os.ReadFile("Pipfile.lock")
+	if err == nil {
+		if err := json.Unmarshal(contents, &pipfileLock); err == nil {
+			if pyVersion := pipfileLock.Meta.Requires.PythonVersion; pyVersion != "" {
+				return pyVersion, true, nil
+			}
+		}
+	}
+
+	/* Example Output:
+	   Python 3.11.2
+	   Python 3.12.0b4
+	*/
+	pythonVersionOutput := "Python 3.12.0" // Fallback to 3.12
+
+	cmd := exec.Command("python3", "--version")
+	out, err := cmd.CombinedOutput()
+	if err == nil {
+		pythonVersionOutput = string(out)
+	} else {
+		cmd := exec.Command("python", "--version")
+		out, err := cmd.CombinedOutput()
+		if err == nil {
+			pythonVersionOutput = string(out)
+		}
+	}
+
+	re := regexp.MustCompile(`Python ([0-9]+\.[0-9]+\.[0-9]+(?:[a-zA-Z]+[0-9]+)?)`)
+	match := re.FindStringSubmatch(pythonVersionOutput)
+
+	if len(match) > 1 {
+		version := match[1]
+		nonNumericRegex := regexp.MustCompile(`[^0-9.]`)
+		pinned := nonNumericRegex.MatchString(version)
+		return version, pinned, nil
+	}
+	return "", false, fmt.Errorf("Could not find Python version")
+}
