@@ -15,12 +15,11 @@ import (
 	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/command/launch/plan"
 	"github.com/superfly/flyctl/internal/flyerr"
-	"gopkg.in/yaml.v2"
+	"gopkg.in/yaml.v3"
 )
 
 var healthcheck_channel = make(chan string)
 var bundle, ruby string
-var binrails = filepath.Join(".", "bin", "rails")
 
 func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	// `bundle init` will create a file with a commented out rails gem,
@@ -44,7 +43,13 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 		}
 
 		if err != nil {
-			return nil, errors.Wrap(err, "failure finding bundle executable")
+			// If bundle is not found but a Dockerfile exists, we can still proceed
+			if _, statErr := os.Stat(filepath.Join(sourceDir, "Dockerfile")); statErr == nil {
+				fmt.Printf("Detected existing Dockerfile, will use it for Rails app (bundle not found)\n")
+				bundle = "" // Mark as unavailable
+			} else {
+				return nil, errors.Wrap(err, "failure finding bundle executable")
+			}
 		}
 	}
 
@@ -55,7 +60,13 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 		}
 
 		if err != nil {
-			return nil, errors.Wrap(err, "failure finding ruby executable")
+			// If ruby is not found but a Dockerfile exists, we can still proceed
+			if _, statErr := os.Stat(filepath.Join(sourceDir, "Dockerfile")); statErr == nil {
+				fmt.Printf("Detected existing Dockerfile, will use it for Rails app (ruby not found)\n")
+				ruby = "" // Mark as unavailable
+			} else {
+				return nil, errors.Wrap(err, "failure finding ruby executable")
+			}
 		}
 	}
 
@@ -117,19 +128,35 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 		// mysql
 		s.DatabaseDesired = DatabaseKindMySQL
 		s.SkipDatabase = false
-	} else if !checksPass(sourceDir, fileExists("Dockerfile")) || checksPass(sourceDir, dirContains("Dockerfile", "libpq-dev", "postgres")) {
-		// postgresql
+	} else if checksPass(sourceDir, dirContains("Dockerfile", "libpq-dev", "postgres")) {
+		// postgresql (detected from existing Dockerfile)
 		s.DatabaseDesired = DatabaseKindPostgres
 		s.SkipDatabase = false
 	} else if checksPass(sourceDir, dirContains("Dockerfile", "sqlite3")) {
-		// sqlite
+		// sqlite (detected from existing Dockerfile)
 		s.DatabaseDesired = DatabaseKindSqlite
 		s.SkipDatabase = true
-		s.ObjectStorageDesired = true
-	} else {
-		// no database
-		s.DatabaseDesired = DatabaseKindNone
+		// Only request object storage if not skipping extensions (for litestream replication)
+		if os.Getenv("SKIP_EXTENSIONS") == "" {
+			s.ObjectStorageDesired = true
+		}
+	} else if checksPass(sourceDir, dirContains("config/database.yml", "adapter.*sqlite")) {
+		// sqlite (detected from database.yml)
+		s.DatabaseDesired = DatabaseKindSqlite
 		s.SkipDatabase = true
+		// Don't set ObjectStorageDesired here - let the normal object storage detection
+		// logic handle it by checking for aws-sdk-s3, active_storage, etc.
+	} else if checksPass(sourceDir, dirContains("config/database.yml", "adapter.*(mysql|trilogy)")) {
+		// mysql (detected from database.yml)
+		s.DatabaseDesired = DatabaseKindMySQL
+		s.SkipDatabase = false
+	} else if checksPass(sourceDir, dirContains("config/database.yml", "adapter.*postgres")) {
+		// postgresql (detected from database.yml)
+		s.DatabaseDesired = DatabaseKindPostgres
+		s.SkipDatabase = false
+	} else {
+		s.DatabaseDesired = DatabaseKindNone
+		s.SkipDatabase = false
 	}
 
 	// enable redis if there are any action cable / anycable channels
@@ -214,6 +241,7 @@ func configureRails(sourceDir string, config *ScannerConfig) (*SourceInfo, error
 	// if the app does not use Rails encrypted credentials.  Rails v6 added
 	// support for multi-environment credentials.  Use the Rails searching
 	// sequence for production credentials to determine the RAILS_MASTER_KEY.
+	binrails := filepath.Join("bin", "rails")
 	masterKey, err := os.ReadFile("config/credentials/production.key")
 	if err != nil {
 		masterKey, err = os.ReadFile("config/master.key")
@@ -278,22 +306,30 @@ Once ready: run 'fly deploy' to deploy your Rails app.
 	}
 
 	// fetch healthcheck route in a separate thread
-	go func() {
-		ruby, err := exec.LookPath("ruby")
-		if err != nil {
+	// Skip in tests to avoid file handle issues on Windows during cleanup
+	if config.SkipHealthcheck {
+		// Send empty value immediately to avoid blocking code that reads from the channel
+		go func() {
 			healthcheck_channel <- ""
-			return
-		}
+		}()
+	} else {
+		go func() {
+			ruby, err := exec.LookPath("ruby")
+			if err != nil {
+				healthcheck_channel <- ""
+				return
+			}
 
-		out, err := exec.Command(ruby, binrails, "runner",
-			"puts Rails.application.routes.url_helpers.rails_health_check_path").Output()
+			out, err := exec.Command(ruby, binrails, "runner",
+				"puts Rails.application.routes.url_helpers.rails_health_check_path").Output()
 
-		if err == nil {
-			healthcheck_channel <- strings.TrimSpace(string(out))
-		} else {
-			healthcheck_channel <- ""
-		}
-	}()
+			if err == nil {
+				healthcheck_channel <- strings.TrimSpace(string(out))
+			} else {
+				healthcheck_channel <- ""
+			}
+		}()
+	}
 
 	return s, nil
 }
@@ -307,6 +343,42 @@ func RailsCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchPlan, f
 	// If the generator fails but a Dockerfile exists, warn the user and proceed.  Only fail if no
 	// Dockerfile exists at the end of this process.
 
+	binrails := filepath.Join("bin", "rails")
+
+	// If bundle or ruby are not available, check if Dockerfile exists and skip generator
+	if bundle == "" || ruby == "" {
+		if _, err := os.Stat("Dockerfile"); err == nil {
+			fmt.Printf("Using existing Dockerfile (bundle/ruby not available locally)\n")
+			// Read and parse the existing Dockerfile to extract configuration
+			if dockerfile, err := os.ReadFile("Dockerfile"); err == nil {
+				// Extract port from Dockerfile
+				re := regexp.MustCompile(`(?m)^EXPOSE\s+(?P<port>\d+)`)
+				m := re.FindStringSubmatch(string(dockerfile))
+				if len(m) > 0 {
+					if port, err := strconv.Atoi(m[1]); err == nil {
+						srcInfo.Port = port
+					}
+				}
+
+				// Extract volume
+				reVol := regexp.MustCompile(`(?m)^VOLUME\s+(\[\s*")?(\/[\w\/]*?(\w+))("\s*\])?\s*$`)
+				mVol := reVol.FindStringSubmatch(string(dockerfile))
+				if len(mVol) > 0 {
+					srcInfo.Volumes = []Volume{
+						{
+							Source:      mVol[3],
+							Destination: mVol[2],
+						},
+					}
+				}
+			}
+
+			return nil
+		} else {
+			return errors.New("No Dockerfile found and bundle/ruby not available to generate one")
+		}
+	}
+
 	// install dockerfile-rails gem, if not already included and the gem directory is writable
 	// if an error occurrs, store it for later in pendingError
 	generatorInstalled := false
@@ -359,21 +431,52 @@ func RailsCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchPlan, f
 
 	err = cmd.Run()
 	if err != nil {
-		return errors.Wrap(err, "Failed to install bundle, exiting")
+		// Check if a Dockerfile already exists - if so, we can proceed without bundle
+		if dockerfile, statErr := os.ReadFile("Dockerfile"); statErr == nil {
+			fmt.Printf("Detected existing Dockerfile, will use it for Rails app (skipping dockerfile-rails generator)\n")
+
+			// Extract port from existing Dockerfile
+			re := regexp.MustCompile(`(?m)^EXPOSE\s+(?P<port>\d+)`)
+			m := re.FindStringSubmatch(string(dockerfile))
+			if len(m) > 0 {
+				if port, parseErr := strconv.Atoi(m[1]); parseErr == nil {
+					srcInfo.Port = port
+				}
+			}
+
+			// Extract volume from existing Dockerfile
+			reVol := regexp.MustCompile(`(?m)^VOLUME\s+(\[\s*")?(\/[\w\/]*?(\w+))("\s*\])?\s*$`)
+			mVol := reVol.FindStringSubmatch(string(dockerfile))
+			if len(mVol) > 0 {
+				srcInfo.Volumes = []Volume{
+					{
+						Source:      mVol[3],
+						Destination: mVol[2],
+					},
+				}
+			}
+
+			// Successfully using existing Dockerfile, return without running generator
+			return nil
+		} else {
+			return errors.Wrap(err, "Failed to install bundle, exiting")
+		}
 	}
 
-	// ensure Gemfile.lock includes the x86_64-linux platform
-	if out, err := exec.Command(bundle, "platform").Output(); err == nil {
-		if !strings.Contains(string(out), "x86_64-linux") {
-			cmd := exec.Command(bundle, "lock", "--add-platform", "x86_64-linux")
-			if err := cmd.Run(); err != nil {
-				return errors.Wrap(err, "Failed to add x86_64-linux platform, exiting")
+	// ensure Gemfile.lock includes the x86_64-linux platform (skip if bundle install failed)
+	if pendingError == nil {
+		if out, err := exec.Command(bundle, "platform").Output(); err == nil {
+			if !strings.Contains(string(out), "x86_64-linux") {
+				cmd := exec.Command(bundle, "lock", "--add-platform", "x86_64-linux")
+				if err := cmd.Run(); err != nil {
+					return errors.Wrap(err, "Failed to add x86_64-linux platform, exiting")
+				}
 			}
 		}
 	}
 
 	// ensure fly.toml exists.  If present, the rails dockerfile generator will
-	// add volumes, processes, release command and potentailly other configuration.
+	// add volumes, processes, release command and potentially other configuration.
 	flyToml := "fly.toml"
 	_, err = os.Stat(flyToml)
 	if os.IsNotExist(err) {
@@ -392,8 +495,7 @@ func RailsCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchPlan, f
 	}
 
 	// base generate command
-	args := []string{binrails, "generate", "dockerfile",
-		"--label=fly_launch_runtime:rails"}
+	args := []string{binrails, "generate", "dockerfile", "--label=fly_launch_runtime:rails"}
 
 	// skip prompt to replace files if Dockerfile already exists
 	_, err = os.Stat("Dockerfile")
@@ -405,9 +507,21 @@ func RailsCallback(appName string, srcInfo *SourceInfo, plan *plan.LaunchPlan, f
 		}
 	}
 
-	// add postgres
-	if plan.Postgres.Provider() != nil {
+	// Pass database flags based on what the app actually uses, not what's in the plan
+	// This ensures the Dockerfile is configured correctly even if the plan includes
+	// a different database (e.g., when migrating from SQLite to Postgres or when
+	// extensions are skipped in tests)
+	switch srcInfo.DatabaseDesired {
+	case DatabaseKindPostgres:
 		args = append(args, "--postgresql", "--no-prepare")
+	case DatabaseKindMySQL:
+		args = append(args, "--mysql")
+	case DatabaseKindSqlite:
+		// No additional flags needed for SQLite here
+	case DatabaseKindNone:
+		// No database flags needed
+	default:
+		// Unknown database kind; no flags added
 	}
 
 	// add redis
