@@ -79,9 +79,9 @@ destination = "/data"
 `
 	}
 
-	f.WriteFlyToml(config)
+	f.WriteFlyToml("%s", config)
 
-	f.Fly("deploy --ha=false")
+	f.Fly("deploy --buildkit --remote-only --ha=false")
 	assertMachineCount(t, f, appName, 1)
 
 	t.Logf("scale up %s to %d machines", appName, n)
@@ -111,12 +111,12 @@ primary_region = "%s"
 	destination = "/data"
 	`, appName, f.PrimaryRegion())
 
-	f.Fly("deploy --ha=false")
+	f.Fly("deploy --buildkit --remote-only --ha=false")
 	ml := f.MachinesList(appName)
 	require.Equal(f, 1, len(ml))
 
 	// Extend the volume because if not found, scaling will default to 1GB.
-	f.Fly("vol extend -s 4 %s", ml[0].Config.Mounts[0].Volume)
+	f.Fly("volume extend %s --size 4 --app %s", ml[0].Config.Mounts[0].Volume, appName)
 
 	f.Fly("scale count -y 2")
 	require.EventuallyWithT(t, func(c *assert.CollectT) {
